@@ -80,15 +80,9 @@
     #endif
 #endif
 
-// Use this to seed the PRNG with a bit more than just time()... which
-// leads to problems if for any reason we get started twice in the same
-// second.
-#define USE_MORE_SECURE_SEED
-
 // =========================================================================
 //  System Defines
 // =========================================================================
-// Define plain_term for Unix and dos_term for DOS.
 
 #ifdef UNIX
     // Uncomment if you're running Crawl with dgamelaunch and have
@@ -101,10 +95,6 @@
     #define USE_UNIX_SIGNALS
 #endif
 
-    // If this is defined, Crawl will attempt to save and exit when it
-    // receives a hangup signal.
-    #define SIGHUP_SAVE
-
     #define FILE_SEPARATOR '/'
 #ifndef USE_TILE
     #define USE_CURSES
@@ -149,25 +139,6 @@
 
     #include "libunix.h"
 
-#elif defined(TARGET_OS_DOS)
-    #define SHORT_FILE_NAMES
-
-    #define FILE_SEPARATOR '\\'
-
-    #include <string>
-    #include "libdos.h"
-
-    #include <dos.h>
-    #include <file.h>
-
-    #define round(x) floor((x)+0.5)
-
-    // Use Perl-compatible regular expressions. libpcre must be available and
-    // linked in.  This is optional.
-    #ifndef REGEX_PCRE
-    #define REGEX_PCRE
-    #endif
-
 #elif defined(TARGET_OS_WINDOWS)
     #if !defined(USE_TILE)
         #include "libw32c.h"
@@ -185,12 +156,15 @@
     #ifndef REGEX_PCRE
     #define REGEX_PCRE
     #endif
-
-    #define NEED_USLEEP
 #else
     #error Missing platform #define or unsupported compiler.
 #endif
 
+#ifndef _WIN32_WINNT
+// Allow using Win2000 syscalls.
+# define _WIN32_WINNT 0x501
+#endif
+
 #if defined(__GNUC__)
 # define NORETURN __attribute__ ((noreturn))
 #elif defined(_MSC_VER)
@@ -228,16 +202,6 @@
     // it in-place, instead of torching the old file.
     #define DGL_REWRITE_PROTECT_DB_FILES
 
-    #ifndef USE_MORE_SECURE_SEED
-    #error DGAMELAUNCH builds should define USE_MORE_SECURE_SEED
-    #endif
-
-    // This secures the PRNG itself by hashing the values with SHA256.
-    // It doesn't have much point if USE_MORE_SECURE_SEED is not used.
-    // PRNG will be about 15 times slower when this is turned on, but
-    // even with that the cpu time used by the PRNG is relatively small.
-    #define MORE_HARDENED_PRNG
-
     // Startup preferences are saved by player name rather than uid,
     // since all players use the same uid in dgamelaunch.
     #ifndef DGL_NO_STARTUP_PREFS_BY_NAME
@@ -343,14 +307,6 @@
     #endif
 #endif
 
-
-#ifdef USE_TILE
-    #ifdef __cplusplus
-    #include "libgui.h"
-    #include "tilesdl.h"
-    #endif
-#endif
-
 // =========================================================================
 //  Lua user scripts (NOTE: this may also be enabled in your makefile!)
 // =========================================================================
@@ -367,6 +323,9 @@
 // =========================================================================
 //  Game Play Defines
 // =========================================================================
+// use Abyss morphing
+// #define NEW_ABYSS
+
 // number of older messages stored during play and in save files
 #define NUM_STORED_MESSAGES   1000
 
@@ -386,9 +345,6 @@
 // in the score file.
 // #define SCORE_WIZARD_CHARACTERS
 
-// Zot Defense is too buggy for 0.8, temporarily disabled.
-// #define ENABLE_ZOTDEF
-
 #define SAVE_SUFFIX ".cs"
 
 // If you are installing Crawl for multiple users, define SAVE_DIR
@@ -397,14 +353,6 @@
 // these -- usually this means you should place them in ~/crawl/
 // unless it's a DGL build.
 
-// If we're on a multiuser system, file locking of shared files is
-// very important (else things will just keep getting corrupted)
-#define USE_FILE_LOCKING
-
-#if defined(DGL_SIMPLE_MESSAGING) && !defined(USE_FILE_LOCKING)
-#error Must define USE_FILE_LOCKING for DGL_SIMPLE_MESSAGING
-#endif
-
 #if !defined(DB_NDBM) && !defined(DB_DBH) && !defined(USE_SQLITE_DBM)
 #define USE_SQLITE_DBM
 #endif
@@ -421,15 +369,16 @@
 
 #ifdef __cplusplus
 
-
 template < class T >
 inline void UNUSED(const volatile T &)
 {
 }
 
+#endif // __cplusplus
+
 // And now headers we want precompiled
 #ifdef TARGET_COMPILER_VC
-#include "msvc.h"
+# include "msvc.h"
 #endif
 
 #include "externs.h"
@@ -437,9 +386,14 @@ inline void UNUSED(const volatile T &)
 #include "version.h"
 
 #ifdef TARGET_COMPILER_VC
-#include "libw32c.h"
+# include "libw32c.h"
 #endif
 
-#endif // __cplusplus
+#ifdef USE_TILE
+# ifdef __cplusplus
+#  include "libgui.h"
+#  include "tiles.h"
+# endif
+#endif
 
 #endif // APPHDR_H
