@@ -7,12 +7,14 @@
 
 #include "abyss.h"
 
+#include <cmath>
 #include <cstdlib>
 #include <algorithm>
 
 #include "abyss.h"
 #include "areas.h"
 #include "artefact.h"
+#include "cellular.h"
 #include "cloud.h"
 #include "colour.h"
 #include "coord.h"
@@ -41,7 +43,6 @@
 #include "showsymb.h"
 #include "sprint.h"
 #include "state.h"
-#include "stuff.h"
 #include "terrain.h"
 #ifdef USE_TILE
  #include "tiledef-dngn.h"
@@ -50,6 +51,7 @@
 #include "traps.h"
 #include "travel.h"
 #include "view.h"
+#include "viewgeom.h"
 #include "xom.h"
 #ifdef WIZARD
  #include "wiz-dgn.h"
@@ -57,6 +59,13 @@
 
 const int ABYSSAL_RUNE_MAX_ROLL = 200;
 
+#ifdef NEW_ABYSS
+static abyss_state abyssal_state;
+
+static std::vector<dungeon_feature_type> abyssal_features;
+static std::list<monster*> displaced_monsters;
+#endif
+
 // If not_seen is true, don't place the feature where it can be seen from
 // the centre.
 static bool _place_feature_near(const coord_def &centre,
@@ -80,11 +89,9 @@ static bool _place_feature_near(const coord_def &centre,
 
         if (grd(cp) == candidate)
         {
-#ifdef DEBUG_DIAGNOSTICS
-            mprf(MSGCH_DIAGNOSTICS, "Placing %s at (%d,%d)",
+            dprf("Placing %s at (%d,%d)",
                  dungeon_feature_name(replacement),
                  cp.x, cp.y);
-#endif
             grd(cp) = replacement;
             return (true);
         }
@@ -106,6 +113,44 @@ static dungeon_feature_type _abyss_proto_feature()
                                0));
 }
 
+#ifdef NEW_ABYSS
+void _write_abyssal_features()
+{
+    if (abyssal_features.empty())
+        return;
+
+    const int count = abyssal_features.size();
+    const int scalar = 0xFF;
+    int index = 0;
+    for (radius_iterator ri(ABYSS_CENTRE, LOS_RADIUS, C_ROUND); ri; ++ri)
+    {
+        const int dist = distance(ABYSS_CENTRE, *ri);
+        int chance = pow(0.98, dist) * scalar;
+        if (!map_masked(*ri, MMT_VAULT))
+        {
+            if (dist < 4 || x_chance_in_y(chance, scalar))
+            {
+                if (abyssal_features[index] != DNGN_UNSEEN)
+                {
+                    grd(*ri) = abyssal_features[index];
+                    env.level_map_mask(*ri) = MMT_VAULT;
+                }
+            }
+            else
+            {
+                //Entombing the player is lame.
+                grd(*ri) = DNGN_FLOOR;
+            }
+        }
+
+        ++index;
+        if (index > count)
+            return;
+    }
+}
+
+#else
+
 // Generate the initial (proto) Abyss level. The proto Abyss is where
 // the player lands when they arrive in the Abyss from elsewhere.
 // _generate_area generates all other Abyss areas.
@@ -114,10 +159,7 @@ void generate_abyss()
     env.level_build_method += " abyss";
     env.level_layout_types.insert("abyss");
 
-#ifdef DEBUG_ABYSS
-    mprf(MSGCH_DIAGNOSTICS,
-         "generate_abyss(); turn_on_level: %d", env.turns_on_level);
-#endif
+    dprf("generate_abyss(); turn_on_level: %d", env.turns_on_level);
 
     for (rectangle_iterator ri(MAPGEN_BORDER); ri; ++ri)
         grd(*ri) = _abyss_proto_feature();
@@ -142,17 +184,18 @@ void generate_abyss()
         }
     }
 }
+#endif
 
 // Returns the roll to use to check if we want to create an abyssal rune.
 static int _abyssal_rune_roll()
 {
-    if (you.attribute[ATTR_ABYSSAL_RUNES])
+    if (you.runes[RUNE_ABYSSAL])
         return (-1);
 
     // The longer the player's hung around in the Abyss, the more
     // likely the rune. Never generate a new rune if the player
     // already found one, but make the Abyssal rune eligible for
-    // generation again if the player loses it.
+    // generation again if the player fails to find or pick it up.
 
     // If the player leaves the Abyss turns_on_level resets to 0. So
     // hang in there if you want your Abyssal rune fix quick. :P
@@ -182,7 +225,7 @@ static int _abyssal_rune_roll()
     const int odds =
         std::min(1 + std::max((env.turns_on_level - cutoff) / scale, 0), 34);
 #ifdef DEBUG_ABYSS
-    mprf(MSGCH_DIAGNOSTICS, "Abyssal rune odds: %d in %d (%.2f%%)",
+    dprf("Abyssal rune odds: %d in %d (%.2f%%)",
          odds, ABYSSAL_RUNE_MAX_ROLL, odds * 100.0 / ABYSSAL_RUNE_MAX_ROLL);
 #endif
     return (odds);
@@ -392,7 +435,11 @@ static std::vector<dungeon_feature_type> _abyss_pick_terrain_elements()
 {
     std::vector<dungeon_feature_type> terrain_elements;
 
+#ifdef NEW_ABYSS
+    const int n_terrain_elements = random_range(5,7);
+#else
     const int n_terrain_elements = 5;
+#endif
 
     // Generate level composition vector.
     for (int i = 0; i < n_terrain_elements; i++)
@@ -413,6 +460,46 @@ static std::vector<dungeon_feature_type> _abyss_pick_terrain_elements()
     return (terrain_elements);
 }
 
+#ifdef NEW_ABYSS
+void push_features_to_abyss()
+{
+    abyssal_features.clear();
+
+    for (radius_iterator ri(you.pos(), LOS_RADIUS, C_ROUND); ri; ++ri)
+    {
+        dungeon_feature_type feature = grd(*ri);
+
+        if(!in_bounds(*ri))
+            feature = DNGN_UNSEEN;
+
+        if (feat_is_stair(feature))
+            feature = (one_chance_in(3) ? DNGN_STONE_ARCH : DNGN_FLOOR);
+
+        if (feat_is_altar(feature))
+            feature = (one_chance_in(9) ? DNGN_ALTAR_XOM : DNGN_FLOOR);
+
+        if (feat_is_trap(feature, true))
+            feature = DNGN_FLOOR;
+
+        switch (feature)
+        {
+            // demote permarock
+            case DNGN_PERMAROCK_WALL:
+                feature = DNGN_ROCK_WALL;
+                break;
+            case DNGN_CLEAR_PERMAROCK_WALL:
+                feature = DNGN_CLEAR_ROCK_WALL;
+            case DNGN_SLIMY_WALL:
+                feature = DNGN_GREEN_CRYSTAL_WALL;
+            default:
+                // handle more terrain types.
+                break;
+        }
+        abyssal_features.push_back(feature);
+    }
+}
+#endif
+
 // Returns N so that the chance of placing an abyss exit on any given
 // square is 1 in N.
 static int _abyss_exit_chance()
@@ -455,9 +542,7 @@ static bool _abyss_check_place_feat(coord_def p,
             *use_map = false;
         }
         else
-        {
             grd(p) = which_feat;
-        }
 
         if (feats_wanted)
             --*feats_wanted;
@@ -468,23 +553,21 @@ static bool _abyss_check_place_feat(coord_def p,
 
 static dungeon_feature_type _abyss_pick_altar()
 {
-    dungeon_feature_type altar = DNGN_UNSEEN;
-
     // Lugonu has a flat 50% chance of corrupting the altar.
     if (coinflip())
-        return DNGN_ALTAR_LUGONU;
+        return (DNGN_ALTAR_LUGONU);
+
+    god_type god;
 
     do
-    {
-        altar = static_cast<dungeon_feature_type>(
-            DNGN_ALTAR_FIRST_GOD + random2(NUM_GODS - 1));
-    }
-    while (is_good_god(feat_altar_god(altar))
-           || is_unavailable_god(feat_altar_god(altar)));
+        god = random_god(true);
+    while (is_good_god(god)
+           || is_unavailable_god(god));
 
-    return (altar);
+    return (altar_for_god(god));
 }
 
+#ifndef NEW_ABYSS
 static void _abyss_apply_terrain(const map_mask &abyss_genlevel_mask)
 {
     const std::vector<dungeon_feature_type> terrain_elements =
@@ -569,8 +652,7 @@ static void _generate_area(const map_mask &abyss_genlevel_mask,
         find_floor_item(OBJ_MISCELLANY, MISC_RUNE_OF_ZOT);
 
 #ifdef DEBUG_ABYSS
-    mprf(MSGCH_DIAGNOSTICS,
-         "_generate_area(). turns_on_level: %d, rune_on_floor: %s",
+    dprf("_generate_area(). turns_on_level: %d, rune_on_floor: %s",
          env.turns_on_level, placed_abyssal_rune? "yes" : "no");
 #endif
 
@@ -586,6 +668,7 @@ static void _generate_area(const map_mask &abyss_genlevel_mask,
     // Abyss has a constant density.
     env.density = 0;
 }
+#endif
 
 class xom_abyss_feature_amusement_check
 {
@@ -639,19 +722,11 @@ public:
         const bool exit_is_near = abyss_exit_nearness();
         const bool rune_is_near = abyss_rune_nearness();
 
-        if (exit_was_near && !exit_is_near
-            || rune_was_near && !rune_is_near
-            && you.attribute[ATTR_ABYSSAL_RUNES] == 0)
-        {
-            xom_is_stimulated(255, "Xom snickers loudly.", true);
-        }
+        if (exit_was_near && !exit_is_near || rune_was_near && !rune_is_near)
+            xom_is_stimulated(200, "Xom snickers loudly.", true);
 
-        if (!rune_was_near && rune_is_near
-            && you.attribute[ATTR_ABYSSAL_RUNES] == 0
-            || !exit_was_near && exit_is_near)
-        {
-            xom_is_stimulated(255);
-        }
+        if (!rune_was_near && rune_is_near || !exit_was_near && exit_is_near)
+            xom_is_stimulated(200);
     }
 };
 
@@ -680,6 +755,35 @@ static void _abyss_move_sanctuary(const coord_def abyss_shift_start_centre,
     }
 }
 
+#ifdef NEW_ABYSS
+static void _push_displaced_monster(monster* mon)
+{
+    displaced_monsters.push_back(mon);
+}
+
+static void _place_displaced_monsters()
+{
+    std::list<monster*>::iterator mon_itr;
+
+    for (mon_itr = displaced_monsters.begin();
+         mon_itr != displaced_monsters.end(); ++mon_itr)
+    {
+        monster* mon = *mon_itr;
+        if (!mon->find_home_near_place(mon->pos()))
+        {
+            maybe_bloodify_square(mon->pos());
+            if (you.can_see(mon))
+                simple_monster_message(mon, " is pulled into the abyss.",
+                        MSGCH_BANISHMENT);
+            _abyss_lose_monster(*mon);
+
+        }
+    }
+
+    displaced_monsters.clear();
+}
+#endif
+
 // Deletes everything on the level at the given position.
 // Things that are wiped:
 // 1. Dungeon terrain (set to DNGN_UNSEEN)
@@ -692,7 +796,11 @@ static void _abyss_move_sanctuary(const coord_def abyss_shift_start_centre,
 // 8. Vault id mask
 // 9. Map markers
 
+#ifdef NEW_ABYSS
+static void _abyss_wipe_square_at(coord_def p, bool saveMonsters=false)
+#else
 static void _abyss_wipe_square_at(coord_def p)
+#endif
 {
     // Nuke terrain.
     destroy_shop_at(p);
@@ -703,13 +811,22 @@ static void _abyss_wipe_square_at(coord_def p)
     // Nuke items.
 #ifdef DEBUG_ABYSS
     if (igrd(p) != NON_ITEM)
-        mprf(MSGCH_DIAGNOSTICS, "Nuke item stack at (%d, %d)", p.x, p.y);
+        dprf("Nuke item stack at (%d, %d)", p.x, p.y);
 #endif
     lose_item_stack(p);
 
     // Nuke monster.
     if (monster* mon = monster_at(p))
+#ifdef NEW_ABYSS
+    {
+        if (saveMonsters)
+            _push_displaced_monster(mon);
+        else
+            _abyss_lose_monster(*mon);
+    }
+#else
         _abyss_lose_monster(*mon);
+#endif
 
     // Delete cloud.
     delete_cloud_at(p);
@@ -727,6 +844,8 @@ static void _abyss_wipe_square_at(coord_def p)
     env.level_map_ids(p)  = INVALID_MAP_INDEX;
 
     remove_markers_and_listeners_at(p);
+
+    env.map_knowledge(p).clear();
 }
 
 // Removes monsters, clouds, dungeon features, and items from the
@@ -760,7 +879,9 @@ static void _abyss_move_masked_vaults_by_delta(const map_mask &mask,
          i != vault_indexes.end(); ++i)
     {
         vault_placement &vp(*env.level_vaults[*i]);
+#ifdef DEBUG_DIAGNOSTICS
         const coord_def oldp = vp.pos;
+#endif
         vp.pos += delta;
         dprf("Moved vault (%s) from (%d,%d)-(%d,%d)",
              vp.map.name.c_str(), oldp.x, oldp.y, vp.pos.x, vp.pos.y);
@@ -833,8 +954,8 @@ static void _abyss_move_entities(coord_def target_centre,
 static void _abyss_expand_mask_to_cover_vault(map_mask *mask,
                                               int map_index)
 {
-    dprf("Expanding mask to cover vault %d (nvaults: %d)",
-         map_index, env.level_vaults.size());
+    dprf("Expanding mask to cover vault %d (nvaults: %u)",
+         map_index, (unsigned int)env.level_vaults.size());
     const vault_placement &vp = *env.level_vaults[map_index];
     for (vault_place_iterator vpi(vp); vpi; ++vpi)
         (*mask)(*vpi) = true;
@@ -904,6 +1025,10 @@ static void _abyss_shift_level_contents_around_player(
 {
     const coord_def source_centre = you.pos();
 
+#ifdef NEW_ABYSS
+    abyssal_state.major_coord += (source_centre - ABYSS_CENTRE);
+#endif
+
     ASSERT(radius >= LOS_RADIUS);
 #ifdef WIZARD
     // This should only really happen due to wizmode blink/movement.
@@ -977,21 +1102,213 @@ void maybe_shift_abyss_around_player()
          if (mitm[i].defined())
              ++j;
 
-    mprf(MSGCH_DIAGNOSTICS, "Number of items present: %d", j);
+    dprf("Number of items present: %d", j);
 
     j = 0;
     for (monster_iterator mi; mi; ++mi)
         ++j;
 
-    mprf(MSGCH_DIAGNOSTICS, "Number of monsters present: %d", j);
-    mprf(MSGCH_DIAGNOSTICS, "Number of clouds present: %d", env.cloud_no);
+    dprf("Number of monsters present: %d", j);
+    dprf("Number of clouds present: %d", env.cloud_no);
 #endif
 }
 
+void save_abyss_uniques()
+{
+    for (monster_iterator mi; mi; ++mi)
+        if (mi->needs_abyss_transit()
+            && !testbits(mi->flags, MF_TAKING_STAIRS))
+        {
+            mi->set_transit(level_id(LEVEL_ABYSS));
+        }
+}
+
+#ifdef NEW_ABYSS
+static bool _abyss_teleport_within_level()
+{
+    // Try to find a good spot within the shift zone.
+    for (int i = 0; i < 100; i++)
+    {
+        const coord_def newspot =
+            dgn_random_point_in_margin(MAPGEN_BORDER
+                                       + ABYSS_AREA_SHIFT_RADIUS
+                                       + 1);
+
+        if ((grd(newspot) == DNGN_FLOOR
+             || grd(newspot) == DNGN_SHALLOW_WATER)
+            && !monster_at(newspot)
+            && env.cgrid(newspot) == EMPTY_CLOUD)
+        {
+#ifdef DEBUG_ABYSS
+            dprf("Abyss same-area teleport to (%d,%d).",
+                 newspot.x, newspot.y);
+#endif
+            you.moveto(newspot);
+            return (true);
+        }
+    }
+    return (false);
+}
+
+static void _abyss_apply_terrain(const map_mask &abyss_genlevel_mask,
+        bool applyGlobal=false)
+{
+    const std::vector<dungeon_feature_type> terrain_elements = _abyss_pick_terrain_elements();
+
+    if (one_chance_in(3))
+        _abyss_create_rooms(abyss_genlevel_mask, random_range(1, 10));
+
+    const int exit_chance = _abyss_exit_chance();
+
+    // Except for the altar on the starting position, don't place any
+    // altars.
+    const int altar_chance =
+        you.char_direction != GDT_GAME_START? 10000 : 0;
+
+    const int n_terrain_elements = terrain_elements.size();
+    int exits_wanted  = 0;
+    int altars_wanted = 0;
+    bool use_abyss_exit_map = true;
+
+    const coord_def major_coord = abyssal_state.major_coord;
+    const double abyss_depth = abyssal_state.depth;
+    const double scale = 2.2;
+
+    const int NUM_CLOUDS = 6;
+    const cloud_type clouds[NUM_CLOUDS] =
+    {
+        CLOUD_BLACK_SMOKE,
+        CLOUD_GREY_SMOKE,
+        CLOUD_BLUE_SMOKE,
+        CLOUD_PURPLE_SMOKE,
+        CLOUD_TLOC_ENERGY,
+        CLOUD_MIST
+    };
+
+    for (rectangle_iterator ri(MAPGEN_BORDER); ri; ++ri)
+    {
+
+        const coord_def p(*ri);
+
+        if (you.pos() == p)
+            continue;
+
+        if (!abyss_genlevel_mask(p) || map_masked(p, MMT_VAULT))
+            continue;
+
+        double x = (p.x + major_coord.x);
+        double y = (p.y + major_coord.y);
+        worley::noise_datum noise = worley::worley(x/scale, y/scale, abyss_depth);
+        dungeon_feature_type feat = DNGN_FLOOR;
+
+        if (grd(p) == DNGN_UNSEEN || applyGlobal)
+        {
+            worley::noise_datum sub_noise =
+                worley::worley(x*17, y*31, abyss_depth / 10);
+
+            int dist = noise.distance[0] * 100;
+            bool isWall = (dist > 118 || dist < 40);
+
+            if (noise.id[0] + noise.id[1] % 2  == 0)
+                isWall = sub_noise.id[0] % 2;
+
+            if (sub_noise.id[0] % 3 == 0)
+                isWall = isWall ^ true;
+
+            if (isWall)
+            {
+                int fuzz = (sub_noise.id[1] % 3 ? 0 : sub_noise.id[1] % 2 + 1);
+                int id = (noise.id[0] + fuzz) % n_terrain_elements;
+                feat = terrain_elements[id];
+            }
+
+            if (feat != grd(p))
+            {
+                if (applyGlobal)
+                    _abyss_wipe_square_at(*ri, true);
+
+                if (feat == DNGN_FLOOR && in_los_bounds_g(p) && !(noise.id[1] % 3))
+                {
+                    cloud_type cloud = clouds[sub_noise.id[1] % NUM_CLOUDS];
+                    check_place_cloud(cloud, p, (noise.id[1] % 4)+2, 0);
+                }
+                grd(p) = feat;
+            }
+
+
+            // Place abyss exits, stone arches, and altars to liven up the scene:
+            (_abyss_check_place_feat(p, exit_chance,
+                                     &exits_wanted,
+                                     &use_abyss_exit_map,
+                                     DNGN_EXIT_ABYSS,
+                                     abyss_genlevel_mask)
+             ||
+             _abyss_check_place_feat(p, altar_chance,
+                                     &altars_wanted,
+                                     NULL,
+                                     _abyss_pick_altar(),
+                                     abyss_genlevel_mask)
+             ||
+             _abyss_check_place_feat(p, 10000, NULL, NULL,
+                                     DNGN_STONE_ARCH,
+                                     abyss_genlevel_mask));
+        }
+
+    }
+}
+
+static int _abyss_place_vaults(const map_mask &abyss_genlevel_mask)
+{
+    unwind_vault_placement_mask vaultmask(&abyss_genlevel_mask);
+
+    int vaults_placed = 0;
+
+    const int maxvaults = 4;
+    for (int i = 0; i < maxvaults; ++i)
+    {
+        const map_def *map = random_map_for_tag("abyss", false, true);
+        if (!map)
+            break;
+
+        if (_abyss_place_map(map) && !one_chance_in(2 + (++vaults_placed)))
+            break;
+    }
+
+    return (vaults_placed);
+}
+
+static void _generate_area(const map_mask &abyss_genlevel_mask)
+{
+    // Any rune on the floor prevents the abyssal rune from being generated.
+    const bool placed_abyssal_rune =
+        find_floor_item(OBJ_MISCELLANY, MISC_RUNE_OF_ZOT);
+
+#ifdef DEBUG_ABYSS
+    dprf("_generate_area(). turns_on_level: %d, rune_on_floor: %s",
+         env.turns_on_level, placed_abyssal_rune? "yes" : "no");
+#endif
+
+    // Nuke map knowledge.
+    env.map_knowledge.init(map_cell());
+    _abyss_apply_terrain(abyss_genlevel_mask);
+
+    bool use_vaults = (you.char_direction == GDT_GAME_START ? false : true);
+
+    if (use_vaults)
+        _abyss_place_vaults(abyss_genlevel_mask);
+    _abyss_create_items(abyss_genlevel_mask, placed_abyssal_rune, use_vaults);
+    generate_random_blood_spatter_on_level(&abyss_genlevel_mask);
+    setup_environment_effects();
+
+    // Abyss has a constant density.
+    env.density = 0;
+}
+#endif
+
 void abyss_area_shift(void)
 {
 #ifdef DEBUG_ABYSS
-    mprf(MSGCH_DIAGNOSTICS, "area_shift() - player at pos (%d, %d)",
+    dprf("area_shift() - player at pos (%d, %d)",
          you.pos().x, you.pos().y);
 #endif
 
@@ -1003,7 +1320,11 @@ void abyss_area_shift(void)
         map_mask abyss_genlevel_mask;
         _abyss_shift_level_contents_around_player(
             ABYSS_AREA_SHIFT_RADIUS, ABYSS_CENTRE, abyss_genlevel_mask);
+#ifdef NEW_ABYSS
+        _generate_area(abyss_genlevel_mask);
+#else
         _generate_area(abyss_genlevel_mask, true);
+#endif
 
         // Update LOS at player's new abyssal vacation retreat.
         los_changed();
@@ -1015,23 +1336,22 @@ void abyss_area_shift(void)
     // And allow monsters in transit another chance to return.
     place_transiting_monsters();
     place_transiting_items();
-
-#ifdef WIZARD
-    // Update map, if already mapped.
-    if (!testbits(env.level_flags, LFLAG_NOT_MAPPABLE))
-        wizard_map_level();
-#endif
 }
 
-void save_abyss_uniques()
+#ifdef NEW_ABYSS
+void _initialize_abyss_state()
 {
-    for (monster_iterator mi; mi; ++mi)
-        if (mi->needs_abyss_transit())
-            mi->set_transit(level_id(LEVEL_ABYSS));
+    abyssal_state.major_coord.x = random2(0x7FFFFFFF);
+    abyssal_state.major_coord.y = random2(0x7FFFFFFF);
+    abyssal_state.depth = 0.0;
 }
+#endif
 
 static void _abyss_generate_new_area()
 {
+#ifdef NEW_ABYSS
+    _initialize_abyss_state();
+#endif
     remove_sanctuary(false);
 
     // Get new monsters and colours.
@@ -1047,12 +1367,16 @@ static void _abyss_generate_new_area()
 
     you.moveto(ABYSS_CENTRE);
     abyss_genlevel_mask.init(true);
+#ifdef NEW_ABYSS
+    _generate_area(abyss_genlevel_mask);
+#else
     _generate_area(abyss_genlevel_mask, true);
+#endif
     grd(you.pos()) = DNGN_FLOOR;
     if (one_chance_in(5))
     {
         _place_feature_near(you.pos(), LOS_RADIUS,
-                             DNGN_FLOOR, DNGN_ALTAR_LUGONU, 50);
+                            DNGN_FLOOR, DNGN_ALTAR_LUGONU, 50);
     }
 
     los_changed();
@@ -1060,6 +1384,101 @@ static void _abyss_generate_new_area()
     place_transiting_items();
 }
 
+#ifdef NEW_ABYSS
+// Generate the initial (proto) Abyss level. The proto Abyss is where
+// the player lands when they arrive in the Abyss from elsewhere.
+// _generate_area generates all other Abyss areas.
+void generate_abyss()
+{
+    env.level_build_method += " abyss";
+    env.level_layout_types.insert("abyss");
+
+    _initialize_abyss_state();
+
+    dprf("generate_abyss(); turn_on_level: %d", env.turns_on_level);
+
+    // Generate the initial abyss without vaults. Vaults are horrifying.
+    _abyss_generate_new_area();
+    _write_abyssal_features();
+
+    // If we're starting out in the Abyss, make sure the starting grid is
+    // an altar to Lugonu and there's an exit near-by.
+    // Otherwise, we start out on floor and there's a chance there's an
+    // altar near-by.
+    if (you.char_direction == GDT_GAME_START)
+    {
+        grd(ABYSS_CENTRE) = DNGN_ALTAR_LUGONU;
+        _place_feature_near(ABYSS_CENTRE, LOS_RADIUS + 2,
+                             DNGN_FLOOR, DNGN_EXIT_ABYSS, 50, true);
+    }
+    else
+    {
+        grd(ABYSS_CENTRE) = DNGN_FLOOR;
+        if (one_chance_in(5))
+        {
+            _place_feature_near(ABYSS_CENTRE, LOS_RADIUS,
+                                DNGN_FLOOR, DNGN_ALTAR_LUGONU, 50);
+        }
+    }
+
+    generate_random_blood_spatter_on_level();
+    setup_environment_effects();
+}
+
+void _mulch_vault_item(const coord_def &pos)
+{
+    int item_count = 0;
+    for (stack_iterator si(pos); si; ++si)
+    {
+        ++item_count;
+        if (si->defined() && (si->flags &= ~(ISFLAG_THROWN | ISFLAG_DROPPED)))
+        {
+            --item_count;
+            item_was_lost(*si);
+            si->clear();
+        }
+    }
+
+    if (!item_count)
+        igrd(pos) = NON_ITEM;
+}
+
+void _decay_vaults()
+{
+    for (rectangle_iterator ri(MAPGEN_BORDER); ri; ++ri)
+    {
+        if (map_masked(*ri, MMT_VAULT))
+        {
+            _mulch_vault_item(*ri);
+            env.level_map_mask(*ri) &= ~MMT_VAULT;
+        }
+    }
+}
+
+void abyss_maybe_decay_vaults()
+{
+    if (coinflip())
+        _decay_vaults();
+    else
+    {
+        push_features_to_abyss();
+        _abyss_generate_new_area();
+    }
+}
+
+void abyss_morph()
+{
+    abyssal_state.depth += 0.25;
+    map_mask abyss_genlevel_mask;
+    _abyss_invert_mask(&abyss_genlevel_mask);
+    dgn_erase_unused_vault_placements();
+    _abyss_apply_terrain(abyss_genlevel_mask, true);
+    _place_displaced_monsters();
+    los_changed();
+}
+
+#else
+
 static bool _abyss_teleport_within_level()
 {
     // Try to find a good spot within the shift zone.
@@ -1076,8 +1495,7 @@ static bool _abyss_teleport_within_level()
             && env.cgrid(newspot) == EMPTY_CLOUD)
         {
 #ifdef DEBUG_ABYSS
-            mprf(MSGCH_DIAGNOSTICS,
-                 "Abyss same-area teleport to (%d,%d).",
+            dprf("Abyss same-area teleport to (%d,%d).",
                  newspot.x, newspot.y);
 #endif
             you.moveto(newspot);
@@ -1086,6 +1504,7 @@ static bool _abyss_teleport_within_level()
     }
     return (false);
 }
+#endif
 
 void abyss_teleport(bool new_area)
 {
@@ -1095,7 +1514,7 @@ void abyss_teleport(bool new_area)
         return;
 
 #ifdef DEBUG_ABYSS
-    mpr("New area Abyss teleport.", MSGCH_DIAGNOSTICS);
+    dprf("New area Abyss teleport.");
 #endif
 
     // Teleport to a new area of the abyss.
@@ -1138,11 +1557,8 @@ static void _initialise_level_corrupt_seeds(int power)
         while (tries-- > 0)
         {
             where = dgn_random_point_from(you.pos(), aux_seed_radius, 2);
-            if (grd(where) == DNGN_FLOOR
-                && !env.markers.find(where, MAT_ANY))
-            {
+            if (grd(where) == DNGN_FLOOR && !env.markers.find(where, MAT_ANY))
                 break;
-            }
             where.reset();
         }
 
@@ -1171,7 +1587,7 @@ static bool _spawn_corrupted_servant_near(const coord_def &pos)
         const int offsetX = random2avg(4, 3) + random2(3);
         const int offsetY = random2avg(4, 3) + random2(3);
         const coord_def p(pos.x + (coinflip()? offsetX : -offsetX),
-                           pos.y + (coinflip()? offsetY : -offsetY));
+                          pos.y + (coinflip()? offsetY : -offsetY));
         if (!in_bounds(p) || actor_at(p)
             || !feat_compatible(DNGN_FLOOR, grd(p)))
         {
@@ -1437,7 +1853,7 @@ bool lugonu_corrupt_level(int power)
     _corrupt_level_features(cenv);
     run_corruption_effects(300);
 
-#ifndef USE_TILE
+#ifndef USE_TILE_LOCAL
     // Allow extra time for the flash to linger.
     delay(1000);
 #endif
