@@ -13,6 +13,17 @@
 const int ABYSS_AREA_SHIFT_RADIUS = LOS_RADIUS + 2;
 const coord_def ABYSS_CENTRE(GXM / 2, GYM / 2);
 
+#ifdef NEW_ABYSS
+struct abyss_state
+{
+    coord_def major_coord;
+    double depth;
+};
+void abyss_morph();
+void abyss_maybe_decay_vaults();
+void push_features_to_abyss();
+#endif
+
 void generate_abyss();
 void maybe_shift_abyss_around_player();
 void abyss_area_shift();
