@@ -1132,40 +1132,75 @@ static const species_skill_aptitude species_skill_aptitudes[] =
     APT(SP_DEEP_DWARF,      SK_INVOCATIONS,     2),
     APT(SP_DEEP_DWARF,      SK_EVOCATIONS,      3),
 
-    // SP_CAT
-    APT(SP_CAT,             SK_FIGHTING,       -2),
-    APT(SP_CAT,             SK_SHORT_BLADES,    0),
-    APT(SP_CAT,             SK_LONG_BLADES,     0),
-    APT(SP_CAT,             SK_AXES,            0),
-    APT(SP_CAT,             SK_MACES_FLAILS,    0),
-    APT(SP_CAT,             SK_POLEARMS,        0),
-    APT(SP_CAT,             SK_STAVES,          0),
-    APT(SP_CAT,             SK_SLINGS,          0),
-    APT(SP_CAT,             SK_BOWS,            0),
-    APT(SP_CAT,             SK_CROSSBOWS,       0),
-    APT(SP_CAT,             SK_THROWING,        0),
-    APT(SP_CAT,             SK_ARMOUR,          0),
-    APT(SP_CAT,             SK_DODGING,         2),
-    APT(SP_CAT,             SK_STEALTH,         2),
-    APT(SP_CAT,             SK_STABBING,        3),
-    APT(SP_CAT,             SK_SHIELDS,         0),
-    APT(SP_CAT,             SK_TRAPS_DOORS,     2),
-    APT(SP_CAT,             SK_UNARMED_COMBAT, -2),
-    APT(SP_CAT,             SK_SPELLCASTING,    0),
-    APT(SP_CAT,             SK_CONJURATIONS,   -1),
-    APT(SP_CAT,             SK_HEXES,           3),
-    APT(SP_CAT,             SK_CHARMS,          2),
-    APT(SP_CAT,             SK_SUMMONINGS,      1),
-    APT(SP_CAT,             SK_NECROMANCY,      0),
-    APT(SP_CAT,             SK_TRANSLOCATIONS,  2),
-    APT(SP_CAT,             SK_TRANSMUTATIONS,  1),
-    APT(SP_CAT,             SK_FIRE_MAGIC,     -1),
-    APT(SP_CAT,             SK_ICE_MAGIC,      -2),
-    APT(SP_CAT,             SK_AIR_MAGIC,      -1),
-    APT(SP_CAT,             SK_EARTH_MAGIC,    -2),
-    APT(SP_CAT,             SK_POISON_MAGIC,   -1),
-    APT(SP_CAT,             SK_INVOCATIONS,    -1),
-    APT(SP_CAT,             SK_EVOCATIONS,     -2),
+    // SP_FELID
+    APT(SP_FELID,           SK_FIGHTING,       -1),
+    APT(SP_FELID,           SK_SHORT_BLADES,    0),
+    APT(SP_FELID,           SK_LONG_BLADES,     0),
+    APT(SP_FELID,           SK_AXES,            0),
+    APT(SP_FELID,           SK_MACES_FLAILS,    0),
+    APT(SP_FELID,           SK_POLEARMS,        0),
+    APT(SP_FELID,           SK_STAVES,          0),
+    APT(SP_FELID,           SK_SLINGS,          0),
+    APT(SP_FELID,           SK_BOWS,            0),
+    APT(SP_FELID,           SK_CROSSBOWS,       0),
+    APT(SP_FELID,           SK_THROWING,        0),
+    APT(SP_FELID,           SK_ARMOUR,          0),
+    APT(SP_FELID,           SK_DODGING,         3),
+    APT(SP_FELID,           SK_STEALTH,         3),
+    APT(SP_FELID,           SK_STABBING,        3),
+    APT(SP_FELID,           SK_SHIELDS,         0),
+    APT(SP_FELID,           SK_TRAPS_DOORS,     2),
+    APT(SP_FELID,           SK_UNARMED_COMBAT, -1),
+    APT(SP_FELID,           SK_SPELLCASTING,    0),
+    APT(SP_FELID,           SK_CONJURATIONS,   -1),
+    APT(SP_FELID,           SK_HEXES,           4),
+    APT(SP_FELID,           SK_CHARMS,          2),
+    APT(SP_FELID,           SK_SUMMONINGS,      1),
+    APT(SP_FELID,           SK_NECROMANCY,      0),
+    APT(SP_FELID,           SK_TRANSLOCATIONS,  4),
+    APT(SP_FELID,           SK_TRANSMUTATIONS,  1),
+    APT(SP_FELID,           SK_FIRE_MAGIC,     -1),
+    APT(SP_FELID,           SK_ICE_MAGIC,      -2),
+    APT(SP_FELID,           SK_AIR_MAGIC,      -1),
+    APT(SP_FELID,           SK_EARTH_MAGIC,    -2),
+    APT(SP_FELID,           SK_POISON_MAGIC,   -1),
+    APT(SP_FELID,           SK_INVOCATIONS,    -1),
+    APT(SP_FELID,           SK_EVOCATIONS,     -2),
+
+    // SP_OCTOPODE
+    APT(SP_OCTOPODE,        SK_FIGHTING,        0),
+    APT(SP_OCTOPODE,        SK_SHORT_BLADES,    0),
+    APT(SP_OCTOPODE,        SK_LONG_BLADES,     0),
+    APT(SP_OCTOPODE,        SK_AXES,            0),
+    APT(SP_OCTOPODE,        SK_MACES_FLAILS,    0),
+    APT(SP_OCTOPODE,        SK_POLEARMS,        0),
+    APT(SP_OCTOPODE,        SK_STAVES,          0),
+    APT(SP_OCTOPODE,        SK_SLINGS,          0),
+    APT(SP_OCTOPODE,        SK_BOWS,            0),
+    APT(SP_OCTOPODE,        SK_CROSSBOWS,       0),
+    APT(SP_OCTOPODE,        SK_THROWING,        0),
+    APT(SP_OCTOPODE,        SK_ARMOUR,         -4),
+    APT(SP_OCTOPODE,        SK_DODGING,         0),
+    APT(SP_OCTOPODE,        SK_STEALTH,         3),
+    APT(SP_OCTOPODE,        SK_STABBING,        0),
+    APT(SP_OCTOPODE,        SK_SHIELDS,         0),
+    APT(SP_OCTOPODE,        SK_TRAPS_DOORS,     1),
+    APT(SP_OCTOPODE,        SK_UNARMED_COMBAT,  0),
+    APT(SP_OCTOPODE,        SK_SPELLCASTING,    0),
+    APT(SP_OCTOPODE,        SK_CONJURATIONS,    0),
+    APT(SP_OCTOPODE,        SK_HEXES,           0),
+    APT(SP_OCTOPODE,        SK_CHARMS,          0),
+    APT(SP_OCTOPODE,        SK_SUMMONINGS,      0),
+    APT(SP_OCTOPODE,        SK_NECROMANCY,      0),
+    APT(SP_OCTOPODE,        SK_TRANSLOCATIONS,  0),
+    APT(SP_OCTOPODE,        SK_TRANSMUTATIONS,  0),
+    APT(SP_OCTOPODE,        SK_FIRE_MAGIC,      0),
+    APT(SP_OCTOPODE,        SK_ICE_MAGIC,       0),
+    APT(SP_OCTOPODE,        SK_AIR_MAGIC,       0),
+    APT(SP_OCTOPODE,        SK_EARTH_MAGIC,     0),
+    APT(SP_OCTOPODE,        SK_POISON_MAGIC,    2),
+    APT(SP_OCTOPODE,        SK_INVOCATIONS,     0),
+    APT(SP_OCTOPODE,        SK_EVOCATIONS,      1),
 };
 
 #endif
