@@ -30,15 +30,11 @@
 #include "player.h"
 #include "random.h"
 #include "religion.h"
+#include "shout.h"
 #include "species.h"
 #include "spl-book.h"
 #include "stuff.h"
 #include "view.h" // Elemental colours for unrandarts
-#include "shout.h"
-
-// The initial generation of a randart is very simple - it occurs in
-// dungeon.cc and consists of giving it a few random things - plus &
-// plus2 mainly.
 
 static bool _god_fits_artefact(const god_type which_god, const item_def &item,
                                bool name_check_only = false)
@@ -88,9 +84,11 @@ static bool _god_fits_artefact(const god_type which_god, const item_def &item,
         if (item.base_type == OBJ_BOOKS)
             type_bad = true;
 
-        if (item.base_type == OBJ_JEWELLERY && (item.sub_type == RING_WIZARDRY
-            || item.sub_type == RING_FIRE || item.sub_type == RING_ICE
-            || item.sub_type == RING_MAGICAL_POWER))
+        if (item.base_type == OBJ_JEWELLERY
+            && (item.sub_type == RING_WIZARDRY
+             || item.sub_type == RING_FIRE
+             || item.sub_type == RING_ICE
+             || item.sub_type == RING_MAGICAL_POWER))
         {
             type_bad = true;
         }
@@ -124,8 +122,10 @@ static bool _god_fits_artefact(const god_type which_god, const item_def &item,
     if (is_evil_god(which_god) && brand == SPWPN_HOLY_WRATH)
         return (false);
     else if (is_good_god(which_god)
-             && (brand == SPWPN_DRAINING || brand == SPWPN_PAIN
-                 || brand == SPWPN_VAMPIRICISM || brand == SPWPN_REAPING
+             && (brand == SPWPN_DRAINING
+                 || brand == SPWPN_PAIN
+                 || brand == SPWPN_VAMPIRICISM
+                 || brand == SPWPN_REAPING
                  || brand == SPWPN_CHAOS
                  || is_demonic(item)
                  || artefact_wpn_property(item, ARTP_CURSED) != 0))
@@ -216,6 +216,12 @@ static bool _god_fits_artefact(const god_type which_god, const item_def &item,
         }
         break;
 
+    case GOD_ASHENZARI:
+        // Cursed god: no holy wrath (since that brand repels curses).
+        if (brand == SPWPN_HOLY_WRATH)
+            return (false);
+        break;
+
     default:
         break;
     }
@@ -223,7 +229,7 @@ static bool _god_fits_artefact(const god_type which_god, const item_def &item,
     return (true);
 }
 
-std::string replace_name_parts(const std::string name_in, const item_def& item)
+std::string replace_name_parts(const std::string &name_in, const item_def& item)
 {
     std::string name = name_in;
 
@@ -310,7 +316,7 @@ std::string replace_name_parts(const std::string name_in, const item_def& item)
         else
         {
             do
-                which_god = static_cast<god_type>(random2(NUM_GODS - 1) + 1);
+                which_god = random_god(true);
             while (!_god_fits_artefact(which_god, item, true));
         }
 
@@ -368,6 +374,13 @@ bool is_special_unrandom_artefact(const item_def &item)
             && (_seekunrandart(item)->flags & UNRAND_FLAG_SPECIAL));
 }
 
+bool is_randapp_artefact(const item_def &item)
+{
+    return (item.flags & ISFLAG_UNRANDART
+            && !(item.flags & ISFLAG_KNOW_TYPE)
+            && (_seekunrandart(item)->flags & UNRAND_FLAG_RANDAPP));
+}
+
 unique_item_status_type get_unique_item_status(const item_def& item)
 {
     if (item.flags & ISFLAG_UNRANDART)
@@ -395,9 +408,14 @@ void set_unique_item_status(int art, unique_item_status_type status)
     you.unique_items[art - UNRAND_START] = status;
 }
 
-static uint32_t _calc_seed(const item_def &item)
+void reveal_randapp_artefact(item_def &item)
 {
-    return (item.special & RANDART_SEED_MASK);
+    ASSERT(is_unrandom_artefact(item));
+    const unrandart_entry *unrand = _seekunrandart(item);
+    ASSERT(unrand);
+    ASSERT(unrand->flags & UNRAND_FLAG_RANDAPP);
+    // name and tile update themselves
+    item.colour = unrand->colour;
 }
 
 void artefact_desc_properties(const item_def &item,
@@ -411,6 +429,14 @@ void artefact_desc_properties(const item_def &item,
 
     artefact_wpn_properties(item, proprt, known);
 
+    if (item.base_type == OBJ_ARMOUR
+        && item.sub_type == ARM_GOLD_DRAGON_ARMOUR)
+    {
+        ++proprt[ARTP_POISON];
+        ++proprt[ARTP_FIRE];
+        ++proprt[ARTP_COLD];
+    }
+
     if (!force_fake_props && item_ident(item, ISFLAG_KNOW_PROPERTIES))
         return;
 
@@ -678,12 +704,8 @@ void static _get_randart_properties(const item_def &item,
     const int atype = item.sub_type;
     int power_level = 0;
 
-    const uint32_t seed = _calc_seed(item);
-    rng_save_excursion exc;
-    seed_rng(seed);
-
     if (aclass == OBJ_ARMOUR)
-        power_level = item.plus / 2 + 2;
+        power_level = item.plus * 2 / (armour_max_enchant(item) + 2) + 2;
     else if (aclass == OBJ_JEWELLERY)
         power_level = 1 + random2(3) + random2(2);
     else // OBJ_WEAPON
@@ -1277,9 +1299,7 @@ void artefact_wpn_properties(const item_def &item,
             proprt[i] = static_cast<short>(unrand->prpty[i]);
     }
     else
-    {
         _get_randart_properties(item, proprt);
-    }
 }
 
 
@@ -1366,6 +1386,10 @@ static std::string _get_artefact_type(const item_def &item,
     case OBJ_WEAPONS:
         return "weapon";
     case OBJ_ARMOUR:
+        if (item.sub_type == ARM_ROBE)
+            return "robe";
+        if (get_item_slot(item) == EQ_BODY_ARMOUR)
+            return "body armour";
         return "armour";
     case OBJ_JEWELLERY:
         // Distinguish between amulets and rings only in appearance.
@@ -1410,7 +1434,7 @@ static bool _artefact_name_lookup(std::string &result,
     return (!result.empty());
 }
 
-std::string artefact_name(const item_def &item, bool appearance)
+std::string make_artefact_name(const item_def &item, bool appearance)
 {
     ASSERT(is_artefact(item));
 
@@ -1422,11 +1446,12 @@ std::string artefact_name(const item_def &item, bool appearance)
     if (is_unrandom_artefact(item))
     {
         const unrandart_entry *unrand = _seekunrandart(item);
-        return (item_type_known(item) ? unrand->name : unrand->unid_name);
+        if (item_type_known(item))
+            return unrand->name;
+        if (!(unrand->flags & UNRAND_FLAG_RANDAPP))
+            return unrand->unid_name;
     }
 
-    const uint32_t seed = _calc_seed(item);
-
     std::string lookup;
     std::string result;
 
@@ -1453,9 +1478,6 @@ std::string artefact_name(const item_def &item, bool appearance)
     // get base type
     lookup += _get_artefact_type(item, appearance);
 
-    rng_save_excursion rng_state;
-    seed_rng(seed);
-
     if (appearance)
     {
         std::string appear = getRandNameString(lookup, " appearance");
@@ -1530,12 +1552,12 @@ std::string get_artefact_name(const item_def &item, bool force_known)
         // print artefact's real name
         if (item.props.exists(ARTEFACT_NAME_KEY))
             return item.props[ARTEFACT_NAME_KEY].get_string();
-        return artefact_name(item, false);
+        return make_artefact_name(item, false);
     }
     // print artefact appearance
     if (item.props.exists(ARTEFACT_APPEAR_KEY))
         return item.props[ARTEFACT_APPEAR_KEY].get_string();
-    return artefact_name(item, false);
+    return make_artefact_name(item, false);
 }
 
 void set_artefact_name(item_def &item, const std::string &name)
@@ -1904,12 +1926,10 @@ bool make_item_randart(item_def &item, bool force_mundane)
     int randart_tries = 500;
     do
     {
-        item.special = (random_int() & RANDART_SEED_MASK);
         // Now that we found something, initialise the props array.
         if (--randart_tries <= 0 || !_init_artefact_properties(item))
         {
-            // Something went wrong that no amount of changing
-            // item.special will fix.
+            // Something went wrong that no amount of rerolling will fix.
             item.special = 0;
             item.props.erase(ARTEFACT_PROPS_KEY);
             item.props.erase(KNOWN_PROPS_KEY);
@@ -1924,14 +1944,14 @@ bool make_item_randart(item_def &item, bool force_mundane)
     if (item.props.exists(ARTEFACT_NAME_KEY))
         ASSERT(item.props[ARTEFACT_NAME_KEY].get_type() == SV_STR);
     else
-        set_artefact_name(item, artefact_name(item, false));
+        set_artefact_name(item, make_artefact_name(item, false));
 
     // get artefact appearance
     if (item.props.exists(ARTEFACT_APPEAR_KEY))
         ASSERT(item.props[ARTEFACT_APPEAR_KEY].get_type() == SV_STR);
     else
         item.props[ARTEFACT_APPEAR_KEY].get_string() =
-            artefact_name(item, true);
+            make_artefact_name(item, true);
 
     return (true);
 }
@@ -2000,7 +2020,13 @@ bool make_item_unrandart(item_def &item, int unrand_index)
 
     // get artefact appearance
     ASSERT(!item.props.exists(ARTEFACT_APPEAR_KEY));
-    item.props[ARTEFACT_APPEAR_KEY].get_string() = unrand->unid_name;
+    if (!(unrand->flags & UNRAND_FLAG_RANDAPP))
+        item.props[ARTEFACT_APPEAR_KEY].get_string() = unrand->unid_name;
+    else
+    {
+        item.props[ARTEFACT_APPEAR_KEY].get_string() = make_artefact_name(item, true);
+        item_colour(item);
+    }
 
     set_unique_item_status(unrand_index, UNIQ_EXISTS);
 
@@ -2027,6 +2053,27 @@ const char *unrandart_descrip(int which_descrip, const item_def &item)
                                  : "Unknown.");
 }
 
+void unrand_reacts()
+{
+    item_def*  weapon     = you.weapon();
+    const int  old_plus   = weapon ? weapon->plus   : 0;
+    const int  old_plus2  = weapon ? weapon->plus2  : 0;
+
+    for (int i = 0; i < NUM_EQUIP; i++)
+    {
+        if (you.unrand_reacts & (1 << i))
+        {
+            item_def&        item  = you.inv[you.equip[i]];
+            unrandart_entry* entry = get_unrand_entry(item.special);
+
+            entry->world_reacts_func(&item);
+        }
+    }
+
+    if (weapon && (old_plus != weapon->plus || old_plus2 != weapon->plus2))
+        you.wield_change = true;
+}
+
 // Set all non-zero properties in proprt on the randart supplied.
 static void _artefact_merge_properties(item_def &item,
                                        const artefact_properties_t &proprt)
@@ -2087,17 +2134,17 @@ void cheibriados_make_item_ponderous(item_def &item)
 }
 
 template<typename Z>
-static inline void artefact_pad_store_vector(CrawlVector &vector, Z value)
+static inline void artefact_pad_store_vector(CrawlVector &vec, Z value)
 {
-    if (vector.get_max_size() < ART_PROPERTIES)
+    if (vec.get_max_size() < ART_PROPERTIES)
     {
         // Authentic tribal dance to propitiate the asserts in store.cc:
-        const int old_size = vector.get_max_size();
-        vector.set_max_size(VEC_MAX_SIZE);
-        vector.resize(ART_PROPERTIES);
-        vector.set_max_size(ART_PROPERTIES);
+        const int old_size = vec.get_max_size();
+        vec.set_max_size(VEC_MAX_SIZE);
+        vec.resize(ART_PROPERTIES);
+        vec.set_max_size(ART_PROPERTIES);
         for (int i = old_size; i < ART_PROPERTIES; ++i)
-            vector[i] = value;
+            vec[i] = value;
     }
 }
 
