@@ -11,6 +11,7 @@
 #include "externs.h"
 #include "random.h"
 #include "ray.h"
+#include "spl-cast.h"
 
 class monster;
 
@@ -138,6 +139,7 @@ struct bolt
     bool        can_see_invis;   // tracer firer can see invisible?
     mon_attitude_type attitude;  // attitude of whoever fired tracer
     int         foe_ratio;       // 100* foe ratio (see mons_should_fire())
+    std::map<mid_t, int> hit_count; // how many times targets were affected
 
     tracer_info foe_info;
     tracer_info friend_info;
@@ -304,10 +306,11 @@ int mons_adjust_flavoured(monster* mons, bolt &pbolt, int hurted,
 bool enchant_monster_with_flavour(monster* mon, actor *atk,
                                   beam_type flavour, int powc = 0);
 
-bool enchant_monster_invisible(monster* mon, const std::string how);
+bool enchant_monster_invisible(monster* mon, const std::string &how);
 
-void mass_enchantment(enchant_type wh_enchant, int pow,
-                       int *m_succumbed = NULL, int *m_attempted = NULL);
+spret_type mass_enchantment(enchant_type wh_enchant, int pow,
+                            int *m_succumbed = NULL, int *m_attempted = NULL,
+                            bool fail = false);
 
 bool poison_monster(monster* mons, const actor* who, int levels = 1,
                     bool force = false, bool verbose = true);
@@ -317,8 +320,9 @@ bool napalm_monster(monster* mons, const actor* who, int levels = 1,
 void fire_tracer(const monster* mons, struct bolt &pbolt,
                   bool explode_only = false);
 void mimic_alert(monster* mimic);
-bool zapping(zap_type ztype, int power, bolt &pbolt,
-             bool needs_tracer = false, const char* msg = NULL);
+spret_type zapping(zap_type ztype, int power, bolt &pbolt,
+                   bool needs_tracer = false, const char* msg = NULL,
+                   bool fail = false);
 bool player_tracer(zap_type ztype, int power, bolt &pbolt, int range = 0);
 
 void init_zap_index();
