@@ -15,7 +15,8 @@ Branch& your_branch()
 
 bool at_branch_bottom()
 {
-    return your_branch().depth == player_branch_depth();
+    return your_branch().depth == player_branch_depth()
+           && you.level_type == LEVEL_DUNGEON;
 }
 
 level_id branch_entry_level(branch_type branch)
@@ -85,7 +86,8 @@ branch_type str_to_branch(const std::string &branch, branch_type err)
 
 int current_level_ambient_noise()
 {
-    switch (you.level_type) {
+    switch (you.level_type)
+    {
     case LEVEL_DUNGEON:
         return branches[you.where_are_you].ambient_noise;
     case LEVEL_ABYSS:
