@@ -50,7 +50,6 @@
 #include "spl-util.h"
 #include "stash.h"
 #include "state.h"
-#include "stuff.h"
 #include "env.h"
 #include "transform.h"
 #include "travel.h"
@@ -371,13 +370,21 @@ static void _sdump_visits(dump_params &par)
 
         if (num_zigs > 0)
         {
-            text += make_stringf("You %svisited %d Ziggurat",
-                                 have.c_str(), num_zigs);
+            text += make_stringf("You %s%s %d Ziggurat",
+                                 have.c_str(),
+                                 (num_zigs == you.zigs_completed) ? "completed"
+                                                                  : "visited",
+                                 num_zigs);
             if (num_zigs > 1)
                 text += "s";
-            text += make_stringf(", and %s %d of %s levels.\n",
+            if (num_zigs != you.zigs_completed && you.zigs_completed)
+                text += make_stringf(" (completing %d)", you.zigs_completed);
+            text += make_stringf(", and %s %d of %s levels",
                                  seen.c_str(), zig_levels,
                                  num_zigs > 1 ? "their" : "its");
+            if (num_zigs != 1 && !you.zigs_completed)
+                text += make_stringf(" (deepest: %d)", you.zig_max);
+            text += ".\n";
         }
 
         if (!misc_portals.empty())
@@ -745,11 +752,10 @@ static void _sdump_inventory(dump_params &par)
     std::string &text(par.text);
     std::string text2;
 
-    int inv_class2[OBJ_GOLD];
+    int inv_class2[NUM_OBJECT_CLASSES];
     int inv_count = 0;
-    char tmp_quant[20];
 
-    for (i = 0; i < OBJ_GOLD; i++)
+    for (i = 0; i < NUM_OBJECT_CLASSES; i++)
         inv_class2[i] = 0;
 
     for (i = 0; i < ENDOFPACK; i++)
@@ -771,7 +777,7 @@ static void _sdump_inventory(dump_params &par)
     {
         text += "Inventory:\n\n";
 
-        for (i = 0; i < OBJ_GOLD; i++)
+        for (i = 0; i < NUM_OBJECT_CLASSES; i++)
         {
             if (inv_class2[i] != 0)
             {
@@ -808,13 +814,8 @@ static void _sdump_inventory(dump_params &par)
                         int ival = -1;
                         if (par.show_prices)
                         {
-                            text += " (";
-
-                            itoa(ival = item_value(you.inv[j], true),
-                                  tmp_quant, 10);
-
-                            text += tmp_quant;
-                            text += " gold)";
+                            text += make_stringf(" (%d gold)",
+                                        ival = item_value(you.inv[j], true));
                         }
 
                         if (origin_describable(you.inv[j])
@@ -853,21 +854,8 @@ static void _sdump_inventory(dump_params &par)
 static void _sdump_skills(dump_params &par)
 {
     std::string &text(par.text);
-    char tmp_quant[20];
 
-    if (par.se)
-        text += " You had ";
-    else
-        text += " You have ";
-
-    itoa(you.exp_available, tmp_quant, 10);
-    text += tmp_quant;
-    text += " experience left.";
-
-    text += "\n";
-    text += "\n";
-    text += "   Skills:";
-    text += "\n";
+    text += "   Skills:\n";
 
     dump_skills(text);
     text += "\n";
@@ -899,7 +887,6 @@ static std::string spell_type_shortname(int spell_class, bool slash)
 static void _sdump_spells(dump_params &par)
 {
     std::string &text(par.text);
-    char tmp_quant[20];
 
 // This array helps output the spell types in the traditional order.
 // this can be tossed as soon as I reorder the enum to the traditional order {dlb}
@@ -940,9 +927,7 @@ static void _sdump_spells(dump_params &par)
             text += "You had ";
         else
             text += "You have ";
-        itoa(spell_levels, tmp_quant, 10);
-        text += tmp_quant;
-        text += " spell levels left.";
+        text += make_stringf("%d spell levels left.", spell_levels);
     }
 
     text += "\n";
@@ -999,10 +984,7 @@ static void _sdump_spells(dump_params &par)
 
                 spell_line = chop_string(spell_line, 66);
 
-                itoa(spell_difficulty(spell), tmp_quant, 10);
-                spell_line += tmp_quant;
-
-                spell_line = chop_string(spell_line, 71);
+                spell_line += make_stringf("%-5d", spell_difficulty(spell));
 
                 spell_line += spell_hunger_string(spell);
                 spell_line += "\n";
@@ -1284,9 +1266,7 @@ static bool _write_dump(const std::string &fname, dump_params &par,
     file_name += ".txt";
     FILE *handle = fopen_replace(file_name.c_str());
 
-#ifdef DEBUG_DIAGNOSTICS
-    mprf(MSGCH_DIAGNOSTICS, "File name: %s", file_name.c_str());
-#endif
+    dprf("File name: %s", file_name.c_str());
 
     if (handle != NULL)
     {
@@ -1324,9 +1304,7 @@ void display_notes()
         if (spaceleft <= 0)
             return;
 
-        // Use smarter linebreak function.
-        // was:  linebreak_string(suffix, spaceleft - 4, spaceleft);
-        linebreak_string2(suffix, spaceleft);
+        linebreak_string(suffix, spaceleft);
         std::vector<std::string> parts = split_string("\n", suffix);
         if (parts.empty()) // Disregard pure-whitespace notes.
             continue;
