@@ -1,8 +1,7 @@
-/*
- *  File:       chardump.h
- *  Summary:    Dumps character info out to the morgue file.
- *  Written by: Linley Henzell
- */
+/**
+ * @file
+ * @brief Dumps character info out to the morgue file.
+**/
 
 
 #ifndef CHARDUMP_H
@@ -22,10 +21,11 @@ enum item_origin_dump_selector
     IODS_RODS             = 32,
     IODS_STAVES           = 64,
     IODS_BOOKS            = 128,
-    IODS_EVERYTHING       = 0xFF
+    IODS_EVERYTHING       = 0xFF,
 };
 
-struct scorefile_entry;
+class scorefile_entry;
+std::string morgue_directory();
 bool dump_char(const std::string &fname,
                bool show_prices,
                bool full_id = false,
@@ -33,11 +33,13 @@ bool dump_char(const std::string &fname,
 void dump_map(const char* fname, bool debug = false, bool dist = false);
 void dump_map(FILE *fp, bool debug = false, bool dist = false);
 void display_notes();
-std::string munge_description(const std::string &inStr);
+std::string munge_description(std::string inStr);
 const char *hunger_level(void);
 
 #ifdef DGL_WHEREIS
 void whereis_record(const char *status = "active");
 #endif
 
+void record_turn_timestamp();
+
 #endif
