@@ -48,8 +48,7 @@ int m_getch();
 int unmangle_direction_keys(int keyin, KeymapContext keymap = KMC_DEFAULT,
                             bool fake_ctrl = true, bool fake_shift = true);
 
-int nowrapcprintf(int wrapcol, const char *s, ...);
-int nowrap_eol_cprintf(const char *s, ...);
+void nowrap_eol_cprintf(const char *s, ...);
 
 // Returns zero if user entered text and pressed Enter, otherwise returns the
 // key pressed that caused the exit, usually Escape.
@@ -208,7 +207,8 @@ public:
         enable_smart_cursor(false);
         set_cursor_enabled(cursor_enabled);
     }
-    ~cursor_control() {
+    ~cursor_control()
+    {
         set_cursor_enabled(cstate);
         enable_smart_cursor(smartcstate);
     }
