@@ -116,7 +116,8 @@ static int _randomized_element_colour(int rand, const coord_def&,
     int accum = 0;
     for (random_colour_map::const_iterator it = rand_vals.begin();
          it != rand_vals.end();
-         ++it) {
+         ++it)
+    {
         if ((accum += it->first) > rand)
             return it->second;
     }
@@ -134,14 +135,6 @@ static int _etc_rock(int, const coord_def& loc)
     return element_colour(env.rock_colour, false, loc);
 }
 
-static int _etc_stone(int, const coord_def& loc)
-{
-    if (player_in_branch(BRANCH_HALL_OF_ZOT))
-        return element_colour(env.rock_colour, false, loc);
-    else
-        return LIGHTGREY;
-}
-
 static int _etc_elven_brick(int, const coord_def& loc)
 {
     if ((loc.x + loc.y) % 2)
@@ -227,7 +220,7 @@ bool get_tornado_phase(const coord_def& loc)
         int y = loc.y - center.y;
         double dir = atan2(x, y)/PI;
         double dist = sqrt(x*x + y*y);
-        return ((int)floor(dir*2 + dist*0.33 + (you.frame_no % 54)/2.7))&1;
+        return ((int)floor(dir*2 + dist*0.33 - (you.frame_no % 54)/2.7))&1;
     }
 }
 
@@ -364,18 +357,20 @@ void init_element_colours()
                             80,  DARKGREY,
                             40,  LIGHTGREY,
                         0));
-    // assassin
+    // assassin, necromancer
     add_element_colour(_create_random_element_colour_calc(
                             ETC_DEATH, "death",
                             80,  DARKGREY,
                             40,  MAGENTA,
                         0));
+#if TAG_MAJOR_VERSION == 32
     // necromancer
     add_element_colour(_create_random_element_colour_calc(
                             ETC_NECRO, "necro",
                             80,  DARKGREY,
                             40,  MAGENTA,
                         0));
+#endif
     // ie demonology
     add_element_colour(_create_random_element_colour_calc(
                             ETC_UNHOLY, "unholy",
@@ -454,7 +449,7 @@ void init_element_colours()
                             20,  MAGENTA,
                         0));
     add_element_colour(_create_random_element_colour_calc(
-                            ETC_GILA, "gila",
+                            ETC_FLASH, "flash",
                             30,  LIGHTMAGENTA,
                             30,  MAGENTA,
                             30,  YELLOW,
@@ -478,9 +473,12 @@ void init_element_colours()
     add_element_colour(new element_colour_calc(
                             ETC_ROCK, "rock", _etc_rock
                        ));
-    add_element_colour(new element_colour_calc(
-                            ETC_STONE, "stone", _etc_stone
-                       ));
+#if TAG_MAJOR_VERSION == 32
+    add_element_colour(_create_random_element_colour_calc(
+                            ETC_STONE, "stone",
+                            1,  LIGHTGREY,
+                        0));
+#endif
     add_element_colour(_create_random_element_colour_calc(
                             ETC_MIST, "mist",
                             100, CYAN,
@@ -667,7 +665,7 @@ int str_to_colour(const std::string &str, int default_colour,
     return ((ret == 16) ? default_colour : ret);
 }
 
-#if defined(TARGET_OS_WINDOWS) || defined(TARGET_OS_DOS) || defined(USE_TILE)
+#if defined(TARGET_OS_WINDOWS) || defined(USE_TILE)
 static unsigned short _dos_reverse_brand(unsigned short colour)
 {
     if (Options.dos_use_background_intensity)
@@ -743,7 +741,7 @@ unsigned short dos_brand(unsigned short colour,
 }
 #endif
 
-#if defined(TARGET_OS_WINDOWS) || defined(TARGET_OS_DOS) || defined(USE_TILE)
+#if defined(TARGET_OS_WINDOWS) || defined(USE_TILE)
 static unsigned _colflag2brand(int colflag)
 {
     switch (colflag)
@@ -779,7 +777,7 @@ unsigned real_colour(unsigned raw_colour, const coord_def& loc)
     if (is_element_colour(raw_colour))
         raw_colour = colflags | element_colour(raw_colour, false, loc);
 
-#if defined(TARGET_OS_WINDOWS) || defined(TARGET_OS_DOS) || defined(USE_TILE)
+#if defined(TARGET_OS_WINDOWS) || defined(USE_TILE)
     if (colflags)
     {
         unsigned brand = _colflag2brand(colflags);
