@@ -37,7 +37,7 @@
 #include "hiscores.h"
 #include "zotdef.h"
 
-#if defined(USE_TILE) && (defined(TARGET_OS_WINDOWS) || defined(TARGET_COMPILER_MINGW))
+#if defined(USE_TILE_LOCAL) && (defined(TARGET_OS_WINDOWS) || defined(TARGET_COMPILER_MINGW))
 #define NOCOMM            /* Comm driver APIs and definitions */
 #define NOLOGERROR        /* LogError() and related definitions */
 #define NOPROFILER        /* Profiler APIs */
@@ -140,11 +140,11 @@ static void _dump_player(FILE *file)
     fprintf(file, "Job:        %s\n\n", get_job_name(you.char_class));
     fprintf(file, "class_name: %s\n\n", you.class_name.c_str());
 
-    fprintf(file, "HP: %d/%d; base: %d/%d\n", you.hp, you.hp_max,
-            you.base_hp, you.base_hp2);
-    fprintf(file, "MP: %d/%d; base: %d/%d\n",
+    fprintf(file, "HP: %d/%d; mods: %d/%d\n", you.hp, you.hp_max,
+            you.hp_max_temp, you.hp_max_perm);
+    fprintf(file, "MP: %d/%d; mods: %d/%d\n",
             you.magic_points, you.max_magic_points,
-            you.base_magic_points, you.base_magic_points2);
+            you.hp_max_temp, you.mp_max_perm);
     fprintf(file, "Stats: %d (%d) %d (%d) %d (%d)\n",
             you.strength(), you.max_strength(), you.intel(), you.max_intel(),
             you.dex(), you.max_dex());
@@ -172,7 +172,7 @@ static void _dump_player(FILE *file)
                 debug_coord_str(you.running.pos).c_str());
     }
 
-    if (you.delay_queue.size() > 0)
+    if (!you.delay_queue.empty())
     {
         fprintf(file, "Delayed (%u):\n",
                 (unsigned int)you.delay_queue.size());
@@ -470,7 +470,7 @@ static void _debug_dump_lua_markers(FILE *file)
 
         std::string result = lua_marker->debug_to_string();
 
-        if (result.size() > 0 && result[result.size() - 1] == '\n')
+        if (!result.empty() && result[result.size() - 1] == '\n')
             result = result.substr(0, result.size() - 1);
 
         fprintf(file, "Lua marker %d at (%d, %d):\n",
@@ -516,8 +516,10 @@ static void _dump_ver_stuff(FILE* file)
     fprintf(file, "Game mode: %s\n",
             gametype_to_str(crawl_state.type).c_str());
 
-#ifdef USE_TILE
+#if defined(USE_TILE_LOCAL)
     fprintf(file, "Tiles: yes\n\n");
+#elif defined(USE_TILE_WEB)
+    fprintf(file, "Tiles: online\n\n");
 #else
     fprintf(file, "Tiles: no\n\n");
 #endif
@@ -697,12 +699,12 @@ void do_crash_dump()
 //---------------------------------------------------------------
 static NORETURN void _BreakStrToDebugger(const char *mesg, bool assert)
 {
-#if defined(USE_TILE) && (defined(TARGET_COMPILER_MINGW) || defined(TARGET_OS_WINDOWS))
+#if defined(USE_TILE_LOCAL) && (defined(TARGET_COMPILER_MINGW) || defined(TARGET_OS_WINDOWS))
     SDL_SysWMinfo SysInfo;
     SDL_VERSION(&SysInfo.version);
     if (SDL_GetWMInfo(&SysInfo) > 0)
     {
-        MessageBoxW(SysInfo.window, utf8_to_16(mesg).c_str(),
+        MessageBoxW(SysInfo.window, OUTW(mesg),
                    assert ? L"Assertion failed!" : L"Error",
                    MB_OK|MB_ICONERROR);
     }
