@@ -30,7 +30,6 @@
 #include "religion.h"
 #include "shopping.h"
 #include "state.h"
-#include "stuff.h"
 #include "tagstring.h"
 #include "terrain.h"
 #include "travel.h"
@@ -552,10 +551,17 @@ static std::string _print_altars_for_gods(const std::vector<god_type>& gods,
             colour = "white";
         if (you.penance[god])
             colour = (you.penance[god] > 10) ? "red" : "lightred";
+        else if (you.religion == god)
+            colour = "yellow";
+        else if (god_likes_your_god(god))
+            colour = "brown";
 
         if (!print_unseen && !strcmp(colour, "darkgrey"))
             continue;
 
+        if (is_unavailable_god(god))
+            colour = you.worshipped[god] ? "magenta" : "darkgrey";
+
         snprintf(buffer, sizeof buffer, "<%s>%s</%s>",
                  colour, god_name(god, false).c_str(), colour);
         disp += buffer;
@@ -780,8 +786,9 @@ bool unnotice_feature(const level_pos &pos)
 
 void display_overview()
 {
+    clrscr();
     std::string disp = overview_description_string(true);
-    linebreak_string(disp, get_number_of_cols() - 5, get_number_of_cols() - 1);
+    linebreak_string(disp, get_number_of_cols());
     formatted_scroller(MF_EASY_EXIT | MF_ANYPRINTABLE | MF_NOSELECT,
                        disp).show();
     redraw_screen();
