@@ -167,7 +167,7 @@ enum ability_type
     ABIL_MAKE_ACQUIRE_GOLD,
     ABIL_MAKE_ACQUIREMENT,
     ABIL_MAKE_WATER,
-    ABIL_MAKE_ELECTRIC_EEL,
+    ABIL_MAKE_LIGHTNING_SPIRE,
     ABIL_MAKE_BAZAAR,
     ABIL_MAKE_ALTAR,
     ABIL_MAKE_GRENADES,
@@ -223,10 +223,12 @@ enum attribute_type
     ATTR_DIVINE_VIGOUR,         // strength of Ely's Divine Vigour
     ATTR_DIVINE_STAMINA,        // strength of Zin's Divine Stamina
     ATTR_DIVINE_SHIELD,         // strength of TSO's Divine Shield
-    ATTR_UNIQUE_RUNES,
-    ATTR_DEMONIC_RUNES,
-    ATTR_ABYSSAL_RUNES,
-    ATTR_RUNES_IN_ZOT,         // Unused but needed for save file compatibility.
+#if TAG_MAJOR_VERSION == 32
+    ATTR_UNUSED_UNIQUE_RUNES,
+    ATTR_UNUSED_DEMONIC_RUNES,
+    ATTR_UNUSED_ABYSSAL_RUNES,
+    ATTR_UNUSED_RUNES_IN_ZOT,
+#endif
     ATTR_WEAPON_SWAP_INTERRUPTED,
     ATTR_GOLD_FOUND,
     ATTR_PURCHASES,            // Gold amount spent at shops.
@@ -304,16 +306,10 @@ enum beam_type                  // beam[].flavour
     BEAM_CHARM,
     BEAM_BANISH,
     BEAM_DEGENERATE,
-#if TAG_MAJOR_VERSION == 32
-    BEAM_ENSLAVE_UNDEAD,
-#endif
     BEAM_ENSLAVE_SOUL,
     BEAM_PAIN,
     BEAM_DISPEL_UNDEAD,
     BEAM_DISINTEGRATION,
-#if TAG_MAJOR_VERSION == 32
-    BEAM_ENSLAVE_DEMON,
-#endif
     BEAM_BLINK,
     BEAM_BLINK_CLOSE,
     BEAM_PETRIFY,
@@ -322,7 +318,8 @@ enum beam_type                  // beam[].flavour
     BEAM_HIBERNATION,
     BEAM_BERSERK,
     BEAM_SLEEP,
-    BEAM_LAST_ENCHANTMENT = BEAM_SLEEP,
+    BEAM_INNER_FLAME,
+    BEAM_LAST_ENCHANTMENT = BEAM_INNER_FLAME,
 
     // new beams for evaporate
     BEAM_POTION_STINKING_CLOUD,
@@ -343,8 +340,8 @@ enum beam_type                  // beam[].flavour
     BEAM_HOLY_LIGHT,
     BEAM_POTION_RANDOM,
     BEAM_AIR,
-
-    BEAM_LAST_REAL = BEAM_AIR,
+    BEAM_PETRIFYING_CLOUD,
+    BEAM_LAST_REAL = BEAM_PETRIFYING_CLOUD,
 
     // For getting the visual effect of a beam.
     BEAM_VISUAL,
@@ -362,8 +359,8 @@ enum book_type
 #if TAG_MAJOR_VERSION == 32
     BOOK_MINOR_MAGIC_II,
     BOOK_MINOR_MAGIC_III,
-#endif
     BOOK_CONJURATIONS_I,
+#endif
     BOOK_CONJURATIONS_II,
     BOOK_FLAMES,
     BOOK_FROST,
@@ -401,9 +398,9 @@ enum book_type
     BOOK_DRAGON,
     BOOK_BURGLARY,
     BOOK_DREAMS,
-    BOOK_CHEMISTRY,
-    BOOK_ZOOLOGY,
-    MAX_NORMAL_BOOK = BOOK_ZOOLOGY,
+    BOOK_ALCHEMY,
+    BOOK_BEASTS,
+    MAX_NORMAL_BOOK = BOOK_BEASTS,
 
     MIN_GOD_ONLY_BOOK,
     BOOK_ANNIHILATIONS = MIN_GOD_ONLY_BOOK,
@@ -477,6 +474,7 @@ enum canned_message_type
     MSG_UNTHINKING_ACT,
     MSG_NOTHING_THERE,
     MSG_NOTHING_CLOSE_ENOUGH,
+    MSG_NO_ENERGY,
     MSG_SPELL_FIZZLES,
     MSG_HUH,
     MSG_EMPTY_HANDED,
@@ -485,6 +483,7 @@ enum canned_message_type
     MSG_NO_SPELLS,
     MSG_MANA_INCREASE,
     MSG_MANA_DECREASE,
+    MSG_DISORIENTED,
     MSG_TOO_HUNGRY,
 };
 
@@ -522,6 +521,9 @@ enum cloud_type
     CLOUD_STEAM,
     CLOUD_GLOOM,
     CLOUD_INK,
+#if TAG_MAJOR_VERSION > 32
+    CLOUD_PETRIFY,
+#endif
     CLOUD_HOLY_FLAMES,
     CLOUD_MIASMA,
     CLOUD_MIST,
@@ -530,6 +532,9 @@ enum cloud_type
     CLOUD_MUTAGENIC,
     CLOUD_MAGIC_TRAIL,
     CLOUD_TORNADO,
+#if TAG_MAJOR_VERSION == 32
+    CLOUD_PETRIFY,
+#endif
     NUM_CLOUD_TYPES,
 
     CLOUD_OPAQUE_FIRST = CLOUD_BLACK_SMOKE,
@@ -578,6 +583,7 @@ enum command_type
     CMD_PICKUP,
     CMD_PICKUP_QUANTITY,
     CMD_DROP,
+    CMD_DROP_LAST,
     CMD_BUTCHER,
     CMD_INSPECT_FLOOR,
     CMD_SHOW_TERRAIN,
@@ -586,9 +592,6 @@ enum command_type
     CMD_EVOKE,
     CMD_EVOKE_WIELDED,
     CMD_WIELD_WEAPON,
-#if TAG_MAJOR_VERSION > 32
-    CMD_UNWIELD_WEAPON,
-#endif
     CMD_WEAPON_SWAP,
     CMD_FIRE,
     CMD_QUIVER_ITEM,
@@ -626,6 +629,7 @@ enum command_type
     CMD_DISPLAY_MAP,
     CMD_DISPLAY_OVERMAP,
     CMD_DISPLAY_RELIGION,
+    CMD_DISPLAY_RUNES,
     CMD_DISPLAY_CHARACTER_STATUS,
     CMD_DISPLAY_SPELLS,
     CMD_EXPERIENCE_CHECK,
@@ -829,14 +833,11 @@ enum command_type
     CMD_DISABLE_MORE,
     CMD_MIN_SYNTHETIC = CMD_DISABLE_MORE,
     CMD_ENABLE_MORE,
+    CMD_UNWIELD_WEAPON,
 
     // [ds] Silently ignored, requests another round of input.
     CMD_NEXT_CMD,
 
-#if TAG_MAJOR_VERSION == 32
-    CMD_UNWIELD_WEAPON,
-#endif
-
     // Must always be last
     CMD_MAX_CMD
 };
@@ -1126,6 +1127,7 @@ enum dungeon_feature_type
     DNGN_TREE,
     DNGN_ORCISH_IDOL,
     DNGN_SWAMP_TREE,
+    DNGN_LAVA_SEA,                     // Gehenna equivalent for permarock
     DNGN_GRANITE_STATUE = 21,
     // Highest solid grid value.
     DNGN_MAXSOLID = DNGN_GRANITE_STATUE,
@@ -1352,6 +1354,9 @@ enum duration_type
     DUR_LIFESAVING,
     DUR_PARALYSIS_IMMUNITY,
     DUR_DARKNESS,
+    DUR_PETRIFYING,
+    DUR_SHROUD_OF_GOLUBRIA,
+    DUR_TORNADO_COOLDOWN,
     NUM_DURATIONS
 };
 
@@ -1434,6 +1439,7 @@ enum enchant_type
     ENCH_MAD,           // Permanently mad.
     ENCH_SILVER_CORONA, // Zin's silver light.
     ENCH_RECITE_TIMER,  // Was recited against.
+    ENCH_INNER_FLAME,
     // Update enchantment names in monster.cc when adding or removing
     // enchantments.
     NUM_ENCHANTMENTS
@@ -1469,14 +1475,24 @@ enum equipment_type
     EQ_BOOTS,
     EQ_SHIELD,
     EQ_BODY_ARMOUR,
+    //Everything beyond here is jewellery
     EQ_LEFT_RING,
     EQ_RIGHT_RING,
     EQ_AMULET,
+    //Octopodes don't have left and right rings. They have eight rings, instead.
+    EQ_RING_ONE,
+    EQ_RING_TWO,
+    EQ_RING_THREE,
+    EQ_RING_FOUR,
+    EQ_RING_FIVE,
+    EQ_RING_SIX,
+    EQ_RING_SEVEN,
+    EQ_RING_EIGHT,
     NUM_EQUIP,
 
     EQ_MIN_ARMOUR = EQ_CLOAK,
     EQ_MAX_ARMOUR = EQ_BODY_ARMOUR,
-    EQ_MAX_WORN   = EQ_AMULET,
+    EQ_MAX_WORN   = EQ_RING_EIGHT,
     // these aren't actual equipment slots, they're categories for functions
     EQ_STAFF            = 100,         // weapon with base_type OBJ_STAVES
     EQ_RINGS,                          // check both rings
@@ -1485,6 +1501,24 @@ enum equipment_type
     EQ_ALL_ARMOUR,                     // check all armour types
 };
 
+enum eq_type
+{
+    ET_WEAPON,
+    ET_SHIELD,
+    ET_ARMOUR,
+    ET_JEWELS,
+    NUM_ET
+};
+
+enum eq_type_flags
+{
+    ETF_WEAPON = 0x1,
+    ETF_SHIELD = 0x2,
+    ETF_ARMOUR = 0x4,
+    ETF_JEWELS = 0x8,
+    ETF_ALL    = 0xF
+};
+
 enum feature_flag_type
 {
     FFT_NONE          = 0,
@@ -1600,6 +1634,8 @@ enum item_status_flag_type  // per item flags: ie. ident status, cursed status
     ISFLAG_EMBROIDERED_SHINY = 0x00040000,  // armour: depends on sub-type
     ISFLAG_COSMETIC_MASK     = 0x00070000,  // mask of cosmetic descriptions
 
+    ISFLAG_UNOBTAINABLE      = 0x00080000,  // vault on display
+
     ISFLAG_NO_RACE           = 0x00000000,  // used for clearing these flags
     ISFLAG_ORCISH            = 0x01000000,  // low quality items
     ISFLAG_DWARVEN           = 0x02000000,  // strong and robust items
@@ -1643,7 +1679,7 @@ enum job_type
     JOB_SUMMONER,
     JOB_AIR_ELEMENTALIST,
     JOB_EARTH_ELEMENTALIST,
-    JOB_CRUSADER,
+    JOB_SKALD,
     JOB_VENOM_MAGE,
     JOB_CHAOS_KNIGHT,
     JOB_TRANSMUTER,
@@ -1793,6 +1829,7 @@ enum menu_type
     MT_DROP,
     MT_PICKUP,
     MT_KNOW,
+    MT_RUNES,
 };
 
 enum mon_holy_type
@@ -1813,6 +1850,7 @@ enum targ_mode_type
     TARG_HOSTILE,
     TARG_HOSTILE_SUBMERGED, // Target hostiles including submerged ones
     TARG_EVOLVABLE_PLANTS,  // Targeting mode for Fedhas' evolution
+    TARG_HOSTILE_UNDEAD,    // For dispel undead
     TARG_NUM_MODES
 };
 
@@ -1824,7 +1862,9 @@ enum monster_type                      // (int) menv[].type
     MONS_GIANT_NEWT,
     MONS_GIANT_GECKO,
     MONS_IGUANA,
+#if TAG_MAJOR_VERSION == 32
     MONS_GILA_MONSTER,
+#endif
     MONS_KOMODO_DRAGON,
     MONS_SMALL_SNAKE,
     MONS_SNAKE,
@@ -1840,7 +1880,9 @@ enum monster_type                      // (int) menv[].type
     MONS_LABORATORY_RAT,
     MONS_QUOKKA,         // Quokka are a type of wallaby, returned -- bwr 382
     MONS_PORCUPINE,
+#if TAG_MAJOR_VERSION == 32
     MONS_MEGABAT,
+#endif
     MONS_JACKAL,
     MONS_HOUND,
     MONS_WAR_DOG,
@@ -2180,7 +2222,7 @@ enum monster_type                      // (int) menv[].type
     MONS_HAIRY_DEVIL,
     MONS_ICE_DEVIL,
     MONS_BLUE_DEVIL,
-    MONS_BEAST,
+    MONS_HELL_BEAST,
     MONS_IRON_DEVIL,
     MONS_EXECUTIONER,
     MONS_GREEN_DEATH,
@@ -2193,7 +2235,7 @@ enum monster_type                      // (int) menv[].type
     MONS_FIEND,
     MONS_ICE_FIEND,
     MONS_SHADOW_FIEND,
-    MONS_PANDEMONIUM_DEMON,
+    MONS_PANDEMONIUM_LORD,
     MONS_EFREET,
     MONS_RAKSHASA,
     MONS_RAKSHASA_FAKE,
@@ -2347,7 +2389,7 @@ enum monster_type                      // (int) menv[].type
     MONS_PLAYER_GHOST,
     MONS_BALL_LIGHTNING,
     MONS_ORB_OF_DESTRUCTION,    // a projectile, not a real mon
-    MONS_HELL_DEMON,
+    MONS_HELL_LORD,
     MONS_MERGED_SLIME_CREATURE, // used only for recoloring
     MONS_SENSED,                // dummy monster for unspecified sensed mons
     MONS_PLAYER,                // a certain ugly creature
@@ -2358,7 +2400,7 @@ enum monster_type                      // (int) menv[].type
     MONS_SENSED_EASY,
     MONS_SENSED_TOUGH,
     MONS_SENSED_NASTY,
-    MONS_SALT_PILLAR,
+    MONS_PILLAR_OF_SALT,
     MONS_TERPSICHORE,
     MONS_BAT,
     MONS_SPRIGGAN_AIR_MAGE,
@@ -2366,6 +2408,12 @@ enum monster_type                      // (int) menv[].type
     MONS_IGNACIO,
     MONS_HOLY_SWINE,            // porkalator only
     MONS_SENSED_FRIENDLY,
+    MONS_GIANT,
+    MONS_BASILISK,
+    MONS_OCTOPODE,
+    MONS_LIGHTNING_SPIRE,
+    MONS_CATOBLEPAS,
+    MONS_GOLEM,
 
     NUM_MONSTERS,                      // used for polymorph
 
@@ -2453,6 +2501,9 @@ enum mutation_type
     MUT_HORNS,          // head
     MUT_STINGER,
     MUT_TALONS,         // feet
+#if TAG_MAJOR_VERSION != 32
+    MUT_TENTACLES,      // Gloves but don't lose a slot yet.
+#endif
 
     // scales
     MUT_DISTORTION_FIELD,
@@ -2466,6 +2517,9 @@ enum mutation_type
     MUT_THIN_METALLIC_SCALES,
     MUT_THIN_SKELETAL_STRUCTURE,
     MUT_YELLOW_SCALES,
+#if TAG_MAJOR_VERSION != 32
+    MUT_CAMOUFLAGE,
+#endif
 
     MUT_ACUTE_VISION,
     MUT_AGILE,
@@ -2541,6 +2595,8 @@ enum mutation_type
 
 #if TAG_MAJOR_VERSION == 32
     MUT_POWERED_BY_PAIN,
+    MUT_CAMOUFLAGE,
+    MUT_TENTACLES,      // Gloves but don't lose a slot yet.
 #endif
     NUM_MUTATIONS,
 
@@ -2573,7 +2629,7 @@ enum object_class_type                 // mitm[].base_type
     OBJ_ORBS,
     OBJ_MISCELLANY,
     OBJ_CORPSES,
-    OBJ_GOLD, // important role as upper limit to chardump::dump_inventory() {dlb}
+    OBJ_GOLD,
 #if TAG_MAJOR_VERSION == 32
     OBJ_GEMSTONES, // found in itemname.cc, labeled as miscellaneous in invent.cc {dlb}
 #endif
@@ -2789,6 +2845,7 @@ enum skill_type
     SK_AIR_MAGIC,
     SK_EARTH_MAGIC,
     SK_POISON_MAGIC,
+    SK_LAST_MAGIC = SK_POISON_MAGIC,
     SK_INVOCATIONS,
     SK_EVOCATIONS,
     SK_LAST_SKILL = SK_EVOCATIONS,
@@ -2800,6 +2857,25 @@ enum skill_type
     SK_NONE,
 };
 
+// TAG_MAJOR_VERSION. Just sort this enum when bumping major.
+enum skill_menu_state
+{
+    SKM_NONE,
+    SKM_MODE_AUTO,
+    SKM_MODE_MANUAL,
+    SKM_DO_PRACTISE,
+    SKM_SHOW_KNOWN,
+    SKM_SHOW_ALL,
+    SKM_LEVEL_ENHANCED,
+    SKM_LEVEL_NORMAL,
+    SKM_VIEW_TRAINING,
+    SKM_VIEW_PROGRESS,
+    SKM_VIEW_TRANSFER,
+    SKM_VIEW_POINTS,
+    SKM_DO_FOCUS,
+    SKM_VIEW_NEW_LEVEL,
+};
+
 // order is important on these (see player_speed())
 enum speed_type
 {
@@ -2842,7 +2918,8 @@ enum species_type
     SP_MERFOLK,
     SP_VAMPIRE,
     SP_DEEP_DWARF,
-    SP_CAT,
+    SP_FELID,
+    SP_OCTOPODE,
     SP_ELF,                            // (placeholder)
     SP_HILL_DWARF,                     // (placeholder)
     SP_OGRE_MAGE,                      // (placeholder)
@@ -2957,7 +3034,9 @@ enum spell_type
     SPELL_CURE_POISON,
     SPELL_CONTROL_TELEPORT,
     SPELL_POISON_WEAPON,
+#if TAG_MAJOR_VERSION == 32
     SPELL_RESIST_POISON,
+#endif
     SPELL_PROJECTED_NOISE,
 #if TAG_MAJOR_VERSION == 32
     SPELL_ALTER_SELF,
@@ -3095,6 +3174,9 @@ enum spell_type
     SPELL_MESMERISE,
     SPELL_MELEE, // like SPELL_NO_SPELL, but doesn't cause a re-roll
     SPELL_FIRE_SUMMON,
+    SPELL_SHROUD_OF_GOLUBRIA,
+    SPELL_INNER_FLAME,
+    SPELL_PETRIFYING_CLOUD,
 
     NUM_SPELLS
 };
@@ -3236,8 +3318,8 @@ enum zap_type
     ZAP_BREATHE_STEAM,
 #if TAG_MAJOR_VERSION == 32
     ZAP_CONTROL_DEMON,
-#endif
     ZAP_ORB_OF_FRAGMENTATION,
+#endif
     ZAP_THROW_ICICLE,
     ZAP_ICE_STORM,
     ZAP_CORONA,
@@ -3263,6 +3345,8 @@ enum zap_type
     ZAP_HOLY_FLAMES,
     ZAP_HOLY_BREATH,
     ZAP_BREATHE_MEPHITIC,
+    ZAP_IOOD_BURST,
+    ZAP_INNER_FLAME,
 
     NUM_ZAPS
 };
@@ -3314,6 +3398,7 @@ enum daction_type
     DACT_SHUFFLE_DECKS,
     DACT_REAUTOMAP,
     DACT_REMOVE_JIYVA_ALTARS,
+    DACT_PIKEL_SLAVES,
     NUM_DACTIONS,
 };
 
@@ -3323,6 +3408,17 @@ enum final_effect_flavour
     FINEFF_MIRROR_DAMAGE,
 };
 
+enum disable_type
+{
+    DIS_SPAWNS,
+    DIS_MON_ACT,
+    DIS_MON_REGEN,
+    DIS_PLAYER_REGEN,
+    DIS_HUNGER,
+    DIS_DEATH,
+    NUM_DISABLEMENTS
+};
+
 #ifdef USE_TILE
 enum screen_mode
 {
@@ -3368,14 +3464,20 @@ enum tile_flags
 
     TILE_FLAG_S_UNDER    = 0x00002000,
     TILE_FLAG_FLYING     = 0x00004000,
+
+    // 3 mutually exclusive flags for behaviour.
+    TILE_FLAG_BEH_MASK   = 0x00018000,
     TILE_FLAG_STAB       = 0x00008000,
     TILE_FLAG_MAY_STAB   = 0x00010000,
+    TILE_FLAG_FLEEING    = 0x00018000,
+
     TILE_FLAG_NET        = 0x00020000,
     TILE_FLAG_POISON     = 0x00040000,
     TILE_FLAG_ANIM_WEP   = 0x00080000,
     TILE_FLAG_MIMIC      = 0x00100000,
-    TILE_FLAG_FLAME      = 0x00200000,
+    TILE_FLAG_STICKY_FLAME = 0x00200000,
     TILE_FLAG_BERSERK    = 0x00400000,
+    TILE_FLAG_INNER_FLAME= 0x40000000,
 
     // MDAM has 5 possibilities, so uses 3 bits.
     TILE_FLAG_MDAM_MASK  = 0x03800000,
