@@ -71,14 +71,8 @@ std::vector<player_save_info> find_saved_characters();
 
 std::string get_savefile_directory(bool ignore_game_type = false);
 std::string get_bonefile_directory(bool ignore_game_type = false);
-std::string get_save_filename(const std::string &pre,
-                              const std::string &suf,
-                              const std::string &ext,
-                              bool suppress_uid = false);
-std::string get_savedir_filename(const std::string &pre,
-                                 const std::string &suf,
-                                 const std::string &ext,
-                                 bool suppress_uid = false);
+std::string get_save_filename(const std::string &name);
+std::string get_savedir_filename(const std::string &name);
 std::string get_base_savedir_path(const std::string &subpath = "");
 std::string get_savedir_path(const std::string &shortpath);
 std::string savedir_versioned_path(const std::string &subdirs = "");
@@ -104,8 +98,10 @@ void save_game_state();
 
 bool get_save_version(reader &file, int &major, int &minor);
 
-bool save_exists(const std::string& name);
-void restore_game(const std::string& name);
+bool save_exists(const std::string& filename);
+bool restore_game(const std::string& filename);
+
+void sighup_save_and_exit();
 
 bool is_existing_level(const level_id &level);
 
@@ -129,10 +125,8 @@ FILE *lk_open(const char *mode, const std::string &file);
 void lk_close(FILE *handle, const char *mode, const std::string &file);
 
 // file locking stuff
-#ifdef USE_FILE_LOCKING
 bool lock_file_handle(FILE *handle, bool write);
 bool unlock_file_handle(FILE *handle);
-#endif // USE_FILE_LOCKING
 
 class file_lock
 {
