@@ -21,13 +21,13 @@ void add_final_effect(final_effect_flavour flavour,
 {
     final_effect fe;
 
-    fe.att = NON_MONSTER;
-    fe.def = NON_MONSTER;
+    fe.att = 0;
+    fe.def = 0;
 
     if (attacker)
-        fe.att = attacker->mindex();
+        fe.att = attacker->mid;
     if (defender)
-        fe.def = defender->mindex();
+        fe.def = defender->mid;
 
     fe.flavour = flavour;
     fe.pos     = pos;
@@ -35,7 +35,7 @@ void add_final_effect(final_effect_flavour flavour,
 
     for (std::vector<final_effect>::iterator fi = env.final_effects.begin();
          fi != env.final_effects.end();
-         fi++)
+         ++fi)
     {
         if (fi->flavour == fe.flavour
             && fi->att == fe.att
@@ -61,17 +61,8 @@ void fire_final_effects()
         const final_effect &fe = env.final_effects[i];
         // We can't just pass the pointer, as we wouldn't be notified
         // if it becomes invalid between scheduling and firing.
-
-        // This code doesn't check for monster being cleaned and a new one
-        // immediately replacing it; this is not supposed to happen save for
-        // zombifying (and then it's the same monster), but if this changes,
-        // we'd need an identifier or such.
-        actor *attacker = (fe.att == NON_MONSTER) ? 0 :
-                          (fe.att == MHITYOU) ? (actor*)&you :
-                          &menv[fe.att];
-        actor *defender = (fe.def == NON_MONSTER) ? 0 :
-                          (fe.def == MHITYOU) ? (actor*)&you :
-                          &menv[fe.def];
+        actor *attacker = actor_by_mid(fe.att);
+        actor *defender = actor_by_mid(fe.def);
 
         switch (fe.flavour)
         {
@@ -84,12 +75,12 @@ void fire_final_effects()
             if (!attacker || attacker == defender || !attacker->alive())
                 continue;
             // defender being dead is ok, if we killed them we still suffer
-            if (fe.att == MHITYOU)
+            if (fe.att == MID_PLAYER)
             {
                 mpr("It reflects your damage back at you!");
                 ouch(fe.x, NON_MONSTER, KILLED_BY_REFLECTION);
             }
-            else if (fe.def == MHITYOU)
+            else if (fe.def == MID_PLAYER)
             {
                 simple_god_message(" mirrors your injury!");
 #ifndef USE_TILE
