@@ -69,6 +69,9 @@ static void _heal_from_food(int hp_amt, int mp_amt = 0, bool unrot = false,
 void make_hungry(int hunger_amount, bool suppress_msg,
                  bool allow_reducing)
 {
+    if (crawl_state.disables[DIS_HUNGER])
+        return;
+
     if (crawl_state.game_is_zotdef() && you.species == SP_SPRIGGAN)
     {
         you.hunger = 6000;
@@ -165,9 +168,6 @@ void weapon_switch(int targ)
                  you.inv[targ].name(DESC_INVENTORY).c_str());
             return;
         }
-
-        mprf("Switching back to %s.",
-             you.inv[targ].name(DESC_INVENTORY).c_str());
     }
 
     // Unwield the old weapon and wield the new.
@@ -199,136 +199,8 @@ void weapon_switch(int targ)
     you.turn_is_over = true;
 }
 
-// Look for a butchering implement. If fallback is true,
-// prompt the user if no obvious options exist.
-// Returns whether a weapon was switched.
-static bool _find_butchering_implement(int &butcher_tool, bool gloved_butcher)
-{
-    // When berserk, you can't change weapons.  Sanity check!
-    if (!can_wield(NULL, true))
-        return (false);
-
-    // If wielding a distortion weapon, never attempt to switch away
-    // automatically.
-    if (const item_def *wpn = you.weapon())
-    {
-        // Otherwise we wouldn't be here.
-        ASSERT(!can_cut_meat(*wpn));
-
-        if (wpn->base_type == OBJ_WEAPONS
-            && item_type_known(*wpn)
-            && get_weapon_brand(*wpn) == SPWPN_DISTORTION
-            && !you.duration[DUR_WEAPON_BRAND])
-        {
-            if (!gloved_butcher)
-            {
-                mprf(MSGCH_WARN,
-                    "You're wielding a weapon of distortion, will not "
-                    "autoswap for butchering.");
-            }
-
-            return (false);
-        }
-
-        if (!check_old_item_warning(*wpn, OPER_WIELD))
-            return (false);
-    }
-
-    bool potential_candidate = false;
-
-    // Look for a butchering implement in your pack.
-    for (int i = 0; i < ENDOFPACK; ++i)
-    {
-        item_info tool = get_item_info(you.inv[i]);
-        if (tool.defined()
-            && tool.base_type == OBJ_WEAPONS
-            && can_cut_meat(tool)
-            && can_wield(&tool)
-            // Don't even suggest autocursing items.
-            // Note that unknown autocursing is OK.
-            && (!is_artefact(tool)
-                || (artefact_known_wpn_property(tool, ARTP_CURSED) <= 0)))
-        {
-            if (Options.easy_butcher
-                && item_known_uncursed(tool)
-                && item_type_known(tool)
-                // Don't even ask!
-                && !needs_handle_warning(tool, OPER_WIELD))
-            {
-                butcher_tool = i;
-                return (true);
-            }
-            else
-                potential_candidate = true;
-        }
-    }
-
-    if (!potential_candidate)
-    {
-        if (!gloved_butcher)
-        {
-            mpr("You don't carry any weapon you could use for butchering.");
-            if (crawl_state.game_is_hints())
-            {
-                mpr("You should pick up the first knife, dagger, sword or axe "
-                    "you find so you can use it to butcher corpses.",
-                    MSGCH_TUTORIAL);
-            }
-        }
-
-        return (false);
-    }
-
-    const int item_slot = prompt_invent_item(
-                              "What would you like to use? (- for none)?",
-                              MT_INVLIST, OSEL_BUTCHERY,
-                              true, true, true, '-', -1, NULL, OPER_WIELD);
-
-    if (prompt_failed(item_slot))
-    {
-        canned_msg(MSG_OK);
-        return (false);
-    }
-    else if (item_slot == PROMPT_GOT_SPECIAL)
-    {
-        if (you.has_claws() || form_can_butcher_barehanded())
-        {
-            butcher_tool = SLOT_BARE_HANDS;
-            return (true);
-        }
-        else
-        {
-            mpr("You can't butcher without a weapon!");
-            return (false);
-        }
-    }
-    else if (item_slot == you.equip[EQ_WEAPON])
-    {
-        mpr("You are already wielding that!");
-        return (false);
-    }
-
-    item_info tool = get_item_info(you.inv[item_slot]);
-    if (tool.defined()
-        && tool.base_type == OBJ_WEAPONS
-        && can_cut_meat(tool))
-    {
-        if (can_wield(&tool))
-        {
-            butcher_tool = item_slot;
-            return (true);
-        }
-
-        mpr("You can't wield this item!");
-        return (false);
-    }
-
-    mpr("That item isn't sharp enough!");
-    return (false);
-}
-
 static bool _prepare_butchery(bool can_butcher, bool removed_gloves,
-                              bool wpn_switch, int butchering_tool)
+                              bool wpn_switch)
 {
     // No preparation necessary.
     if (can_butcher)
@@ -352,30 +224,18 @@ static bool _prepare_butchery(bool can_butcher, bool removed_gloves,
         finish_last_delay();
     }
 
-    if (wpn_switch)
+    if (wpn_switch
+        && !wield_weapon(true, SLOT_BARE_HANDS, false, true, false, false))
     {
-        std::string tool;
-        if (butchering_tool == SLOT_BARE_HANDS)
-        {
-            tool = "unarmed";
-        }
-        else
-        {
-            item_def& new_wpn(you.inv[butchering_tool]);
-            tool = new_wpn.name(DESC_INVENTORY_EQUIP);
-        }
-
-        mprf("Switching to %s for butchering.", tool.c_str());
-
-        if (!wield_weapon(true, butchering_tool, false, true, false, false))
-            return (false);
+        return (false);
     }
 
     // Switched to a good butchering tool.
     return (true);
 }
 
-static bool _butcher_corpse(int corpse_id, bool first_corpse = true,
+static bool _butcher_corpse(int corpse_id, int butcher_tool,
+                            bool first_corpse = true,
                             bool bottle_blood = false)
 {
     ASSERT(corpse_id != -1);
@@ -388,6 +248,14 @@ static bool _butcher_corpse(int corpse_id, bool first_corpse = true,
     {
         return false;
     }
+    else if (!bottle_blood && you.species == SP_VAMPIRE
+             && !you.has_spell(SPELL_SUBLIMATION_OF_BLOOD)
+             && !you.has_spell(SPELL_SIMULACRUM)
+             && !yesno("You'd want to drain or bottle this corpse instead. "
+                       "Continue anyway?", true, 'n'))
+    {
+        return false;
+    }
 
     // Start work on the first corpse we butcher.
     if (first_corpse)
@@ -403,7 +271,8 @@ static bool _butcher_corpse(int corpse_id, bool first_corpse = true,
         dtype = DELAY_BOTTLE_BLOOD;
     }
 
-    start_delay(dtype, work_req, corpse_id, mitm[corpse_id].special);
+    start_delay(dtype, work_req, corpse_id, mitm[corpse_id].special,
+                butcher_tool);
 
     you.turn_is_over = true;
     return (true);
@@ -496,12 +365,8 @@ bool butchery(int which_corpse, bool bottle_blood)
         return (false);
     }
 
-    if (you.flight_mode() == FL_LEVITATE)
-    {
-        mpr("You can't reach the floor from up here.");
-        learned_something_new(HINT_LEVITATING);
+    if (!player_can_reach_floor())
         return (false);
-    }
 
     // Vampires' fangs are optimised for biting, not for tearing flesh.
     // (Not that they really need to.) Other species with this mutation
@@ -519,7 +384,10 @@ bool butchery(int which_corpse, bool bottle_blood)
     bool gloved_butcher   = (you.has_claws() && player_wearing_slot(EQ_GLOVES)
                              && !you.inv[you.equip[EQ_GLOVES]].cursed());
 
-    bool can_butcher      = (teeth_butcher || barehand_butcher || birdie_butcher
+    bool knife_butcher    = !barehand_butcher && !you.weapon() && form_can_wield();
+
+    bool can_butcher      = (teeth_butcher || barehand_butcher
+                             || birdie_butcher || knife_butcher
                              || you.weapon() && can_cut_meat(*you.weapon()));
 
     if (!Options.easy_butcher && !can_butcher)
@@ -575,34 +443,37 @@ bool butchery(int which_corpse, bool bottle_blood)
 
     bool wpn_switch     = false;
     bool removed_gloves = false;
-    int butcher_tool    = SLOT_BARE_HANDS;
 
     if (!can_butcher)
     {
-        // Try to find a butchering implement.
-        if (!_find_butchering_implement(butcher_tool, gloved_butcher)
-            && !gloved_butcher)
-        {
-            return (false);
-        }
-
-        if (butcher_tool == SLOT_BARE_HANDS && gloved_butcher)
+        if (you.weapon() && you.weapon()->cursed() && gloved_butcher)
             removed_gloves = true;
-        else if (you.equip[EQ_WEAPON] != butcher_tool)
+        else
             wpn_switch = true;
     }
 
+    int butcher_tool;
+
+    if (barehand_butcher || removed_gloves)
+        butcher_tool = SLOT_CLAWS;
+    else if (teeth_butcher)
+        butcher_tool = SLOT_TEETH;
+    else if (birdie_butcher)
+        butcher_tool = SLOT_BIRDIE;
+    else if (wpn_switch || knife_butcher)
+        butcher_tool = SLOT_BUTCHERING_KNIFE;
+    else
+        butcher_tool = you.weapon()->link;
+
     // Butcher pre-chosen corpse, if found, or if there is only one corpse.
     bool success = false;
     if (prechosen && corpse_id == which_corpse
         || num_corpses == 1 && !Options.always_confirm_butcher)
     {
-        if (!_prepare_butchery(can_butcher, removed_gloves, wpn_switch,
-                               butcher_tool))
-        {
+        if (!_prepare_butchery(can_butcher, removed_gloves, wpn_switch))
             return (false);
-        }
-        success = _butcher_corpse(corpse_id, true, bottle_blood);
+
+        success = _butcher_corpse(corpse_id, butcher_tool, true, bottle_blood);
         _terminate_butchery(wpn_switch, removed_gloves, old_weapon, old_gloves);
 
         // Remind player of corpses in pack that could be butchered or
@@ -662,7 +533,7 @@ bool butchery(int which_corpse, bool bottle_blood)
                     if (!did_weap_swap)
                     {
                         if (_prepare_butchery(can_butcher, removed_gloves,
-                                              wpn_switch, butcher_tool))
+                                              wpn_switch))
                         {
                             did_weap_swap = true;
                         }
@@ -698,7 +569,8 @@ bool butchery(int which_corpse, bool bottle_blood)
 
         if (corpse_id != -1)
         {
-            if (_butcher_corpse(corpse_id, first_corpse, bottle_blood))
+            if (_butcher_corpse(corpse_id, butcher_tool, first_corpse,
+                                bottle_blood))
             {
                 success = true;
                 first_corpse = false;
@@ -810,11 +682,10 @@ bool eat_food(int slot)
     if (!_eat_check())
         return (false);
 
-    int result;
     // Skip the prompts if we already know what we're eating.
     if (slot == -1)
     {
-        result = prompt_eat_chunks();
+        int result = prompt_eat_chunks();
         if (result == 1 || result == -1)
             return (result > 0);
 
@@ -991,7 +862,7 @@ bool food_change(bool suppress_message)
                 if (you.level_type == LEVEL_LABYRINTH
                     && !_player_has_enough_food())
                 {
-                    xom_is_stimulated(64);
+                    xom_is_stimulated(50);
                 }
 
                 learned_something_new(HINT_YOU_STARVING);
@@ -1494,7 +1365,7 @@ bool eat_from_inventory()
 
 // Returns -1 for cancel, 1 for eaten, 0 for not eaten,
 //         -2 for skip to inventory.
-int prompt_eat_chunks()
+int prompt_eat_chunks(bool only_auto)
 {
     // Full herbivores cannot eat chunks.
     if (player_mutation_level(MUT_HERBIVOROUS) == 3)
@@ -1599,6 +1470,8 @@ int prompt_eat_chunks()
             }
             else if (easy_contam && contam && !bad)
                 autoeat = true;
+            else if (only_auto)
+                return 0;
             else
             {
                 mprf(MSGCH_PROMPT, "%s %s%s? (ye/n/q/i?)",
@@ -1790,7 +1663,7 @@ static void _eat_chunk(corpse_effect_type chunk_effect, bool cannibal,
         xom_is_stimulated(random2(200));
         break;
 
-    case CE_HCL:
+    case CE_ROT:
         you.rot(&you, 10 + random2(10));
         if (you.sicken(50 + random2(100)))
             xom_is_stimulated(random2(100));
@@ -1799,7 +1672,7 @@ static void _eat_chunk(corpse_effect_type chunk_effect, bool cannibal,
     case CE_POISONOUS:
         mpr("Yeeuch - this meat is poisonous!");
         if (poison_player(3 + random2(4), "", "poisonous meat"))
-            xom_is_stimulated(random2(128));
+            xom_is_stimulated(random2(100));
         break;
 
     case CE_ROTTEN:
@@ -2085,10 +1958,10 @@ void finished_eating_message(int food_type)
         case FOOD_APPLE:
         case FOOD_APRICOT:
             mprf("Mmmm... Yummy %s.",
-                (food_type == FOOD_APPLE)   ? "apple." :
-                (food_type == FOOD_PEAR)    ? "pear." :
-                (food_type == FOOD_APRICOT) ? "apricot."
-                                            : "fruit.");
+                (food_type == FOOD_APPLE)   ? "apple" :
+                (food_type == FOOD_PEAR)    ? "pear" :
+                (food_type == FOOD_APRICOT) ? "apricot"
+                                            : "fruit");
             return;
         case FOOD_CHOKO:
             mpr("That choko was very bland.");
@@ -2117,7 +1990,7 @@ void finished_eating_message(int food_type)
             mpr("That grape was delicious!");
             return;
         case FOOD_SULTANA:
-            mpr("That sultana was delicious! (but very small)");
+            mpr("That sultana was delicious... but very small.");
             return;
         case FOOD_LYCHEE:
             mpr("That lychee was delicious!");
@@ -2130,7 +2003,7 @@ void finished_eating_message(int food_type)
     switch (food_type)
     {
     case FOOD_HONEYCOMB:
-        mpr("That honeycomb was delicious.");
+        mpr("That honeycomb was delicious!");
         break;
     case FOOD_ROYAL_JELLY:
         mpr("That royal jelly was delicious!");
@@ -2146,24 +2019,20 @@ void finished_eating_message(int food_type)
             mprf("Mmm... %s.", Options.pizza.c_str());
         else
         {
-            int temp_rand;
-            if (carnivorous) // non-vegetable
-                temp_rand = random2(7);
-            else if (herbivorous) // non-meaty
-                temp_rand = 6 + random2(3);
-            else
-                temp_rand = random2(9);
-
-            mprf("Mmm... %s",
-                (temp_rand == 0) ? "Ham and pineapple." :
-                (temp_rand == 1) ? "Supreme." :
-                (temp_rand == 2) ? "Super Supreme!" :
-                (temp_rand == 3) ? "Pepperoni." :
-                (temp_rand == 4) ? "Yeuchh - Anchovies!" :
-                (temp_rand == 5) ? "Chicken." :
-                (temp_rand == 6) ? "Cheesy." :
-                (temp_rand == 7) ? "Vegetable."
-                                 : "Mushroom.");
+            int temp_rand = random2(9);
+            mprf("%s %s.",
+                (carnivorous && temp_rand >= 6
+                 || herbivorous && temp_rand <= 4
+                 || temp_rand == 3) ? "Yeuchh!" : "Mmm...",
+                (temp_rand == 0) ? "Ham and pineapple" :
+                (temp_rand == 1) ? "Super Supreme" :
+                (temp_rand == 2) ? "Pepperoni" :
+                (temp_rand == 3) ? "Anchovies" :
+                (temp_rand == 4) ? "Chicken" :
+                (temp_rand == 5) ? "Cheesy" :
+                (temp_rand == 6) ? "Vegetable" :
+                (temp_rand == 7) ? "Peppers"
+                                 : "Mushroom");
         }
         break;
     case FOOD_CHEESE:
@@ -2309,8 +2178,8 @@ void vampire_nutrition_per_turn(const item_def &corpse, int feeding)
                     // Always print this message - maybe you lost poison
                     // resistance due to feeding.
                     mpr("Blech - this blood tastes nasty!");
-                    if (poison_player(1 + random2(3), "", "poisoned blood"))
-                        xom_is_stimulated(random2(128));
+                    if (poison_player(1 + random2(3), "", "poisonous blood"))
+                        xom_is_stimulated(random2(100));
                     stop_delay();
                     return;
 
@@ -2336,7 +2205,7 @@ void vampire_nutrition_per_turn(const item_def &corpse, int feeding)
                     // No healing from bad mutagenic blood.
                     break;
 
-                case CE_HCL:
+                case CE_ROT:
                     you.rot(&you, 5 + random2(5));
                     if (you.sicken(50 + random2(100)))
                         xom_is_stimulated(random2(100));
@@ -2405,7 +2274,7 @@ bool causes_rot(const item_def &food)
     if (you.species == SP_GHOUL)
         return (false);
 
-    return (mons_corpse_effect(food.plus) == CE_HCL);
+    return (mons_corpse_effect(food.plus) == CE_ROT);
 }
 
 // Returns 1 for herbivores, -1 for carnivores and 0 for either.
@@ -2655,7 +2524,7 @@ bool can_ingest(int what_isit, int kindof_thing, bool suppress_msg,
             }
             else if (kindof_thing == FOOD_CHUNK)
             {
-                if (rotten && !_player_can_eat_rotten_meat(true))
+                if (rotten && !_player_can_eat_rotten_meat(!suppress_msg))
                     return (false);
 
                 if (ur_chunkslover)
@@ -2753,7 +2622,7 @@ static corpse_effect_type _determine_chunk_effect(corpse_effect_type chunktype,
     // Determine the initial effect of eating a particular chunk. {dlb}
     switch (chunktype)
     {
-    case CE_HCL:
+    case CE_ROT:
     case CE_MUTAGEN_RANDOM:
         if (you.species == SP_GHOUL)
             chunktype = CE_CLEAN;
@@ -2905,10 +2774,10 @@ static void _heal_from_food(int hp_amt, int mp_amt, bool unrot,
                             bool restore_str)
 {
     if (hp_amt > 0)
-        inc_hp(hp_amt, false);
+        inc_hp(hp_amt);
 
     if (mp_amt > 0)
-        inc_mp(mp_amt, false);
+        inc_mp(mp_amt);
 
     if (unrot && player_rotted())
     {
@@ -2951,7 +2820,8 @@ int you_min_hunger()
 
 void handle_starvation()
 {
-    if (you.is_undead != US_UNDEAD && you.hunger <= 500)
+    if (you.is_undead != US_UNDEAD && !you.duration[DUR_DEATHS_DOOR]
+        && you.hunger <= 500)
     {
         if (!you.cannot_act() && one_chance_in(40))
         {
@@ -2960,7 +2830,7 @@ void handle_starvation()
 
             you.increase_duration(DUR_PARALYSIS, 5 + random2(8), 13);
             if (you.religion == GOD_XOM)
-                xom_is_stimulated(get_tension() > 0 ? 255 : 128);
+                xom_is_stimulated(get_tension() > 0 ? 200 : 100);
         }
 
         if (you.hunger <= 100)
@@ -2970,3 +2840,20 @@ void handle_starvation()
         }
     }
 }
+
+const char* hunger_cost_string(const int hunger)
+{
+    if (you.is_undead == US_UNDEAD)
+        return ("N/A");
+
+    // Spell hunger is "Fruit" if casting the spell five times costs at
+    // most one "Fruit".
+    const char* hunger_descriptions[] = {
+        "None", "Sultana", "Strawberry", "Choko", "Honeycomb", "Ration"
+    };
+
+    const int breakpoints[] = { 1, 15, 41, 121, 401 };
+
+    return (hunger_descriptions[breakpoint_rank(hunger, breakpoints,
+                                                ARRAYSZ(breakpoints))]);
+}
