@@ -114,6 +114,7 @@ static spell_type search_order_misc[] = {
     SPELL_CONFUSE,
     SPELL_MEPHITIC_CLOUD,
     SPELL_SLOW,
+    SPELL_PETRIFY,
     SPELL_POLYMORPH_OTHER,
     SPELL_TELEPORT_OTHER,
     SPELL_EVAPORATE, // replaced with Mephitic Cloud, though at lower priority
@@ -269,8 +270,13 @@ void ghost_demon::init_random_demon()
             spells[5] = SPELL_TELEPORT_SELF;
 
         // Convert the player spell indices to monster spell ones.
+        // Pan lords also get their Agony upgraded to Torment.
         for (int i = 0; i < NUM_MONSTER_SPELL_SLOTS; ++i)
+        {
             spells[i] = translate_spell(spells[i]);
+            if (spells[i] == SPELL_AGONY)
+                spells[i] = SPELL_SYMBOL_OF_TORMENT;
+        }
 
         // Give demon a chance for some monster-only spells.
         // Demon-summoning should be fairly common.
@@ -826,8 +832,6 @@ spell_type ghost_demon::translate_spell(spell_type spel) const
         return (SPELL_CALL_IMP);
     case SPELL_DELAYED_FIREBALL:
         return (SPELL_FIREBALL);
-    case SPELL_PETRIFY:
-        return (SPELL_PARALYSE);
     case SPELL_EVAPORATE:
         return (SPELL_MEPHITIC_CLOUD);
     case SPELL_STICKY_FLAME:
