@@ -207,9 +207,8 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
     if (god == GOD_KIKUBAAQUDGHA)
     {
         you.gift_timeout = 0; // no protection during pain branding weapon
-        you.turn_is_over = true; // torment() relies on this to assign xp
 
-        torment(TORMENT_KIKUBAAQUDGHA, you.pos());
+        torment(&you, TORMENT_KIKUBAAQUDGHA, you.pos());
 
         // Bloodify surrounding squares (75% chance).
         for (radius_iterator ri(you.pos(), 2, true, true); ri; ++ri)
@@ -342,11 +341,8 @@ void pray()
     const god_type altar_god = feat_altar_god(grd(you.pos()));
     if (altar_god != GOD_NO_GOD)
     {
-        if (you.flight_mode() == FL_LEVITATE)
-        {
-            mpr("You are floating high above the altar.");
+        if (!player_can_reach_floor("altar"))
             return;
-        }
 
         if (you.religion != GOD_NO_GOD && altar_god == you.religion)
         {
@@ -370,9 +366,11 @@ void pray()
 
     if (you.religion == GOD_NO_GOD)
     {
+        const mon_holy_type holi = you.holiness();
+
         mprf(MSGCH_PRAY,
-             "You spend a moment contemplating the meaning of %slife.",
-             you.is_undead ? "un" : "");
+             "You spend a moment contemplating the meaning of %s.",
+             holi == MH_NONLIVING || holi == MH_UNDEAD ? "existence" : "life");
 
         // Zen meditation is timeless.
         return;
@@ -518,7 +516,7 @@ static void _give_sac_group_feedback(int which)
 
 static void _ashenzari_sac_scroll(const item_def& item)
 {
-    int scr = (you.species == SP_CAT) ? SCR_CURSE_JEWELLERY :
+    int scr = (you.species == SP_FELID) ? SCR_CURSE_JEWELLERY :
               random_choose(SCR_CURSE_WEAPON, SCR_CURSE_ARMOUR,
                             SCR_CURSE_JEWELLERY, -1);
     int it = items(0, OBJ_SCROLLS, scr, true, 0, MAKE_ITEM_NO_RACE,
@@ -562,161 +560,183 @@ static bool _destroyed_valuable_weapon(int value, int type)
     return (false);
 }
 
+static piety_gain_t _sac_corpse(const item_def& item)
+{
+#ifdef NEW_OKAWARU_PIETY
+    if (you.religion == GOD_OKAWARU)
+    {
+        monster dummy;
+        dummy.type = (monster_type)(item.orig_monnum ? item.orig_monnum - 1 : item.plus);
+        if (item.props.exists(MONSTER_HIT_DICE))
+            dummy.hit_dice = item.props[MONSTER_HIT_DICE].get_short();
+        if (item.props.exists(MONSTER_NUMBER))
+            dummy.number   = item.props[MONSTER_NUMBER].get_short();
+        define_monster(&dummy);
+        int gain = get_fuzzied_monster_difficulty(&dummy);
+        dprf("fuzzied corpse difficulty: %4.2f", gain*0.01);
+
+        gain_piety(gain, 700);
+        gain = div_rand_round(gain, 700);
+        return (gain <= 0) ? PIETY_NONE : (gain < 4) ? PIETY_SOME : PIETY_LOTS;
+    }
+#endif
+
+    gain_piety(13, 19);
+
+    // The feedback is not accurate any longer on purpose; it only reveals
+    // the rate you get piety at.
+    return x_chance_in_y(13, 19) ? PIETY_SOME : PIETY_NONE;
+}
+
 // God effects of sacrificing one item from a stack (e.g., a weapon, one
 // out of 20 arrows, etc.).  Does not modify the actual item in any way.
 static piety_gain_t _sacrifice_one_item_noncount(const item_def& item,
        int *js, bool first)
 {
-    piety_gain_t relative_piety_gain = PIETY_NONE;
-
     // XXX: this assumes that there's no overlap between
     //      item-accepting gods and corpse-accepting gods.
     if (god_likes_fresh_corpses(you.religion))
-    {
-        gain_piety(13, 19);
+        return _sac_corpse(item);
 
-        // The feedback is not accurate any longer on purpose; it only reveals
-        // the rate you get piety at.
-        if (x_chance_in_y(13, 19))
-            relative_piety_gain = PIETY_SOME;
-    }
-    else
-    {
-        switch (you.religion)
-        {
-        case GOD_ELYVILON:
-        {
-            const int value = item_value(item) / item.quantity;
-            const bool valuable_weapon =
-                _destroyed_valuable_weapon(value, item.base_type);
-            const bool unholy_weapon = is_unholy_item(item);
-            const bool evil_weapon = is_evil_item(item);
+    // item_value() multiplies by quantity.
+    const int shop_value = item_value(item) / item.quantity;
+    // Since the god is taking the items as a sacrifice, they must have at
+    // least minimal value, otherwise they wouldn't be taken.
+    const int value = (is_worthless_consumable(item) ? 1 : shop_value);
 
-            if (valuable_weapon || unholy_weapon || evil_weapon)
+#if defined(DEBUG_DIAGNOSTICS) || defined(DEBUG_SACRIFICE)
+        mprf(MSGCH_DIAGNOSTICS, "Sacrifice item value: %d", value);
+#endif
+
+    piety_gain_t relative_piety_gain = PIETY_NONE;
+    switch (you.religion)
+    {
+    case GOD_ELYVILON:
+    {
+        const bool valuable_weapon =
+            _destroyed_valuable_weapon(value, item.base_type);
+        const bool unholy_weapon = is_unholy_item(item);
+        const bool evil_weapon = is_evil_item(item);
+
+        if (valuable_weapon || unholy_weapon || evil_weapon)
+        {
+            if (unholy_weapon || evil_weapon)
             {
-                if (unholy_weapon || evil_weapon)
+                const char *desc_weapon = evil_weapon ? "evil" : "unholy";
+
+                // Print this in addition to the above!
+                if (first)
                 {
-                    const char *desc_weapon = evil_weapon ? "evil" : "unholy";
-
-                    // Print this in addition to the above!
-                    if (first)
-                    {
-                        simple_god_message(make_stringf(
-                                 " welcomes the destruction of %s %s weapon%s.",
-                                 item.quantity == 1 ? "this" : "these",
-                                 desc_weapon,
-                                 item.quantity == 1 ? ""     : "s").c_str(),
-                                 GOD_ELYVILON);
-                    }
+                    simple_god_message(make_stringf(
+                             " welcomes the destruction of %s %s weapon%s.",
+                             item.quantity == 1 ? "this" : "these",
+                             desc_weapon,
+                             item.quantity == 1 ? ""     : "s").c_str(),
+                             GOD_ELYVILON);
                 }
-
-                gain_piety(1);
-                relative_piety_gain = PIETY_SOME;
             }
-            break;
+
+            gain_piety(1);
+            relative_piety_gain = PIETY_SOME;
         }
+        break;
+    }
 
-        case GOD_BEOGH:
+    case GOD_BEOGH:
+    {
+        const int item_orig = item.orig_monnum - 1;
+
+        int chance = 4;
+
+        if (item_orig == MONS_SAINT_ROKA)
+            chance += 12;
+        else if (item_orig == MONS_ORC_HIGH_PRIEST)
+            chance += 8;
+        else if (item_orig == MONS_ORC_PRIEST)
+            chance += 4;
+
+        if (food_is_rotten(item))
+            chance--;
+        else if (item.sub_type == CORPSE_SKELETON)
+            chance -= 2;
+
+        gain_piety(chance, 20);
+        if (x_chance_in_y(chance, 20))
+            relative_piety_gain = PIETY_SOME;
+        break;
+    }
+
+    case GOD_NEMELEX_XOBEH:
+    {
+        if (you.attribute[ATTR_CARD_COUNTDOWN] && x_chance_in_y(value, 800))
         {
-            const int item_orig = item.orig_monnum - 1;
-
-            int chance = 4;
-
-            if (item_orig == MONS_SAINT_ROKA)
-                chance += 12;
-            else if (item_orig == MONS_ORC_HIGH_PRIEST)
-                chance += 8;
-            else if (item_orig == MONS_ORC_PRIEST)
-                chance += 4;
-
-            if (food_is_rotten(item))
-                chance--;
-            else if (item.sub_type == CORPSE_SKELETON)
-                chance -= 2;
-
-            gain_piety(chance, 20);
-            if (x_chance_in_y(chance, 20))
-                relative_piety_gain = PIETY_SOME;
-            break;
-        }
-
-        case GOD_NEMELEX_XOBEH:
-        {
-            // item_value() multiplies by quantity.
-            const int value = item_value(item) / item.quantity;
-
-            if (you.attribute[ATTR_CARD_COUNTDOWN] && x_chance_in_y(value, 800))
-            {
-                you.attribute[ATTR_CARD_COUNTDOWN]--;
+            you.attribute[ATTR_CARD_COUNTDOWN]--;
 #if defined(DEBUG_DIAGNOSTICS) || defined(DEBUG_CARDS) || defined(DEBUG_SACRIFICE)
-                mprf(MSGCH_DIAGNOSTICS, "Countdown down to %d",
-                     you.attribute[ATTR_CARD_COUNTDOWN]);
+            mprf(MSGCH_DIAGNOSTICS, "Countdown down to %d",
+                 you.attribute[ATTR_CARD_COUNTDOWN]);
 #endif
-            }
-            // Nemelex piety gain is fairly fast... at least when you
-            // have low piety.
-            int piety_change, piety_denom;
-            if (item.base_type == OBJ_CORPSES)
-            {
-                piety_change = 1;
-                piety_denom = 2 + you.piety/50;
-            }
-            else
-            {
-                piety_change = value/2 + 1;
-                if (is_artefact(item))
-                    piety_change *= 2;
-                piety_denom = 30 + you.piety/2;
-            }
-
-            gain_piety(piety_change, piety_denom);
-
-            // Preserving the old behaviour of giving the big message for
-            // artifacts and artifacts only.
-            relative_piety_gain = x_chance_in_y(piety_change, piety_denom) ?
-                                    is_artefact(item) ?
-                                      PIETY_LOTS : PIETY_SOME : PIETY_NONE;
-
-            if (item.base_type == OBJ_FOOD && item.sub_type == FOOD_CHUNK
-                || is_blood_potion(item))
-            {
-                // Count chunks and blood potions towards decks of
-                // Summoning.
-                you.sacrifice_value[OBJ_CORPSES] += value;
-            }
-            else if (item.base_type == OBJ_CORPSES)
-            {
-#if defined(DEBUG_GIFTS) || defined(DEBUG_CARDS) || defined(DEBUG_SACRIFICE)
-                mprf(MSGCH_DIAGNOSTICS, "Corpse mass is %d",
-                     item_mass(item));
-#endif
-                you.sacrifice_value[item.base_type] += item_mass(item);
-            }
-            else
-                you.sacrifice_value[item.base_type] += value;
-            break;
         }
-
-        case GOD_JIYVA:
+        // Nemelex piety gain is fairly fast... at least when you
+        // have low piety.
+        int piety_change, piety_denom;
+        if (item.base_type == OBJ_CORPSES)
         {
-            // item_value() multiplies by quantity.
-            const int value = item_value(item) / item.quantity;
-            // compress into range 0..250
-            const int stepped = stepdown_value(value, 50, 50, 200, 250);
-            gain_piety(stepped, 50);
-            relative_piety_gain = (piety_gain_t)std::min(2,
-                                    div_rand_round(stepped, 50));
-            jiyva_slurp_bonus(div_rand_round(stepped, 50), js);
-            break;
+            piety_change = 1;
+            piety_denom = 2 + you.piety/50;
+        }
+        else
+        {
+            piety_change = value/2 + 1;
+            if (is_artefact(item))
+                piety_change *= 2;
+            piety_denom = 30 + you.piety/2;
         }
 
-        case GOD_ASHENZARI:
-            _ashenzari_sac_scroll(item);
-            break;
+        gain_piety(piety_change, piety_denom);
 
-        default:
-            break;
+        // Preserving the old behaviour of giving the big message for
+        // artifacts and artifacts only.
+        relative_piety_gain = x_chance_in_y(piety_change, piety_denom) ?
+                                is_artefact(item) ?
+                                  PIETY_LOTS : PIETY_SOME : PIETY_NONE;
+
+        if (item.base_type == OBJ_FOOD && item.sub_type == FOOD_CHUNK
+            || is_blood_potion(item))
+        {
+            // Count chunks and blood potions towards decks of
+            // Summoning.
+            you.sacrifice_value[OBJ_CORPSES] += value;
         }
+        else if (item.base_type == OBJ_CORPSES)
+        {
+#if defined(DEBUG_GIFTS) || defined(DEBUG_CARDS) || defined(DEBUG_SACRIFICE)
+            mprf(MSGCH_DIAGNOSTICS, "Corpse mass is %d",
+                 item_mass(item));
+#endif
+            you.sacrifice_value[item.base_type] += item_mass(item);
+        }
+        else
+            you.sacrifice_value[item.base_type] += value;
+        break;
+    }
+
+    case GOD_JIYVA:
+    {
+        // compress into range 0..250
+        const int stepped = stepdown_value(value, 50, 50, 200, 250);
+        gain_piety(stepped, 50);
+        relative_piety_gain = (piety_gain_t)std::min(2,
+                                div_rand_round(stepped, 50));
+        jiyva_slurp_bonus(div_rand_round(stepped, 50), js);
+        break;
+    }
+
+    case GOD_ASHENZARI:
+        _ashenzari_sac_scroll(item);
+        break;
+
+    default:
+        break;
     }
 
     return (relative_piety_gain);
@@ -844,11 +864,6 @@ static bool _offer_items()
         }
 
 
-#if defined(DEBUG_DIAGNOSTICS) || defined(DEBUG_SACRIFICE)
-        mprf(MSGCH_DIAGNOSTICS, "Sacrifice item value: %d",
-             item_value(item));
-#endif
-
         piety_gain_t relative_gain = sacrifice_item_stack(item);
         print_sacrifice_message(you.religion, mitm[i], relative_gain);
         item_was_destroyed(mitm[i]);
