@@ -36,6 +36,12 @@ enum object_selector
 
 #define SLOT_BARE_HANDS      -2
 
+// Only used for butchering messages
+#define SLOT_BUTCHERING_KNIFE -3
+#define SLOT_CLAWS            -4
+#define SLOT_TEETH            -5
+#define SLOT_BIRDIE           -6
+
 #define PROMPT_ABORT         -1
 #define PROMPT_GOT_SPECIAL   -2
 #define PROMPT_NOTHING       -3
@@ -111,7 +117,7 @@ public:
 
     virtual std::string get_filter_text() const;
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual bool get_tiles(std::vector<tile_def>& tiles) const;
 #endif
 
@@ -232,6 +238,7 @@ unsigned char get_invent(int invent_type);
 bool in_inventory(const item_def &i);
 
 std::string item_class_name(int type, bool terse = false);
+const char* item_slot_name(equipment_type type, bool terse);
 
 bool check_old_item_warning(const item_def& item, operation_types oper);
 bool check_warning_inscriptions(const item_def& item, operation_types oper);
