@@ -17,7 +17,8 @@ void init_properties(void);
 bool item_known_cursed(const item_def &item);
 bool item_known_uncursed(const item_def &item);
 void do_curse_item(item_def &item, bool quiet = true);
-void do_uncurse_item(item_def &item, bool inscribe = true, bool no_ash = false);
+void do_uncurse_item(item_def &item, bool inscribe = true, bool no_ash = false,
+                     bool check_bondage = true);
 
 // stationary:
 void set_item_stationary(item_def &item);
@@ -75,6 +76,7 @@ bool item_is_rechargeable(const item_def &it, bool hide_charged = false,
                           bool weapons = false);
 int wand_charge_value(int type);
 int wand_max_charges(int type);
+bool is_offensive_wand(const item_def& item);
 bool is_enchantable_weapon(const item_def &wpn, bool uncurse,
                            bool first = true);
 bool is_enchantable_armour(const item_def &arm, bool uncurse,
@@ -103,6 +105,8 @@ hands_reqd_type hands_reqd(const item_def &item, size_type size);
 hands_reqd_type hands_reqd(object_class_type base_type, int sub_type,
                            size_type size);
 
+bool is_whip_type(int wpn_type);
+
 bool is_demonic(const item_def &item);
 bool is_blessed(const item_def &item);
 bool is_blessed_convertible(const item_def &item);
