@@ -11,7 +11,7 @@ static const char * Job_Abbrev_List[ NUM_JOBS ] =
       "Pa",
 #endif
       "As", "Be", "Hu",
-      "Cj", "En", "FE", "IE", "Su", "AE", "EE", "Cr",
+      "Cj", "En", "FE", "IE", "Su", "AE", "EE", "Sk",
       "VM",
       "CK", "Tm", "He",
 #if TAG_MAJOR_VERSION == 32
@@ -28,7 +28,7 @@ static const char * Job_Name_List[ NUM_JOBS ] =
 #endif
       "Assassin", "Berserker", "Hunter", "Conjurer", "Enchanter",
       "Fire Elementalist", "Ice Elementalist", "Summoner", "Air Elementalist",
-      "Earth Elementalist", "Crusader",
+      "Earth Elementalist", "Skald",
       "Venom Mage",
       "Chaos Knight", "Transmuter", "Healer",
 #if TAG_MAJOR_VERSION == 32
@@ -40,7 +40,9 @@ static const char * Job_Name_List[ NUM_JOBS ] =
 
 const char *get_job_abbrev(int which_job)
 {
-    COMPILE_CHECK(ARRAYSZ(Job_Abbrev_List) == NUM_JOBS, c1);
+    if (which_job == JOB_UNKNOWN)
+        return "Un";
+    COMPILE_CHECK(ARRAYSZ(Job_Abbrev_List) == NUM_JOBS);
     ASSERT(which_job >= 0 && which_job < NUM_JOBS);
 
     return (Job_Abbrev_List[which_job]);
@@ -64,7 +66,9 @@ job_type get_job_by_abbrev(const char *abbrev)
 
 const char *get_job_name(int which_job)
 {
-    COMPILE_CHECK(ARRAYSZ(Job_Name_List) == NUM_JOBS, c1);
+    if (which_job == JOB_UNKNOWN)
+        return "Unemployed";
+    COMPILE_CHECK(ARRAYSZ(Job_Name_List) == NUM_JOBS);
     ASSERT(which_job >= 0 && which_job < NUM_JOBS);
 
     return (Job_Name_List[which_job]);
