@@ -5,7 +5,7 @@
 
 #include "AppHdr.h"
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -19,7 +19,6 @@
 #include "message.h"
 #include "stash.h"
 #include "state.h"
-#include "stuff.h"
 #include "terrain.h"
 #include "tiledef-main.h"
 #include "travel.h"
@@ -194,44 +193,6 @@ bool kbhit()
 }
 
 #ifdef UNIX
-int itoa(int value, char *strptr, int radix)
-{
-    unsigned int bitmask = 32768;
-    int ctr = 0;
-    int startflag = 0;
-
-    if (radix == 10)
-    {
-        sprintf(strptr, "%i", value);
-    }
-    else if (radix == 2)             /* int to "binary string" */
-    {
-        while (bitmask)
-        {
-            if (value & bitmask)
-            {
-                startflag = 1;
-                sprintf(strptr + ctr, "1");
-            }
-            else if (startflag)
-            {
-                sprintf(strptr + ctr, "0");
-            }
-
-            bitmask = bitmask >> 1;
-            if (startflag)
-                ctr++;
-        }
-
-        if (!startflag)         /* Special case if value == 0 */
-            sprintf((strptr + ctr++), "0");
-
-        strptr[ctr] = (char) NULL;
-    }
-    return (0);                /* Me? Fail? Nah. */
-}
-
-
 // Convert string to lowercase.
 char *strlwr(char *str)
 {
@@ -244,4 +205,4 @@ char *strlwr(char *str)
 }
 
 #endif // #ifdef UNIX
-#endif // #ifdef USE_TILE
+#endif // #ifdef USE_TILE_LOCAL
