@@ -141,7 +141,7 @@ static std::string get_userfunction(const keyseq &seq)
 
 static bool userfunc_referenced(int index, const macromap &mm)
 {
-    for (macromap::const_iterator i = mm.begin(); i != mm.end(); i++)
+    for (macromap::const_iterator i = mm.begin(); i != mm.end(); ++i)
     {
         if (userfunc_index(i->second) == index)
             return (true);
@@ -363,7 +363,7 @@ static std::string vtostr(const keyseq &seq)
         v = &dummy;
     }
 
-    for (keyseq::const_iterator i = v->begin(); i != v->end(); i++)
+    for (keyseq::const_iterator i = v->begin(); i != v->end(); ++i)
     {
         if (*i <= 32 || *i > 127)
         {
@@ -503,11 +503,11 @@ static void macro_buf_add_long(keyseq actions,
     // the sequence "abcdef" and macros "ab", "bcde" and "de"
     // "ab" and "de" are recognised as macros.
 
-    while (actions.size() > 0)
+    while (!actions.empty())
     {
         tmp = actions;
 
-        while (tmp.size() > 0)
+        while (!tmp.empty())
         {
             macromap::const_iterator subst = keymap.find(tmp);
             // Found a macro. Add the expansion (action) of the
@@ -523,7 +523,7 @@ static void macro_buf_add_long(keyseq actions,
             tmp.pop_back();
         }
 
-        if (tmp.size() == 0)
+        if (tmp.empty())
         {
             // Didn't find a macro. Add the first keypress of the sequence
             // into the buffer, remove it from the sequence, and try again.
@@ -575,6 +575,11 @@ bool is_processing_macro()
     return (macro_keys_left >= 0);
 }
 
+bool has_pending_input()
+{
+    return !Buffer.empty() && !SendKeysBuffer.empty();
+}
+
 /*
  * Command macros are only applied from the immediate front of the
  * buffer, and only when the game is expecting a command.
@@ -587,7 +592,7 @@ static void macro_buf_apply_command_macro()
     keyseq tmp = Buffer;
 
     // find the longest match from the start of the buffer and replace it
-    while (tmp.size() > 0)
+    while (!tmp.empty())
     {
         macromap::const_iterator expansion = Macros.find(tmp);
 
@@ -621,7 +626,7 @@ int macro_buf_get()
 
     _macro_inject_sent_keys();
 
-    if (Buffer.size() == 0)
+    if (Buffer.empty())
     {
         // If we're trying to fetch a new keystroke, then the processing
         // of the previous keystroke is complete.
@@ -647,7 +652,7 @@ int macro_buf_get()
 
 static void write_map(FILE *f, const macromap &mp, const char *key)
 {
-    for (macromap::const_iterator i = mp.begin(); i != mp.end(); i++)
+    for (macromap::const_iterator i = mp.begin(); i != mp.end(); ++i)
     {
         // Need this check, since empty values are added into the
         // macro struct for all used keyboard commands.
@@ -760,7 +765,7 @@ int getch_with_command_macros()
 {
     _macro_inject_sent_keys();
 
-    if (Buffer.size() == 0)
+    if (Buffer.empty())
     {
         // Read some keys...
         keyseq keys = _getch_mul();
@@ -1023,7 +1028,7 @@ static void _read_macros_from(const char* filename)
         s = f.get_line();
         trim_string(s);  // remove white space from ends
 
-        if (s[0] == '#')
+        if (s.empty() || s[0] == '#')
             continue;    // skip comments
         else if (s.substr(0, 2) == "K:")
         {
@@ -1141,7 +1146,7 @@ void remove_key_recorder(key_recorder* recorder)
 {
     std::vector<key_recorder*>::iterator i;
 
-    for (i = recorders.begin(); i != recorders.end(); i++)
+    for (i = recorders.begin(); i != recorders.end(); ++i)
         if (*i == recorder)
         {
             recorders.erase(i);
