@@ -309,7 +309,8 @@ struct keyed_mapspec;
 class map_lines
 {
 public:
-    class iterator {
+    class iterator
+    {
     public:
         iterator(map_lines &ml, const std::string &key);
         operator bool () const;
@@ -665,6 +666,8 @@ class mons_spec
     std::vector<monster_spells> spells;
     uint64_t extra_monster_flags;
 
+    monster_type initial_shifter;
+
     CrawlHashTable props;
 
     mons_spec(int id = RANDOM_MONSTER,
@@ -678,7 +681,7 @@ class mons_spec
           colour(BLACK), god(GOD_NO_GOD), god_gift(false), hd(0), hp(0),
           abjuration_duration(0), summon_type(0), items(), monname(""),
           non_actor_summoner(""), explicit_spells(false), spells(),
-          extra_monster_flags(0), props()
+          extra_monster_flags(0), initial_shifter(RANDOM_MONSTER), props()
     {
     }
 };
@@ -700,6 +703,7 @@ public:
     std::string add_mons(const std::string &s, bool fix_slot = false);
     std::string set_mons(int slot, const std::string &s);
 
+    bool empty()               const { return mons.empty(); }
     size_t size()              const { return mons.size(); }
     size_t slot_size(int slot) const { return mons[slot].mlist.size(); }
 
