@@ -15,7 +15,7 @@
 #include "defines.h"
 #include "libutil.h"
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
  #include "tilebuf.h"
  #include "tiledoll.h"
 #endif
@@ -76,7 +76,7 @@ public:
     bool preselected;
     void *data;
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     std::vector<tile_def> tiles;
 #endif
 
@@ -158,7 +158,7 @@ public:
         return get_text();
     }
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual bool get_tiles(std::vector<tile_def>& tileset) const;
 
     virtual void add_tile(tile_def tile);
@@ -185,12 +185,12 @@ class MonsterMenuEntry : public MenuEntry
 public:
     MonsterMenuEntry(const std::string &str, const monster* mon, int hotkey);
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual bool get_tiles(std::vector<tile_def>& tileset) const;
 #endif
 };
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
 class PlayerMenuEntry : public MenuEntry
 {
 public:
@@ -210,7 +210,7 @@ public:
     FeatureMenuEntry(const std::string &str, const dungeon_feature_type f,
                      int hotkey);
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual bool get_tiles(std::vector<tile_def>& tileset) const;
 #endif
 };
@@ -534,6 +534,7 @@ public:
     virtual void set_bounds(const coord_def& min_coord, const coord_def& max_coord);
     virtual void set_bounds_no_multiply(const coord_def& min_coord,
                                          const coord_def& max_coord);
+    virtual void move(const coord_def& delta);
     virtual const coord_def& get_min_coord() const { return m_min_coord; }
     virtual const coord_def& get_max_coord() const { return m_max_coord; }
 
@@ -590,7 +591,7 @@ protected:
     MenuItem* m_link_up;
     MenuItem* m_link_down;
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     // Holds the conversion values to translate unit values to pixel values
     unsigned int m_unit_width_pixels;
     unsigned int m_unit_height_pixels;
@@ -623,7 +624,7 @@ protected:
     std::string m_text;
     std::string m_render_text;
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     FontBuffer m_font_buf;
 #endif
 };
@@ -642,11 +643,11 @@ public:
 };
 
 /**
- * Behaves the same as NoSelectTextItem but use formatted text for rendering.
+ * Behaves the same as TextItem but use formatted text for rendering.
  * It ignores bg_colour.
  * TODO: add bg_colour support to formatted_string and merge this with TextItem.
  */
-class FormattedTextItem : public NoSelectTextItem
+class FormattedTextItem : public TextItem
 {
 public:
     virtual void render();
@@ -655,7 +656,7 @@ public:
 /**
  * Holds an arbitary number of tiles, currently rendered on top of each other
  */
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
 class TextTileItem : public TextItem
 {
 public:
@@ -736,7 +737,7 @@ public:
     virtual bool can_be_focused();
 
     virtual InputReturnValue process_input(int key) = 0;
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual InputReturnValue handle_mouse(const MouseEvent& me) = 0;
 #endif
     virtual void render() = 0;
@@ -760,7 +761,8 @@ public:
     virtual bool attach_item(MenuItem* item) = 0;
 
 protected:
-    enum Direction{
+    enum Direction
+    {
         UP,
         DOWN,
         LEFT,
@@ -783,7 +785,7 @@ protected:
     // if you need a different behaviour, pleare override the
     // affected methods
     std::vector<MenuItem*> m_entries;
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     // Holds the conversion values to translate unit values to pixel values
     unsigned int m_unit_width_pixels;
     unsigned int m_unit_height_pixels;
@@ -802,7 +804,7 @@ public:
     virtual ~MenuFreeform();
 
     virtual InputReturnValue process_input(int key);
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual InputReturnValue handle_mouse(const MouseEvent& me);
 #endif
     virtual void render();
@@ -842,7 +844,7 @@ public:
     virtual ~MenuScroller();
 
     virtual InputReturnValue process_input(int key);
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual InputReturnValue handle_mouse(const MouseEvent& me);
 #endif
     virtual void render();
@@ -882,7 +884,7 @@ public:
               const std::string& name);
 
     virtual InputReturnValue process_input(int key);
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual InputReturnValue handle_mouse(const MouseEvent& me);
 #endif
     virtual void render();
@@ -918,7 +920,7 @@ protected:
 };
 
 /**
- * Class for mouse over tooltips, does nothing if USE_TILE is not defined
+ * Class for mouse over tooltips, does nothing if USE_TILE_LOCAL is not defined
  * TODO: actually implement render() and _place_items()
  */
 class MenuTooltip : public MenuDescriptor
@@ -927,14 +929,14 @@ public:
     MenuTooltip(PrecisionMenu* parent);
     virtual ~MenuTooltip();
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual InputReturnValue handle_mouse(const MouseEvent& me);
 #endif
     virtual void render();
 protected:
     virtual void _place_items();
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     ShapeBuffer m_background;
     FontBuffer m_font_buf;
 #endif
@@ -953,7 +955,7 @@ public:
     virtual ~BoxMenuHighlighter();
 
     virtual InputReturnValue process_input(int key);
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual InputReturnValue handle_mouse(const MouseEvent& me);
 #endif
     virtual void render();
@@ -986,7 +988,7 @@ protected:
     PrecisionMenu* m_parent;
     MenuItem* m_active_item;
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     LineBuffer m_line_buf;
 #else
     COLORS m_old_bg_colour;
@@ -1003,7 +1005,7 @@ public:
 protected:
     virtual void _place_items();
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     // Tiles does not seem to support background colors
     ShapeBuffer m_shape_buf;
 #endif
@@ -1047,7 +1049,7 @@ public:
 
     virtual void draw_menu();
     virtual bool process_key(int key);
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     virtual int handle_mouse(const MouseEvent& me);
 #endif
 
@@ -1060,7 +1062,8 @@ public:
     virtual void set_active_object(MenuObject* object);
 protected:
     // These correspond to the Arrow keys when used for browsing the menus
-    enum Direction{
+    enum Direction
+    {
         UP,
         DOWN,
         LEFT,
@@ -1075,8 +1078,7 @@ protected:
     SelectType m_select_type;
 };
 
-int linebreak_string(std::string& s, int wrapcol, int maxcol);
-int linebreak_string2(std::string& s, int maxcol);
+int linebreak_string(std::string& s, int maxcol);
 std::string get_linebreak_string(const std::string& s, int maxcol);
 
 #endif
