@@ -23,7 +23,6 @@
 #include "showsymb.h"
 #include "stash.h"
 #include "state.h"
-#include "stuff.h"
 #include "areas.h"
 #include "tags.h"
 #include "tagstring.h"
@@ -250,16 +249,16 @@ glyph prefix_glyph(prefix_type p)
     switch (p)
     {
     case P_TURN_START:
-        g.ch = '-';
+        g.ch = Options.show_newturn_mark ? '-' : ' ';
         g.col = LIGHTGRAY;
         break;
     case P_TURN_END:
     case P_NEW_TURN:
-        g.ch = '_';
+        g.ch = Options.show_newturn_mark ? '_' : ' ';
         g.col = LIGHTGRAY;
         break;
     case P_NEW_CMD:
-        g.ch = '_';
+        g.ch = Options.show_newturn_mark ? '_' : ' ';
         g.col = DARKGRAY;
         break;
     case P_FULL_MORE:
@@ -309,7 +308,7 @@ class message_window
     {
         cgotoxy(1, n + 1, GOTO_MSG);
         line.display();
-        cprintf("%*s", width() - line.length(), "");
+        cprintf("%*s", width() - line.width(), "");
     }
 
     // Place cursor at end of last non-empty line to handle prompts.
@@ -318,9 +317,9 @@ class message_window
     void place_cursor() const
     {
         int i;
-        for (i = lines.size() - 1; i >= 0 && lines[i].length() == 0; --i);
-        if (i >= 0 && (int) lines[i].length() < crawl_view.msgsz.x)
-            cgotoxy(lines[i].length() + 1, i + 1, GOTO_MSG);
+        for (i = lines.size() - 1; i >= 0 && lines[i].width() == 0; --i);
+        if (i >= 0 && (int) lines[i].width() < crawl_view.msgsz.x)
+            cgotoxy(lines[i].width() + 1, i + 1, GOTO_MSG);
     }
 
     // Whether to show msgwin-full more prompts.
@@ -384,7 +383,8 @@ class message_window
         {
             formatted_string line;
             line.add_glyph(prefix_glyph(prompt));
-            line += lines[next_line-1].substr(1);
+            lines[next_line-1].del_char();
+            line += lines[next_line-1];
             lines[next_line-1] = line;
         }
         show();
@@ -479,7 +479,7 @@ public:
         prompt = P_NONE; // reset prompt
 
         std::vector<formatted_string> newlines;
-        linebreak_string2(text, out_width());
+        linebreak_string(text, out_width());
         formatted_string::parse_string_to_multiple(text, newlines);
 
         for (size_t i = 0; i < newlines.size(); ++i)
@@ -1110,8 +1110,8 @@ unsigned int msgwin_lines()
 
 // mpr() an arbitrarily long list of strings without truncation or risk
 // of overflow.
-void mpr_comma_separated_list(const std::string prefix,
-                              const std::vector<std::string> list,
+void mpr_comma_separated_list(const std::string &prefix,
+                              const std::vector<std::string> &list,
                               const std::string &andc,
                               const std::string &comma,
                               const msg_channel_type channel,
@@ -1401,14 +1401,14 @@ void replay_messages(void)
     formatted_scroller hist(MF_START_AT_END | MF_ALWAYS_SHOW_MORE, "");
     hist.set_more(formatted_string::parse_string(
                         "<cyan>[up/<< : Page up.    down/Space/> : Page down."
-                        "                           Esc exits.]</cyan>"));
+                        "                         Esc exits.]</cyan>"));
 
     const store_t msgs = messages.get_store();
     for (int i = 0; i < msgs.size(); ++i)
         if (channel_message_history(msgs[i].channel))
         {
             std::string text = msgs[i].with_repeats();
-            linebreak_string2(text, cgetsize(GOTO_CRT).x - 1);
+            linebreak_string(text, cgetsize(GOTO_CRT).x - 1);
             std::vector<formatted_string> parts;
             formatted_string::parse_string_to_multiple(text, parts);
             for (unsigned int j = 0; j < parts.size(); ++j)
