@@ -36,8 +36,8 @@ void formatted_message_history(const std::string &st,
                                int wrap_col = 0);
 
 // mpr() an arbitrarily long list of strings
-void mpr_comma_separated_list(const std::string prefix,
-                              const std::vector<std::string> list,
+void mpr_comma_separated_list(const std::string &prefix,
+                              const std::vector<std::string> &list,
                               const std::string &andc = ", and ",
                               const std::string &comma = ", ",
                               const msg_channel_type channel = MSGCH_PLAIN,
