@@ -49,7 +49,7 @@ enum band_type
     BAND_BLINK_FROGS,
     BAND_SKELETAL_WARRIORS,
     BAND_DRACONIAN,
-    BAND_PANDEMONIUM_DEMON,
+    BAND_PANDEMONIUM_LORD,
     BAND_HARPIES,
     BAND_ILSUIW,
     BAND_AZRAEL,
