@@ -15,10 +15,6 @@
 #include <unistd.h>
 #endif
 
-#ifdef TARGET_COMPILER_MINGW
-#include <io.h>
-#endif
-
 #include <cstdlib>
 #include <cstdio>
 #include <cmath>
@@ -91,9 +87,9 @@
 static void _create_monster_hide(const item_def corpse)
 {
     // kiku_receive_corpses() creates corpses that are easily scummed
-    // for hides.  We prevent this by setting "DoNotDropHide" as an item
+    // for hides.  We prevent this by setting "never_hide" as an item
     // property of corpses it creates.
-    if (corpse.props.exists("DoNotDropHide"))
+    if (corpse.props.exists("never_hide"))
         return;
 
     int mons_class = corpse.plus;
@@ -174,7 +170,9 @@ void turn_corpse_into_chunks(item_def &item, bool bloodspatter,
     item.quantity  = 1 + random2(max_chunks);
     item.quantity  = stepdown_value(item.quantity, 4, 4, 12, 12);
 
-    if (you.species != SP_VAMPIRE)
+    if (is_bad_food(item))
+        item.flags |= ISFLAG_DROPPED;
+    else if (you.species != SP_VAMPIRE)
         item.flags &= ~(ISFLAG_THROWN | ISFLAG_DROPPED);
 
     // Happens after the corpse has been butchered.
@@ -1391,6 +1389,7 @@ bool go_berserk(bool intentional, bool potion)
     // Cutting the duration in half since berserk causes haste and hasted
     // actions have half the usual delay. This keeps player turns
     // approximately consistent withe previous versions. -cao
+    // Only 1.5 now, but I'm keeping the reduction as a nerf. -1KB
     int berserk_duration = (20 + random2avg(19,2)) / 2;
 
     you.increase_duration(DUR_BERSERK, berserk_duration);
@@ -1476,8 +1475,7 @@ bool mons_can_hurt_player(const monster* mon, const bool want_move)
     // still use some ranged form of attack.
     if (you.see_cell_no_trans(mon->pos())
         && (mons_itemuse(mon) >= MONUSE_STARTING_EQUIPMENT
-            || mons_has_ranged_ability(mon)
-            || mons_has_ranged_spell(mon)))
+            || mons_has_ranged_attack(mon)))
     {
         return (true);
     }
@@ -1745,7 +1743,6 @@ static void _drop_tomb(const coord_def& pos, bool premature)
     bool seen_change = false;
     for (adjacent_iterator ai(pos); ai; ++ai)
     {
-
         // "Normal" tomb
         if (grd(*ai) == DNGN_ROCK_WALL &&
             env.markers.property_at(*ai, MAT_ANY, "prison") != "Zin")
@@ -1793,7 +1790,8 @@ static void _drop_tomb(const coord_def& pos, bool premature)
             (mon) ? "releases" : "dismisses",
             (mon) ? mon->name(DESC_NOCAP_THE).c_str() : "the silver walls,",
             (mon) ? "from its prison" : "but there is nothing inside them");
-        else {
+        else
+        {
             if (!silenced(you.pos()))
                 mpr("You hear a deep rumble.", MSGCH_SOUND);
             else
@@ -1994,6 +1992,8 @@ void bring_to_safety()
 // This includes ALL afflictions, unlike wizard/Xom revive.
 void revive()
 {
+    adjust_level(-1);
+
     you.disease = 0;
     you.magic_contamination = 0;
     set_hunger(6000, true);
@@ -2030,13 +2030,21 @@ void revive()
     you.stat_zero.init(0);
 
     unrot_hp(9999);
-    set_hp(9999, false);
-    set_mp(9999, false);
+    set_hp(9999);
+    set_mp(9999);
     you.dead = false;
 
     // Remove silence.
     invalidate_agrid();
 
+    if (you.hp_max <= 0)
+    {
+        you.lives = 0;
+        mpr("You are too frail to live.");
+        // possible only with an extreme abuse of Borgnjor's
+        ouch(INSTANT_DEATH, NON_MONSTER, KILLED_BY_DRAINING);
+    }
+
     mpr("You rejoin the land of the living...");
     more();
 }
@@ -2068,9 +2076,7 @@ void setup_environment_effects()
             }
         }
     }
-#ifdef DEBUG_DIAGNOSTICS
-    mprf(MSGCH_DIAGNOSTICS, "%u environment effect seeds", sfx_seeds.size());
-#endif
+    dprf("%u environment effect seeds", (unsigned int)sfx_seeds.size());
 }
 
 static void apply_environment_effect(const coord_def &c)
@@ -2193,13 +2199,17 @@ std::string your_hand(bool plural)
     case TRAN_STATUE:
     case TRAN_LICH:
         result = (you.has_usable_claws()) ? "claw" : "hand";
-        if (you.species == SP_CAT)
+        if (you.species == SP_FELID)
             result = "paw";
+        if (you.species == SP_OCTOPODE)
+            result = "tentacle";
         break;
     case TRAN_ICE_BEAST:
         result = "hand";
-        if (you.species == SP_CAT)
+        if (you.species == SP_FELID)
             result = "paw";
+        if (you.species == SP_OCTOPODE)
+            result = "tentacle";
         break;
     case TRAN_SPIDER:
     case TRAN_PIG:
@@ -2430,9 +2440,9 @@ void swap_with_monster(monster* mon_to_swap)
             you.redraw_quiver = true; // Account for being in a net.
             // Xom thinks this is hilarious if you trap yourself this way.
             if (you_caught)
-                xom_is_stimulated(16);
+                xom_is_stimulated(12);
             else
-                xom_is_stimulated(255);
+                xom_is_stimulated(200);
         }
 
         if (!you_caught)
@@ -2451,8 +2461,11 @@ void maybe_id_ring_TC()
     }
 
     int num_unknown = 0;
-    for (int i = EQ_LEFT_RING; i <= EQ_RIGHT_RING; ++i)
+    for (int i = EQ_LEFT_RING; i < NUM_EQUIP; ++i)
     {
+        if (i == EQ_AMULET)
+            continue;
+
         if (player_wearing_slot(i)
             && !item_ident(you.inv[you.equip[i]], ISFLAG_KNOW_PROPERTIES))
         {
@@ -2460,10 +2473,14 @@ void maybe_id_ring_TC()
         }
     }
 
-    if (num_unknown != 1)
+    if (num_unknown == 0)
         return;
 
-    for (int i = EQ_LEFT_RING; i <= EQ_RIGHT_RING; ++i)
+    for (int i = EQ_LEFT_RING; i < NUM_EQUIP; ++i)
+    {
+        if (i == EQ_AMULET)
+            continue;
+
         if (player_wearing_slot(i))
         {
             item_def& ring = you.inv[you.equip[i]];
@@ -2476,6 +2493,29 @@ void maybe_id_ring_TC()
                      ring.name(DESC_INVENTORY_EQUIP).c_str());
             }
         }
+    }
+}
+
+// Reduce damage by AC.
+// In most cases, we want AC to mostly stop weak attacks completely but affect
+// strong ones less, but the regular formula is too hard to apply well to cases
+// when damage is spread into many small chunks.
+//
+// Every point of damage is processed independently.  Every point of AC has
+// an independent 1/81 chance of blocking that damage.
+//
+// AC 20 stops 22% of damage, AC 40 -- 39%, AC 80 -- 63%.
+int apply_chunked_AC(int dam, int ac)
+{
+    double chance = pow(80.0/81, ac);
+    uint64_t cr = chance * (((uint64_t)1) << 32);
+
+    int hurt = 0;
+    for (int i = 0; i < dam; i++)
+        if (random_int() < cr)
+            hurt++;
+
+    return hurt;
 }
 
 void entered_malign_portal(actor* act)
@@ -2507,3 +2547,13 @@ std::string part_stack_string(const int num, const int total)
 
     return ret;
 }
+
+unsigned int breakpoint_rank(int val, const int breakpoints[],
+                             unsigned int num_breakpoints)
+{
+    unsigned int result = 0;
+    while (result < num_breakpoints && val >= breakpoints[result])
+        ++result;
+
+    return result;
+}
