@@ -29,6 +29,7 @@ bool unsuitable_misled_monster(monster_type mons)
             || mons_class_is_zombified(mons)
             || mons_is_tentacle(mons)
             || mons_class_flag(mons, M_NO_POLY_TO)
+            || mons_class_flag(mons, M_UNFINISHED)
             || mons_genus(mons) == MONS_DRACONIAN
             || mons == MONS_MANTICORE
             || mons == MONS_SLIME_CREATURE
@@ -39,7 +40,7 @@ bool unsuitable_misled_monster(monster_type mons)
             || mons == MONS_SHAPESHIFTER
             || mons == MONS_GLOWING_SHAPESHIFTER
             || mons == MONS_KILLER_KLOWN
-            || mons == MONS_MEGABAT);
+            || mons == MONS_BAT);
 }
 
 monster_type get_misled_monster(monster* mons)
@@ -49,7 +50,7 @@ monster_type get_misled_monster(monster* mons)
         mt = random_monster_at_grid(mons->pos());
 
     if (unsuitable_misled_monster(mt))
-        return (MONS_MEGABAT);
+        return (MONS_BAT);
 
     return mt;
 }
@@ -68,7 +69,7 @@ bool update_mislead_monster(monster* mons)
     short misled_as = get_misled_monster(mons);
     mons->props["mislead_as"] = misled_as;
 
-    if (misled_as == MONS_MEGABAT)
+    if (misled_as == MONS_BAT)
         return (false);
 
     return (true);
