@@ -37,11 +37,8 @@ static void _give_monster_item(monster* mon, int thing,
     item_def &mthing = mitm[thing];
     ASSERT(mthing.defined());
 
-#ifdef DEBUG_DIAGNOSTICS
-    mprf(MSGCH_DIAGNOSTICS,
-         "Giving %s to %s...", mthing.name(DESC_PLAIN).c_str(),
+    dprf("Giving %s to %s...", mthing.name(DESC_PLAIN).c_str(),
          mon->name(DESC_PLAIN, true).c_str());
-#endif
 
     mthing.pos.reset();
     mthing.link = NON_ITEM;
@@ -79,11 +76,9 @@ static void _give_monster_item(monster* mon, int thing,
     if (!(pickupfn ? (mon->*pickupfn)(mthing, false)
                    : mon->pickup_item(mthing, false, true)))
     {
-#ifdef DEBUG_DIAGNOSTICS
-        mprf(MSGCH_DIAGNOSTICS, "Destroying %s because %s doesn't want it!",
+        dprf("Destroying %s because %s doesn't want it!",
              mthing.name(DESC_PLAIN, false, true).c_str(),
              mon->name(DESC_PLAIN, true).c_str());
-#endif
         destroy_item(thing, true);
         return;
     }
@@ -262,6 +257,12 @@ static item_make_species_type _give_weapon(monster* mon, int level,
                                            WPN_SHORT_SWORD, WPN_SHORT_SWORD,
                                            WPN_CLUB,        WPN_WHIP,       -1);
         }
+        else if (one_chance_in(30) && level > 2)
+        {
+            item.base_type = OBJ_WEAPONS;
+            item.sub_type  = WPN_CROSSBOW;
+            break;
+        }
         else
             return (item_race);
         break;
@@ -592,6 +593,7 @@ static item_make_species_type _give_weapon(monster* mon, int level,
     case MONS_YELLOW_DRACONIAN:
     case MONS_PURPLE_DRACONIAN:
     case MONS_GREY_DRACONIAN:
+    case MONS_KENKU:
         if (mons_genus(mon->type) == MONS_NAGA)
             item_race = MAKE_ITEM_NO_RACE;
 
@@ -880,8 +882,11 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         item.base_type = OBJ_WEAPONS;
         item.colour    = YELLOW;       // forced by force_item above {dlb}
 
-        item.sub_type  = (one_chance_in(4) ? WPN_EUDEMON_BLADE
-                                           : WPN_LONG_SWORD);
+        item.sub_type  = random_choose(WPN_EUDEMON_BLADE,
+                                       WPN_BLESSED_LONG_SWORD,
+                                       WPN_BLESSED_SCIMITAR,
+                                       WPN_BLESSED_FALCHION,
+                                       -1);
 
         set_equip_desc(item, ISFLAG_GLOWING);
         set_item_ego_type(item, OBJ_WEAPONS, SPWPN_HOLY_WRATH);
@@ -905,11 +910,10 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         if (x_chance_in_y(5, 9))
         {
             set_item_ego_type(item, OBJ_WEAPONS,
-                              random_choose_weighted(15, SPWPN_FLAMING,
-                                                     2, SPWPN_DRAINING,
-                                                     2, SPWPN_VORPAL,
+                              random_choose_weighted(13, SPWPN_FLAMING,
+                                                     4, SPWPN_DRAINING,
+                                                     4, SPWPN_VORPAL,
                                                      2, SPWPN_DISTORTION,
-                                                     2, SPWPN_SPEED,
                                                      2, SPWPN_PAIN,
                                                      0));
         }
@@ -947,11 +951,10 @@ static item_make_species_type _give_weapon(monster* mon, int level,
         if (x_chance_in_y(5, 9))
         {
             set_item_ego_type(item, OBJ_WEAPONS,
-                              random_choose_weighted(15, SPWPN_FLAMING,
-                                                     2, SPWPN_DRAINING,
-                                                     2, SPWPN_VORPAL,
+                              random_choose_weighted(13, SPWPN_FLAMING,
+                                                     4, SPWPN_DRAINING,
+                                                     4, SPWPN_VORPAL,
                                                      2, SPWPN_DISTORTION,
-                                                     2, SPWPN_SPEED,
                                                      2, SPWPN_PAIN,
                                                      0));
         }
@@ -1549,6 +1552,14 @@ void give_shield(monster* mon, int level)
                                   level, MAKE_ITEM_NO_RACE);
         }
         break;
+    case MONS_KENKU:
+        if (one_chance_in(3))
+        {
+            make_item_for_monster(mon, OBJ_ARMOUR,
+                                  coinflip()? ARM_BUCKLER : ARM_SHIELD,
+                                  level, MAKE_ITEM_NO_RACE);
+        }
+        break;
     case MONS_DEEP_ELF_KNIGHT:
         if (one_chance_in(3))
         {
