@@ -110,7 +110,9 @@ void monster::upgrade_type(monster_type after, bool adjust_hd,
 
     // Initialise a dummy monster to save work.
     monster dummy;
-    dummy.type = after;
+    dummy.type         = after;
+    dummy.base_monster = base_monster;
+    dummy.number       = number;
     define_monster(&dummy);
 
     colour = dummy.colour;
@@ -174,10 +176,8 @@ bool monster::level_up()
         // Not less than 3 hp, not more than 25.
         hpboost = std::min(std::max(hpboost, 3), 25);
 
-#ifdef DEBUG_DIAGNOSTICS
-        mprf(MSGCH_DIAGNOSTICS, "%s: HD: %d, maxhp: %d, boost: %d",
+        dprf("%s: HD: %d, maxhp: %d, boost: %d",
              name(DESC_PLAIN).c_str(), hit_dice, max_hit_points, hpboost);
-#endif
 
         max_hit_points += hpboost;
         hit_points     += hpboost;
