@@ -32,7 +32,6 @@
 
 int mons_tracking_range(const monster* mon)
 {
-
     int range = 0;
     switch (mons_intel(mon))
     {
@@ -356,10 +355,6 @@ std::vector<coord_def> monster_pathfind::calc_waypoints()
     if (path.empty())
         return path;
 
-    dungeon_feature_type can_move =
-        (mons_habitat(mons) == HT_AMPHIBIOUS) ? DNGN_DEEP_WATER
-                                              : DNGN_SHALLOW_WATER;
-
     std::vector<coord_def> waypoints;
     pos = path[0];
 
@@ -368,7 +363,7 @@ std::vector<coord_def> monster_pathfind::calc_waypoints()
 #endif
     for (unsigned int i = 1; i < path.size(); i++)
     {
-        if (can_go_straight(mons, pos, path[i], can_move)
+        if (can_go_straight(mons, pos, path[i])
             && mons_traversable(path[i]))
         {
             continue;
@@ -421,10 +416,23 @@ bool monster_pathfind::mons_traversable(const coord_def& p)
 
 int monster_pathfind::travel_cost(coord_def npos)
 {
+#ifdef EUCLIDEAN
+    int cost = 1;
+    if (mons)
+        cost = mons_travel_cost(npos);
+
+    if ((pos - npos).abs() == 2)
+        cost *= 14;
+    else
+        cost *= 10;
+
+    return cost;
+#else
     if (mons)
         return mons_travel_cost(npos);
 
     return (1);
+#endif
 }
 
 // Assumes that grids that really cannot be entered don't even get here.
