@@ -65,7 +65,8 @@ void alert_nearby_monsters(void);
 beh_type attitude_creation_behavior(mon_attitude_type att);
 beh_type actual_same_attitude(const monster& base);
 
-enum poly_power_type {
+enum poly_power_type
+{
     PPT_LESS,
     PPT_MORE,
     PPT_SAME,
@@ -104,8 +105,9 @@ void mons_check_pool(monster* mons, const coord_def &oldpos,
 void monster_cleanup(monster* mons);
 
 int dismiss_monsters(std::string pattern);
+void zap_los_monsters(bool items_also);
 
-bool curse_an_item(bool destroy_potions, bool quiet = false);
+bool curse_an_item(bool quiet = false);
 
 bool is_any_item(const item_def& item);
 void monster_drop_things(
@@ -172,7 +174,7 @@ void mons_relocated(monster* mons);
 void mons_att_changed(monster* mons);
 
 bool can_go_straight(const monster* mon, const coord_def& p1,
-                     const coord_def& p2, dungeon_feature_type allowed);
+                     const coord_def& p2);
 
 bool is_item_jelly_edible(const item_def &item);
 
@@ -189,15 +191,11 @@ std::string summoned_poof_msg(const monster* mons, const item_def &item);
 
 bool mons_reaped(actor *killer, monster* victim);
 
-actor* forest_near_enemy(const actor *mon);
-void forest_message(const coord_def pos, const std::string msg,
-                    msg_channel_type ch = MSGCH_PLAIN);
-void forest_damage(const actor *mon);
-
 struct bolt;
 
 void setup_spore_explosion(bolt & beam, const monster& origin);
 void setup_lightning_explosion(bolt & beam, const monster& origin);
+void setup_inner_flame_explosion(bolt & beam, const monster& origin);
 
 bool mons_avoids_cloud(const monster* mons, cloud_type cl_type,
                        bool placement = false);
