@@ -2,6 +2,7 @@
 #define MONSTER_H
 
 #include "actor.h"
+#include "bitary.h"
 
 const int KRAKEN_TENTACLE_RANGE = 3;
 #define TIDE_CALL_TURN "tide-call-turn"
@@ -92,6 +93,7 @@ public:
     unsigned short foe;
     int8_t ench_countdown;
     mon_enchant_list enchantments;
+    FixedBitArray<NUM_ENCHANTMENTS> ench_cache;
     uint64_t flags;                    // bitfield of boolean flags
 
     unsigned int experience;
@@ -168,7 +170,7 @@ public:
     // Has ENCH_SHAPESHIFTER or ENCH_GLOWING_SHAPESHIFTER.
     bool is_shapeshifter() const;
 
-    bool has_ench(enchant_type ench) const;
+    bool has_ench(enchant_type ench) const { return ench_cache[ench]; }
     bool has_ench(enchant_type ench, enchant_type ench2) const;
     mon_enchant get_ench(enchant_type ench,
                          enchant_type ench2 = ENCH_NONE) const;
@@ -347,6 +349,7 @@ public:
     int res_torment() const;
     int res_acid() const;
     int res_wind() const;
+    int res_petrify(bool temp = true) const;
     int res_magic() const;
 
     flight_type flight_mode() const;
@@ -405,7 +408,8 @@ public:
     bool sicken(int strength, bool unused = true);
     bool bleed(const actor *agent, int amount, int degree);
     void paralyse(actor *, int str);
-    void petrify(actor *, int str);
+    void petrify(actor *);
+    bool fully_petrify(actor *foe, bool quiet = false);
     void slow_down(actor *, int str);
     void confuse(actor *, int strength);
     bool drain_exp(actor *, bool quiet = false, int pow = 3);
