@@ -124,7 +124,10 @@ static bool _is_noteworthy(const Note& note)
         || note.type == NOTE_DEATH
         || note.type == NOTE_XOM_REVIVAL
         || note.type == NOTE_SEEN_FEAT
-        || note.type == NOTE_PARALYSIS)
+        || note.type == NOTE_PARALYSIS
+        || note.type == NOTE_NAMED_ALLY
+        || note.type == NOTE_ALLY_DEATH
+        || note.type == NOTE_BANISH_MONSTER)
     {
         return (true);
     }
@@ -245,7 +248,6 @@ static const char* _number_to_ordinal(int number)
 
 std::string Note::describe(bool when, bool where, bool what) const
 {
-
     std::ostringstream result;
 
     if (when)
@@ -396,6 +398,18 @@ std::string Note::describe(bool when, bool where, bool what) const
         case NOTE_PARALYSIS:
             result << "Paralysed by " << name << " for " << first << " turns";
             break;
+        case NOTE_NAMED_ALLY:
+            result << "Gained " << name << " as an ally";
+            break;
+        case NOTE_ALLY_DEATH:
+            result << "Your ally " << name << " died";
+            break;
+        case NOTE_BANISH_MONSTER:
+            if (second)
+                result << name << " (ally) was banished";
+            else
+                result << "Banished " << name;
+            break;
         default:
             result << "Buggy note description: unknown note type";
             break;
@@ -404,7 +418,7 @@ std::string Note::describe(bool when, bool where, bool what) const
 
     if (type == NOTE_SEEN_MONSTER || type == NOTE_KILL_MONSTER)
     {
-        if (what && first == MONS_PANDEMONIUM_DEMON)
+        if (what && first == MONS_PANDEMONIUM_LORD)
             result << " the pandemonium lord";
     }
     return result.str();
