@@ -47,6 +47,7 @@
 #include "viewchar.h"
 #include "viewgeom.h"
 #include "showsymb.h"
+#include "spl-transloc.h"
 
 #ifndef USE_TILE
 #include "directn.h"
@@ -199,7 +200,7 @@ void update_turn_count()
         return;
     }
 
-    cgotoxy(19+6, 9, GOTO_STAT);
+    cgotoxy(19+6, 9 + crawl_state.game_is_zotdef(), GOTO_STAT);
 
     // Show the turn count starting from 1. You can still quit on turn 0.
     textcolor(HUD_VALUE_COLOUR);
@@ -409,8 +410,14 @@ static void _print_stats_wp(int y)
     {
         const std::string prefix = "-) ";
         col = LIGHTGREY;
-        text = you.has_usable_claws(true) ? "Claws" : "Nothing wielded";
-        if (you.species == SP_CAT)
+        text = "Nothing wielded"; // Default
+
+        if (you.has_usable_claws(true))
+            text = "Claws";
+        if (you.has_usable_tentacles(true))
+            text = "Tentacles";
+
+        if (you.species == SP_FELID)
             text = "Teeth and claws";
 
         switch (you.form)
@@ -425,7 +432,12 @@ static void _print_stats_wp(int y)
                 break;
             case TRAN_STATUE:
                 col = LIGHTGREY;
-                text = you.has_usable_claws(true) ? "Stone claws" : "Stone fists";
+                if (you.has_usable_claws(true))
+                    text = "Stone claws";
+                else if (you.has_usable_tentacles(true))
+                    text = "Stone tentacles";
+                else
+                    text = "Stone fists";
                 break;
             case TRAN_ICE_BEAST:
                 col = WHITE;
@@ -449,8 +461,7 @@ static void _print_stats_wp(int y)
                 break;
         }
 
-    text = prefix + text;
-
+        text = prefix + text;
     }
 
     cgotoxy(1, y, GOTO_STAT);
@@ -551,21 +562,66 @@ static void _get_status_lights(std::vector<status_light>& out)
 
     const int statuses[] = {
         STATUS_STR_ZERO, STATUS_INT_ZERO, STATUS_DEX_ZERO,
-        STATUS_BURDEN, STATUS_HUNGER, DUR_JELLY_PRAYER, DUR_TELEPORT,
-        DUR_DEATHS_DOOR, DUR_QUAD_DAMAGE, DUR_DEFLECT_MISSILES,
-        DUR_REPEL_MISSILES, STATUS_REGENERATION, DUR_BERSERK,
-        DUR_RESIST_POISON, DUR_RESIST_COLD, DUR_RESIST_FIRE,
-        DUR_INSULATION, DUR_SEE_INVISIBLE,
-        STATUS_AIRBORNE, DUR_INVIS, DUR_CONTROL_TELEPORT, DUR_SILENCE,
-        DUR_CONFUSING_TOUCH, DUR_BARGAIN, DUR_SAGE, DUR_FIRE_SHIELD,
-        DUR_SLIMIFY, DUR_SURE_BLADE, DUR_CONF, DUR_LOWERED_MR,
-        STATUS_BEHELD, DUR_LIQUID_FLAMES, DUR_MISLED, DUR_POISONING,
-        STATUS_SICK, STATUS_ROT, STATUS_NET, STATUS_GLOW, DUR_SWIFTNESS,
-        STATUS_SPEED, DUR_DEATH_CHANNEL, DUR_TELEPATHY, DUR_STEALTH,
-        DUR_BREATH_WEAPON, DUR_EXHAUSTED, DUR_POWERED_BY_DEATH,
-        DUR_TRANSFORMATION, DUR_AFRAID, DUR_MIRROR_DAMAGE, DUR_SCRYING,
-        STATUS_CLINGING, DUR_TORNADO, DUR_LIQUEFYING, DUR_HEROISM,
-        DUR_FINESSE, DUR_LIFESAVING, DUR_DARKNESS,
+        STATUS_BURDEN,
+        STATUS_HUNGER,
+        DUR_PETRIFYING,
+        DUR_PETRIFIED,
+        DUR_PARALYSIS,
+        DUR_JELLY_PRAYER,
+        DUR_TELEPORT,
+        DUR_DEATHS_DOOR,
+        DUR_QUAD_DAMAGE,
+        DUR_DEFLECT_MISSILES,
+        DUR_REPEL_MISSILES,
+        STATUS_REGENERATION,
+        DUR_BERSERK,
+        DUR_RESIST_POISON,
+        DUR_RESIST_COLD,
+        DUR_RESIST_FIRE,
+        DUR_INSULATION,
+        DUR_SEE_INVISIBLE,
+        STATUS_AIRBORNE,
+        DUR_INVIS,
+        DUR_CONTROL_TELEPORT,
+        DUR_SILENCE,
+        DUR_CONFUSING_TOUCH,
+        DUR_BARGAIN,
+        DUR_SAGE,
+        DUR_FIRE_SHIELD,
+        DUR_SLIMIFY,
+        DUR_SURE_BLADE,
+        DUR_CONF,
+        DUR_LOWERED_MR,
+        STATUS_BEHELD,
+        DUR_LIQUID_FLAMES,
+        DUR_MISLED,
+        DUR_POISONING,
+        STATUS_SICK,
+        STATUS_ROT,
+        STATUS_NET,
+        STATUS_GLOW,
+        DUR_SWIFTNESS,
+        STATUS_SPEED,
+        DUR_DEATH_CHANNEL,
+        DUR_TELEPATHY,
+        DUR_STEALTH,
+        DUR_BREATH_WEAPON,
+        DUR_EXHAUSTED,
+        DUR_POWERED_BY_DEATH,
+        DUR_TRANSFORMATION,
+        DUR_AFRAID,
+        DUR_MIRROR_DAMAGE,
+        DUR_SCRYING,
+        STATUS_CLINGING,
+        DUR_TORNADO,
+        DUR_LIQUEFYING,
+        DUR_HEROISM,
+        DUR_FINESSE,
+        DUR_LIFESAVING,
+        DUR_DARKNESS,
+        STATUS_FIREBALL,
+        DUR_SHROUD_OF_GOLUBRIA,
+        DUR_TORNADO_COOLDOWN,
     };
 
     status_info inf;
@@ -578,6 +634,8 @@ static void _get_status_lights(std::vector<status_light>& out)
             out.push_back(sl);
         }
     }
+    if(!allow_control_teleport(true) && Options.show_no_ctele)
+        out.push_back(status_light(RED,"-cTele"));
 }
 
 static void _print_status_lights(int y)
@@ -585,7 +643,7 @@ static void _print_status_lights(int y)
     std::vector<status_light> lights;
     static int last_number_of_lights = 0;
     _get_status_lights(lights);
-    if (lights.size() == 0 && last_number_of_lights == 0)
+    if (lights.empty() && last_number_of_lights == 0)
         return;
     last_number_of_lights = lights.size();
 
@@ -638,6 +696,17 @@ static bool _need_stats_printed()
 }
 #endif
 
+static std::string _get_exp_progress()
+{
+    if (you.experience_level >= 27)
+        return "";
+
+    const int current = exp_needed(you.experience_level);
+    const int next    = exp_needed(you.experience_level + 1);
+    return make_stringf("%2d%%",
+                        (you.experience - current) * 100 / (next - current));
+}
+
 void print_stats(void)
 {
     cursor_control coff(false);
@@ -674,32 +743,38 @@ void print_stats(void)
         cprintf("XP: ");
         textcolor(HUD_VALUE_COLOUR);
         cprintf("%d/%d (%d) ",
-                you.skill_cost_level, you.exp_available, you.experience);
+                you.experience_level, you.skill_cost_level, you.exp_available);
 #else
         cprintf("XL: ");
         textcolor(HUD_VALUE_COLOUR);
         cprintf("%2d ", you.experience_level);
-        textcolor(Options.status_caption_colour);
-        cprintf("Exp: ");
-        textcolor(HUD_VALUE_COLOUR);
-        if (you.exp_available < 100000)
-            cprintf("%-5d", you.exp_available);
-        else if (you.exp_available < 10000000)
-            cprintf("%4dK", you.exp_available / 1000);
-        else
-            cprintf("%4dM", you.exp_available / 1000000);
+        if (you.experience_level < 27)
+        {
+            textcolor(Options.status_caption_colour);
+            cprintf("Next: ");
+            textcolor(HUD_VALUE_COLOUR);
+            cprintf("%s ", _get_exp_progress().c_str());
+        }
 #endif
+        if (crawl_state.game_is_zotdef())
+        {
+            cgotoxy(1, 9, GOTO_STAT);
+            textcolor(Options.status_caption_colour);
+            cprintf("ZP: ");
+            textcolor(HUD_VALUE_COLOUR);
+            cprintf("%d     ", you.zot_points);
+        }
         you.redraw_experience = false;
     }
 
-    int yhack = 0;
+    int yhack = crawl_state.game_is_zotdef();
 
     // If Options.show_gold_turns, line 9 is Gold and Turns
     if (Options.show_gold_turns)
     {
         // Increase y-value for all following lines.
-        yhack = 1;
-        cgotoxy(1+6, 9, GOTO_STAT);
+        yhack++;
+        cgotoxy(1+6, 8 + yhack, GOTO_STAT);
         textcolor(HUD_VALUE_COLOUR);
         cprintf("%-6d", you.gold);
     }
@@ -720,7 +795,7 @@ void print_stats(void)
     }
     you.wield_change  = false;
 
-    if (you.species == SP_CAT)
+    if (you.species == SP_FELID)
     {
         // There are no circumstances under which Felids could quiver something.
         // Reduce line counter for status display.y
@@ -885,8 +960,9 @@ void draw_border(void)
 
     if (Options.show_gold_turns)
     {
-        cgotoxy(1, 9, GOTO_STAT); cprintf("Gold:");
-        cgotoxy(19, 9, GOTO_STAT); cprintf("Turn:");
+        int yhack = crawl_state.game_is_zotdef();
+        cgotoxy(1, 9 + yhack, GOTO_STAT); cprintf("Gold:");
+        cgotoxy(19, 9 + yhack, GOTO_STAT); cprintf("Turn:");
     }
     // Line 8 is exp pool, Level
 }
@@ -1197,7 +1273,9 @@ int update_monster_pane()
 
 static const char* _itosym1(int stat)
 {
-    return ((stat >= 1) ? "+  " : ".  ");
+    return ((stat >= 1) ? "+  " :
+            (stat == 0) ? ".  " :
+                          "x  ");
 }
 
 static const char* _itosym2(int stat)
@@ -1222,12 +1300,18 @@ static const char *s_equip_slot_names[] =
 {
     "Weapon", "Cloak",  "Helmet", "Gloves", "Boots",
     "Shield", "Armour", "Left Ring", "Right Ring", "Amulet",
+    "First Ring", "Second Ring", "Third Ring", "Fourth Ring",
+    "Fifth Ring", "Sixth Ring", "Seventh Ring", "Eighth Ring",
 };
 
 const char *equip_slot_to_name(int equip)
 {
-    if (equip == EQ_RINGS || equip == EQ_LEFT_RING || equip == EQ_RIGHT_RING)
+    if (equip == EQ_RINGS
+        || equip == EQ_LEFT_RING || equip == EQ_RIGHT_RING
+        || equip >= EQ_RING_ONE && equip <= EQ_RING_EIGHT)
+    {
         return "Ring";
+    }
 
     if (equip == EQ_BOOTS
         && (you.species == SP_CENTAUR || you.species == SP_NAGA))
@@ -1284,7 +1368,9 @@ static void _print_overview_screen_equip(column_composer& cols,
     const int e_order[] =
     {
         EQ_WEAPON, EQ_BODY_ARMOUR, EQ_SHIELD, EQ_HELMET, EQ_CLOAK,
-        EQ_GLOVES, EQ_BOOTS, EQ_AMULET, EQ_RIGHT_RING, EQ_LEFT_RING
+        EQ_GLOVES, EQ_BOOTS, EQ_AMULET, EQ_RIGHT_RING, EQ_LEFT_RING,
+        EQ_RING_ONE, EQ_RING_TWO, EQ_RING_THREE, EQ_RING_FOUR,
+        EQ_RING_FIVE, EQ_RING_SIX, EQ_RING_SEVEN, EQ_RING_EIGHT,
     };
 
     char buf[100];
@@ -1292,6 +1378,22 @@ static void _print_overview_screen_equip(column_composer& cols,
     {
         int eqslot = e_order[i];
 
+        if (you.species == SP_OCTOPODE
+            && e_order[i] != EQ_WEAPON
+            && !you_can_wear(e_order[i], true))
+        {
+            continue;
+        }
+
+        if (you.species == SP_OCTOPODE && (eqslot == EQ_RIGHT_RING
+                                       || eqslot == EQ_LEFT_RING))
+        {
+            continue;
+        }
+
+        if (you.species != SP_OCTOPODE && eqslot > EQ_AMULET)
+            continue;
+
         char slot_name_lwr[15];
         snprintf(slot_name_lwr, sizeof slot_name_lwr, "%s",
                  equip_slot_to_name(eqslot));
@@ -1440,7 +1542,7 @@ static std::string _god_powers(bool simple)
     std::string godpowers = simple ? "" : god_name(you.religion) ;
     if (you.religion == GOD_XOM)
     {
-        if (you.gift_timeout == 0)
+        if (!you.gift_timeout)
             godpowers += simple ? "- BORED" : " - BORED";
         else if (you.gift_timeout == 1)
             godpowers += simple ? "- getting BORED" : " - getting BORED";
@@ -1622,7 +1724,7 @@ static std::vector<formatted_string> _get_overview_stats()
 #endif
 
     char lives[40];
-    if (you.species == SP_CAT)
+    if (you.species == SP_FELID)
     {
         snprintf(lives, sizeof(lives), "Lives: %d, deaths: %d",
                  you.lives, you.deaths);
@@ -1630,15 +1732,15 @@ static std::vector<formatted_string> _get_overview_stats()
     else
         lives[0] = 0;
 
-    int xp_needed = (exp_needed(you.experience_level + 1) - you.experience) + 1;
     snprintf(buf, sizeof buf,
-             "Exp: %d/%u (%d)%s\n"
+             "XL: %d%s\n"
              "God: %s\n"
              "Spells: %2d memorised, %2d level%s left\n"
              "%s",
-             you.experience_level, you.experience, you.exp_available,
-             (you.experience_level < 27?
-              make_stringf(", need: %d", xp_needed).c_str() : ""),
+             you.experience_level,
+             (you.experience_level < 27 ? make_stringf("   Next: %s",
+                                           _get_exp_progress().c_str()).c_str()
+                                        : ""),
              godpowers.c_str(),
              you.spell_no, player_spell_levels(),
              (player_spell_levels() == 1) ? "" : "s",
@@ -1734,7 +1836,9 @@ static std::vector<formatted_string> _get_overview_resistances(
     cols.add_formatted(1, buf, false);
 
     const int stasis = wearing_amulet(AMU_STASIS, calc_unid);
-    const int notele = scan_artefacts(ARTP_PREVENT_TELEPORTATION, calc_unid);
+    const int notele = scan_artefacts(ARTP_PREVENT_TELEPORTATION, calc_unid)
+                       || crawl_state.game_is_zotdef()
+                          && you.char_direction == GDT_ASCENDING;
     const int rrtel = !!player_teleport(calc_unid);
     if (notele && !stasis)
     {
@@ -1754,7 +1858,8 @@ static std::vector<formatted_string> _get_overview_resistances(
     }
     cols.add_formatted(1, buf, false);
 
-    const int rctel = player_control_teleport(calc_unid);
+    int rctel = player_control_teleport(calc_unid);
+    rctel = allow_control_teleport(true) ? rctel : -1;
     const int rlevi = you.airborne();
     const int rcfli = wearing_amulet(AMU_CONTROLLED_FLIGHT, calc_unid);
     snprintf(buf, sizeof buf,
@@ -1815,7 +1920,7 @@ static char _get_overview_screen_results()
     overview.add_text(_status_mut_abilities());
 
     std::vector<MenuEntry *> results = overview.show();
-    return (results.size() > 0) ? results[0]->hotkeys[0] : 0;
+    return (!results.empty()) ? results[0]->hotkeys[0] : 0;
 }
 
 std::string dump_overview_screen(bool full_id)
@@ -1905,19 +2010,62 @@ std::string _status_mut_abilities()
     std::vector<std::string> status;
 
     const int statuses[] = {
-        DUR_TRANSFORMATION, DUR_PARALYSIS, DUR_PETRIFIED, DUR_SLEEP,
-        STATUS_BURDEN, STATUS_STR_ZERO, STATUS_INT_ZERO, STATUS_DEX_ZERO,
-        DUR_BREATH_WEAPON, STATUS_BEHELD, DUR_LIQUID_FLAMES, DUR_ICY_ARMOUR,
-        DUR_DEFLECT_MISSILES, DUR_REPEL_MISSILES, DUR_JELLY_PRAYER,
-        STATUS_REGENERATION, DUR_DEATHS_DOOR, DUR_STONESKIN, DUR_TELEPORT,
-        DUR_DEATH_CHANNEL, DUR_PHASE_SHIFT, DUR_SILENCE, DUR_INVIS, DUR_CONF,
-        DUR_EXHAUSTED, DUR_MIGHT, DUR_BRILLIANCE, DUR_AGILITY,
-        DUR_DIVINE_VIGOUR, DUR_DIVINE_STAMINA, DUR_BERSERK, STATUS_AIRBORNE,
-        DUR_BARGAIN, DUR_SLAYING, DUR_SAGE, DUR_MAGIC_SHIELD, DUR_FIRE_SHIELD,
-        DUR_POISONING, STATUS_SICK, STATUS_GLOW, STATUS_ROT,
-        DUR_CONFUSING_TOUCH, DUR_SLIMIFY, DUR_SURE_BLADE, STATUS_NET,
-        STATUS_SPEED, DUR_AFRAID, DUR_MIRROR_DAMAGE, DUR_SCRYING, DUR_TORNADO,
-        DUR_HEROISM, DUR_FINESSE, DUR_LIFESAVING, DUR_DARKNESS,
+        DUR_TRANSFORMATION,
+        DUR_PARALYSIS,
+        DUR_PETRIFIED,
+        DUR_SLEEP,
+        DUR_PETRIFYING,
+        STATUS_BURDEN,
+        STATUS_STR_ZERO, STATUS_INT_ZERO, STATUS_DEX_ZERO,
+        DUR_BREATH_WEAPON,
+        STATUS_BEHELD,
+        DUR_LIQUID_FLAMES,
+        DUR_ICY_ARMOUR,
+        DUR_DEFLECT_MISSILES,
+        DUR_REPEL_MISSILES,
+        DUR_JELLY_PRAYER,
+        STATUS_REGENERATION,
+        DUR_DEATHS_DOOR,
+        DUR_STONESKIN,
+        DUR_TELEPORT,
+        DUR_DEATH_CHANNEL,
+        DUR_PHASE_SHIFT,
+        DUR_SILENCE,
+        DUR_INVIS,
+        DUR_CONF,
+        DUR_EXHAUSTED,
+        DUR_MIGHT,
+        DUR_BRILLIANCE,
+        DUR_AGILITY,
+        DUR_DIVINE_VIGOUR,
+        DUR_DIVINE_STAMINA,
+        DUR_BERSERK,
+        STATUS_AIRBORNE,
+        DUR_BARGAIN,
+        DUR_SLAYING,
+        DUR_SAGE,
+        DUR_MAGIC_SHIELD,
+        DUR_FIRE_SHIELD,
+        DUR_POISONING,
+        STATUS_SICK,
+        STATUS_GLOW,
+        STATUS_ROT,
+        DUR_CONFUSING_TOUCH,
+        DUR_SLIMIFY,
+        DUR_SURE_BLADE,
+        STATUS_NET,
+        STATUS_SPEED,
+        DUR_AFRAID,
+        DUR_MIRROR_DAMAGE,
+        DUR_SCRYING,
+        DUR_TORNADO,
+        DUR_HEROISM,
+        DUR_FINESSE,
+        DUR_LIFESAVING,
+        DUR_DARKNESS,
+        STATUS_FIREBALL,
+        DUR_SHROUD_OF_GOLUBRIA,
+        DUR_TORNADO_COOLDOWN,
     };
 
     status_info inf;
@@ -1987,6 +2135,8 @@ std::string _status_mut_abilities()
           break;
 
       case SP_MUMMY:
+          mutations.push_back("no food or potions");
+          mutations.push_back("fire vulnerability");
           if (you.experience_level > 12)
           {
               std::string help = "in touch with death";
@@ -1996,7 +2146,15 @@ std::string _status_mut_abilities()
           }
           break;
 
-      case SP_CAT:
+      case SP_KOBOLD:
+          mutations.push_back("disease resistance");
+          break;
+
+      case SP_DEEP_DWARF:
+          mutations.push_back("damage resistance");
+          break;
+
+      case SP_FELID:
           mutations.push_back("paw claws");
           break;
 
@@ -2048,12 +2206,18 @@ std::string _status_mut_abilities()
         mutations.push_back("unfitting armour");
     }
 
-    if (you.species == SP_CAT)
+    if (you.species == SP_FELID)
     {
         mutations.push_back("no armour");
         mutations.push_back("no advanced items");
     }
 
+    if (you.species == SP_OCTOPODE)
+    {
+        mutations.push_back("almost no armour");
+        mutations.push_back("amphibious");
+    }
+
     if (beogh_water_walk())
         mutations.push_back("walk on water");
 
@@ -2248,7 +2412,25 @@ std::string _status_mut_abilities()
     //----------------------------
 
     text += print_abilities();
-    linebreak_string2(text, get_number_of_cols());
+
+    //--------------
+    // print runes
+    //--------------
+    std::vector<std::string> runes;
+    for (int i = 0; i < NUM_RUNE_TYPES; i++)
+        if (you.runes[i])
+            runes.push_back(rune_type_name(i));
+    if (!runes.empty())
+    {
+        text += make_stringf("\n<w>%s:</w> %d/%d rune%s: %s",
+                    stringize_glyph(get_item_symbol(SHOW_ITEM_MISCELLANY)).c_str(),
+                    runes.size(), you.obtainable_runes,
+                    you.obtainable_runes == 1 ? "" : "s",
+                    comma_separated_line(runes.begin(), runes.end(),
+                                         ", ", ", ").c_str());
+    }
+
+    linebreak_string(text, get_number_of_cols());
 
     return text;
 }
