@@ -7,6 +7,8 @@
 
 #include "player.h"
 
+#include <math.h>
+
 #include "areas.h"
 #include "artefact.h"
 #include "dgnevent.h"
@@ -118,7 +120,7 @@ bool player::extra_balanced() const
     const dungeon_feature_type grid = grd(pos());
     return (grid == DNGN_SHALLOW_WATER
              && (species == SP_NAGA                      // tails, not feet
-                 || body_size(PSIZE_BODY) > SIZE_MEDIUM)
+                 || body_size(PSIZE_BODY) >= SIZE_LARGE)
                     && !form_changed_physiology());
 }
 
@@ -196,6 +198,8 @@ int player::damage_type(int)
         return (DVORP_SLICING);
     else if (has_usable_claws())
         return (DVORP_CLAWING);
+    else if (has_usable_tentacles())
+        return (DVORP_TENTACLE);
 
     return (DVORP_CRUSHING);
 }
@@ -245,7 +249,7 @@ int player::damage_brand(int)
 // eq must be in [EQ_WEAPON, EQ_AMULET], or bad things will happen.
 item_def *player::slot_item(equipment_type eq, bool include_melded)
 {
-    ASSERT(eq >= EQ_WEAPON && eq <= EQ_AMULET);
+    ASSERT(eq >= EQ_WEAPON && eq < NUM_EQUIP);
 
     const int item = equip[eq];
     if (item == -1 || !include_melded && melded[eq])
@@ -256,7 +260,7 @@ item_def *player::slot_item(equipment_type eq, bool include_melded)
 // const variant of the above...
 const item_def *player::slot_item(equipment_type eq, bool include_melded) const
 {
-    ASSERT(eq >= EQ_WEAPON && eq <= EQ_AMULET);
+    ASSERT(eq >= EQ_WEAPON && eq < NUM_EQUIP);
 
     const int item = equip[eq];
     if (item == -1 || !include_melded && melded[eq])
@@ -296,7 +300,7 @@ bool player::can_wield(const item_def& item, bool ignore_curse,
 bool player::could_wield(const item_def &item, bool ignore_brand,
                          bool /* ignore_transform */) const
 {
-    if (species == SP_CAT)
+    if (species == SP_FELID)
         return (false);
     if (body_size() < SIZE_LARGE
             && (item_mass(item) >= 500
@@ -410,6 +414,11 @@ std::string player::foot_name(bool plural, bool *can_plural) const
             str         = "underbelly";
             *can_plural = false;
         }
+        else if (species == SP_OCTOPODE)
+        {
+            str         = "tentacles";
+            *can_plural = false;
+        }
         else if (fishtail)
         {
             str         = "tail";
@@ -442,6 +451,8 @@ std::string player::arm_name(bool plural, bool *can_plural) const
         str = "feathered arm";
     else if (species == SP_MUMMY)
         str = "bandage-wrapped arm";
+    else if (species == SP_OCTOPODE)
+        str = "tentacle";
 
     if (plural)
         str = pluralise(str);
@@ -474,7 +485,7 @@ bool player::cannot_fight() const
 }
 
 // If you have a randart equipped that has the ARTP_ANGRY property,
-// there's a 1/20 chance of it becoming activated whenever you
+// there's a 1/100 chance of it becoming activated whenever you
 // attack a monster. (Same as the berserk mutation at level 1.)
 // The probabilities for actually going berserk are cumulative!
 static bool _equipment_make_berserk()
@@ -488,7 +499,7 @@ static bool _equipment_make_berserk()
         if (!is_artefact(*item))
             continue;
 
-        if (artefact_wpn_property(*item, ARTP_ANGRY) && one_chance_in(20))
+        if (artefact_wpn_property(*item, ARTP_ANGRY) && one_chance_in(100))
             return (true);
     }
 
@@ -507,8 +518,8 @@ void player::attacking(actor *other)
             pet_target = mon->mindex();
     }
 
-    if (player_mutation_level(MUT_BERSERK)
-            && x_chance_in_y(player_mutation_level(MUT_BERSERK) * 10 - 5, 100)
+    const int chance = pow(3, player_mutation_level(MUT_BERSERK) - 1);
+    if (player_mutation_level(MUT_BERSERK) && x_chance_in_y(chance, 100)
         || _equipment_make_berserk())
     {
         go_berserk(false);
