@@ -30,9 +30,9 @@
 #include "noise.h"
 #include "player.h"
 #include "random.h"
+#include "religion.h"
 #include "skills.h"
 #include "state.h"
-#include "stuff.h"
 #include "terrain.h"
 #include "areas.h"
 #include "hints.h"
@@ -66,8 +66,10 @@ void handle_monster_shouts(monster* mons, bool force)
 
     // Silent monsters can give noiseless "visual shouts" if the
     // player can see them, in which case silence isn't checked for.
+    // Muted monsters can't shout at all.
     if (s_type == S_SILENT && !mons->visible_to(&you)
-        || s_type != S_SILENT && !player_can_hear(mons->pos()))
+        || s_type != S_SILENT && !player_can_hear(mons->pos())
+        || mons->has_ench(ENCH_MUTE))
     {
         return;
     }
@@ -145,7 +147,7 @@ void handle_monster_shouts(monster* mons, bool force)
     std::string key = mons_type_name(mons->type, DESC_PLAIN);
 
     // Pandemonium demons have random names, so use "pandemonium lord"
-    if (mons->type == MONS_PANDEMONIUM_DEMON)
+    if (mons->type == MONS_PANDEMONIUM_LORD)
         key = "pandemonium lord";
     // Search for player ghost shout by the ghost's job.
     else if (mons->type == MONS_PLAYER_GHOST)
@@ -314,11 +316,6 @@ void handle_monster_shouts(monster* mons, bool force)
         learned_something_new(HINT_MONSTER_SHOUT, mons->pos());
 }
 
-void force_monster_shout(monster* mons)
-{
-    handle_monster_shouts(mons, true);
-}
-
 bool check_awaken(monster* mons)
 {
     // Usually redundant because we iterate over player LOS,
@@ -395,6 +392,105 @@ bool check_awaken(monster* mons)
     return (false);
 }
 
+void item_noise(const item_def &item, std::string msg, int loudness)
+{
+    if (is_unrandom_artefact(item))
+    {
+        // "Your Singing Sword" sounds disrespectful
+        // (as if there could be more than one!)
+        msg = replace_all(msg, "@Your_weapon@", "@The_weapon@");
+        msg = replace_all(msg, "@your_weapon@", "@the_weapon@");
+    }
+    else
+    {
+        msg = replace_all(msg, "@Your_weapon@", "Your @weapon@");
+        msg = replace_all(msg, "@your_weapon@", "your @weapon@");
+    }
+
+    // Set appropriate channel (will usually be TALK).
+    msg_channel_type channel = MSGCH_TALK;
+
+    std::string param;
+    const std::string::size_type pos = msg.find(":");
+
+    if (pos != std::string::npos)
+        param = msg.substr(0, pos);
+
+    if (!param.empty())
+    {
+        bool match = true;
+
+        if (param == "DANGER")
+            channel = MSGCH_DANGER;
+        else if (param == "WARN")
+            channel = MSGCH_WARN;
+        else if (param == "SOUND")
+            channel = MSGCH_SOUND;
+        else if (param == "PLAIN")
+            channel = MSGCH_PLAIN;
+        else if (param == "SPELL")
+            channel = MSGCH_FRIEND_SPELL;
+        else if (param == "ENCHANT")
+            channel = MSGCH_FRIEND_ENCHANT;
+        else if (param == "VISUAL")
+            channel = MSGCH_TALK_VISUAL;
+        else if (param != "TALK")
+            match = false;
+
+        if (match)
+            msg = msg.substr(pos + 1);
+    }
+
+    if (msg.empty()) // give default noises
+    {
+        channel = MSGCH_SOUND;
+        msg = "You hear a strange noise.";
+    }
+
+    // replace weapon references
+    msg = replace_all(msg, "@The_weapon@", "The @weapon@");
+    msg = replace_all(msg, "@the_weapon@", "the @weapon@");
+    msg = replace_all(msg, "@weapon@", item.name(DESC_BASENAME));
+
+    // replace references to player name and god
+    msg = replace_all(msg, "@player_name@", you.your_name);
+    msg = replace_all(msg, "@player_god@",
+                      you.religion == GOD_NO_GOD ? "atheism"
+                      : god_name(you.religion, coinflip()));
+
+    mpr(msg.c_str(), channel);
+
+    if (channel != MSGCH_TALK_VISUAL)
+        noisy(loudness, you.pos());
+}
+
+// TODO: Let artefacts besides weapons generate noise.
+void noisy_equipment()
+{
+    if (silenced(you.pos()) || !one_chance_in(20))
+        return;
+
+    std::string msg;
+
+    const item_def* weapon = you.weapon();
+    if (!weapon)
+        return;
+
+    if (is_unrandom_artefact(*weapon))
+    {
+        std::string name = weapon->name(DESC_PLAIN, false, true, false, false,
+                                        ISFLAG_IDENT_MASK);
+        msg = getSpeakString(name);
+        if (msg == "NONE")
+            return;
+    }
+
+    if (msg.empty())
+        msg = getSpeakString("noisy weapon");
+
+    item_noise(*weapon, msg);
+}
+
 void apply_noises()
 {
     // [ds] This copying isn't awesome, but we cannot otherwise handle
@@ -416,6 +512,9 @@ bool noisy(int original_loudness, const coord_def& where,
            const char *msg, int who,
            bool mermaid, bool message_if_unseen, bool fake_noise)
 {
+    if (original_loudness <= 0)
+        return (false);
+
     // high ambient noise makes sounds harder to hear
     const int ambient = current_level_ambient_noise();
     const int loudness =
@@ -689,7 +788,7 @@ void noise_grid::propagate_noise()
     if (noises.empty())
         return;
 
-    dprf("noise_grid: %d noises to apply", noises.size());
+    dprf("noise_grid: %u noises to apply", (unsigned int)noises.size());
     std::vector<coord_def> noise_perimeter[2];
     int circ_index = 0;
 
