@@ -27,12 +27,12 @@
 #include "random.h"
 #include "showsymb.h"
 #include "state.h"
-#include "stuff.h"
 #include "areas.h"
 #include "terrain.h"
 #ifdef USE_TILE
  #include "tileview.h"
 #endif
+#include "traps.h"
 #include "travel.h"
 #include "viewgeom.h"
 #include "viewmap.h"
@@ -119,6 +119,9 @@ static void _update_feat_at(const coord_def &gp)
 
     dungeon_feature_type feat = grid_appearance(gp);
     unsigned colour = env.grid_colours(gp);
+    trap_type trap = TRAP_UNASSIGNED;
+    if (feat_is_trap(feat))
+        trap = get_trap_type(gp);
 
     // Check for mimics
     if (monster_at(gp))
@@ -131,7 +134,7 @@ static void _update_feat_at(const coord_def &gp)
         }
     }
 
-    env.map_knowledge(gp).set_feature(feat, colour);
+    env.map_knowledge(gp).set_feature(feat, colour, trap);
 
     if (haloed(gp))
         env.map_knowledge(gp).flags |= MAP_HALOED;
@@ -420,7 +423,6 @@ static void _update_monster(const monster* mons)
 
 void show_update_at(const coord_def &gp, bool terrain_only)
 {
-
     if (you.see_cell(gp))
         env.map_knowledge(gp).clear_data();
     else if (!env.map_knowledge(gp).known())
