@@ -18,7 +18,6 @@
 #include "options.h"
 #include "show.h"
 #include "state.h"
-#include "stuff.h"
 #include "terrain.h"
 #include "viewchar.h"
 #include "viewgeom.h"
@@ -124,6 +123,9 @@ static int _get_mons_colour(const monster_info& mi)
     if (mi.is(MB_MIRROR_DAMAGE))
         col = ETC_NECRO;
 
+    if (mi.is(MB_INNER_FLAME))
+        col = ETC_FIRE;
+
     if (mi.attitude == ATT_FRIENDLY)
     {
         col |= COLFLAG_FRIENDLY_MONSTER;
@@ -184,8 +186,12 @@ show_class get_cell_show_class(const map_cell& cell,
     if (cell.cloud() != CLOUD_NONE && cell.cloud() != CLOUD_GLOOM)
         return SH_CLOUD;
 
-    if (feat_is_trap(cell.feat()) || is_critical_feature(cell.feat()))
+    if (feat_is_trap(cell.feat())
+     || is_critical_feature(cell.feat())
+     || cell.feat() < DNGN_MINMOVE)
+    {
         return SH_FEATURE;
+    }
 
     if (cell.item())
         return SH_ITEM;
@@ -307,8 +313,12 @@ glyph get_cell_glyph_with_class(const map_cell& cell, const coord_def& loc,
 
         if (cell.item())
         {
-            if (Options.feature_item_brand && is_critical_feature(cell.feat()))
+            if (Options.feature_item_brand
+                && (is_critical_feature(cell.feat())
+                 || cell.feat() < DNGN_MINMOVE))
+            {
                 g.col |= COLFLAG_FEATURE_ITEM;
+            }
             else if (Options.trap_item_brand && feat_is_trap(cell.feat()))
                 g.col |= COLFLAG_TRAP_ITEM;
         }
