@@ -33,5 +33,7 @@ monster_type player_species_to_mons_species(species_type species);
 
 // species_type bounds checking.
 bool is_valid_species(species_type);
-
+int species_exp_modifier(species_type species);
+int species_hp_modifier(species_type species);
+int species_mp_modifier(species_type species);
 #endif
