@@ -35,7 +35,6 @@
 #include "spl-util.h"
 #include "stash.h"
 #include "state.h"
-#include "stuff.h"
 #include "teleport.h"
 #include "terrain.h"
 #include "transform.h"
@@ -47,12 +46,17 @@
 
 static bool _abyss_blocks_teleport(bool cblink)
 {
-    // Lugonu worshippers get their perks.
-    if (you.religion == GOD_LUGONU)
-        return (false);
+    // Controlled Blink (the spell) works more reliably in the Abyss.
+    return (cblink ? coinflip() : !one_chance_in(3));
+}
 
-    // Controlled Blink (the spell) works quite reliably in the Abyss.
-    return (cblink ? one_chance_in(3) : !one_chance_in(3));
+// XXX: can miscast before cancelling.
+spret_type cast_controlled_blink(int pow, bool fail)
+{
+    fail_check();
+    if (blink(pow, true) == -1)
+        return SPRET_ABORT;
+    return SPRET_SUCCESS;
 }
 
 // If wizard_blink is set, all restriction are ignored (except for
@@ -94,6 +98,16 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
             mpr(pre_msg->c_str());
         random_blink(false);
     }
+    // The orb sometimes degrades controlled blinks to completely uncontrolled.
+    else if (you.char_direction == GDT_ASCENDING && !wizard_blink)
+    {
+        if (pre_msg)
+            mpr(pre_msg->c_str());
+        mpr("The orb interferes with your control of the blink!", MSGCH_ORB);
+        if (high_level_controlled_blink && coinflip())
+            return (cast_semi_controlled_blink(pow));
+        random_blink(false);
+    }
     else if (!allow_control_teleport(true) && !wizard_blink)
     {
         if (pre_msg)
@@ -149,6 +163,11 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
                 mesclr();
                 mpr("You can't blink into the sea!");
             }
+            else if (grd(beam.target) == DNGN_LAVA_SEA)
+            {
+                mesclr();
+                mpr("You can't blink into the sea of lava!");
+            }
             else if (!check_moveto(beam.target, "blink"))
             {
                 // try again (messages handled by check_moveto)
@@ -211,6 +230,13 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
     return (1);
 }
 
+spret_type cast_blink(bool allow_partial_control, bool fail)
+{
+    fail_check();
+    random_blink(allow_partial_control);
+    return SPRET_SUCCESS;
+}
+
 void random_blink(bool allow_partial_control, bool override_abyss)
 {
     ASSERT(!crawl_state.game_is_arena());
@@ -220,7 +246,8 @@ void random_blink(bool allow_partial_control, bool override_abyss)
     if (item_blocks_teleport(true, true))
         canned_msg(MSG_STRANGE_STASIS);
     else if (you.level_type == LEVEL_ABYSS
-             && !override_abyss && !one_chance_in(3))
+             && !override_abyss
+             && _abyss_blocks_teleport(false))
     {
         mpr("The power of the Abyss keeps you in your place!");
     }
@@ -233,8 +260,8 @@ void random_blink(bool allow_partial_control, bool override_abyss)
     }
 
     //jmf: Add back control, but effect is cast_semi_controlled_blink(pow).
-    else if (player_control_teleport() && !you.confused()
-             && allow_partial_control && allow_control_teleport())
+    else if (player_control_teleport() && !you.confused() && allow_partial_control
+             && allow_control_teleport())
     {
         mpr("You may select the general direction of your translocation.");
         cast_semi_controlled_blink(100);
@@ -248,13 +275,6 @@ void random_blink(bool allow_partial_control, bool override_abyss)
 
         // Leave a purple cloud.
         place_cloud(CLOUD_TLOC_ENERGY, origin, 1 + random2(3), &you);
-
-        if (you.level_type == LEVEL_ABYSS)
-        {
-            abyss_teleport(false);
-            if (you.pet_target != MHITYOU)
-                you.pet_target = MHITNOT;
-        }
     }
 }
 
@@ -263,15 +283,28 @@ void random_blink(bool allow_partial_control, bool override_abyss)
 bool allow_control_teleport(bool quiet)
 {
     bool retval = !(testbits(env.level_flags, LFLAG_NO_TELE_CONTROL)
-                    || testbits(get_branch_flags(), BFLAG_NO_TELE_CONTROL));
+                    || testbits(get_branch_flags(), BFLAG_NO_TELE_CONTROL)
+                    || you.char_direction == GDT_ASCENDING);
 
     // Tell the player why if they have teleport control.
     if (!quiet && !retval && player_control_teleport())
-        mpr("A powerful magic prevents control of your teleportation.");
+    {
+        if (you.char_direction == GDT_ASCENDING)
+            mpr("The orb prevents control of your teleportation!", MSGCH_ORB);
+        else
+            mpr("A powerful magic prevents control of your teleportation.");
+    }
 
     return (retval);
 }
 
+spret_type cast_teleport_self(bool fail)
+{
+    fail_check();
+    you_teleport();
+    return SPRET_SUCCESS;
+}
+
 void you_teleport(void)
 {
     // [Cha] here we block teleportation, which will save the player from
@@ -294,6 +327,11 @@ void you_teleport(void)
             mpr("You have a feeling this translocation may take a while to kick in...");
             teleport_delay += 5 + random2(10);
         }
+        else if (you.char_direction == GDT_ASCENDING && coinflip())
+        {
+            mpr("You feel the orb delaying this translocation!", MSGCH_ORB);
+            teleport_delay += 5 + random2(5);
+        }
 
         you.set_duration(DUR_TELEPORT, teleport_delay);
     }
@@ -419,7 +457,6 @@ static bool _teleport_player(bool allow_control, bool new_abyss_area,
             pos = lpos.pos;
             redraw_screen();
 
-#if defined(USE_UNIX_SIGNALS) && defined(SIGHUP_SAVE) && defined(USE_CURSES)
             // If we've received a HUP signal then the user can't choose a
             // location, so cancel the teleport.
             if (crawl_state.seen_hups)
@@ -430,7 +467,6 @@ static bool _teleport_player(bool allow_control, bool new_abyss_area,
                     contaminate_player(1, true);
                 return (false);
             }
-#endif
 
             dprf("Target square (%d,%d)", pos.x, pos.y);
 
@@ -664,49 +700,50 @@ void you_teleport_now(bool allow_control, bool new_abyss_area, bool wizard_tele)
             || you.level_type != LEVEL_ABYSS && player_in_a_dangerous_place()))
     {
         if (you.level_type == LEVEL_LABYRINTH && you.species == SP_MINOTAUR)
-            xom_is_stimulated(128);
+            xom_is_stimulated(100);
         else
-            xom_is_stimulated(255);
+            xom_is_stimulated(200);
     }
 }
 
-bool cast_portal_projectile(int pow)
+spret_type cast_portal_projectile(int pow, bool fail)
 {
     dist target;
     int item = get_ammo_to_shoot(-1, target, true);
     if (item == -1)
-        return (false);
+        return SPRET_ABORT;
 
     if (cell_is_solid(target.target))
     {
         mpr("You can't shoot at gazebos.");
-        return (false);
+        return SPRET_ABORT;
     }
 
     // Can't use portal through walls. (That'd be just too cheap!)
     if (you.trans_wall_blocking(target.target))
     {
         mpr("A translucent wall is in the way.");
-        return (false);
+        return SPRET_ABORT;
     }
 
     if (!check_warning_inscriptions(you.inv[item], OPER_FIRE))
-        return (false);
+        return SPRET_ABORT;
 
+    fail_check();
     bolt beam;
     throw_it(beam, item, true, random2(pow/4), &target);
 
-    return (true);
+    return SPRET_SUCCESS;
 }
 
-bool cast_apportation(int pow, bolt& beam)
+spret_type cast_apportation(int pow, bolt& beam, bool fail)
 {
     const coord_def where = beam.target;
 
     if (you.trans_wall_blocking(where))
     {
         mpr("Something is in the way.");
-        return (false);
+        return SPRET_ABORT;
     }
 
     // Letting mostly-melee characters spam apport after every Shoals
@@ -715,7 +752,7 @@ bool cast_apportation(int pow, bolt& beam)
     if (grd(where) == DNGN_DEEP_WATER || grd(where) == DNGN_LAVA)
     {
         mpr("The density of the terrain blocks your spell.");
-        return (false);
+        return SPRET_ABORT;
     }
 
     // Let's look at the top item in that square...
@@ -728,15 +765,16 @@ bool cast_apportation(int pow, bolt& beam)
         {
             if (mons_is_item_mimic(m->type) && you.can_see(m))
             {
+                fail_check();
                 mprf("%s twitches.", m->name(DESC_CAP_THE).c_str());
                 // Nothing else gives this message, so identify the mimic.
                 discover_mimic(m);
-                return (true);  // otherwise you get free mimic ID
+                return SPRET_SUCCESS;  // otherwise you get free mimic ID
             }
         }
 
         mpr("There are no items there.");
-        return (false);
+        return SPRET_ABORT;
     }
 
     item_def& item = mitm[item_idx];
@@ -745,16 +783,19 @@ bool cast_apportation(int pow, bolt& beam)
     if (crawl_state.game_is_zotdef() && item_is_orb(item))
     {
         mpr("You cannot apport the sacred Orb!");
-        return (false);
+        return SPRET_ABORT;
     }
 
     // Protect the player from destroying the item.
-    if (feat_destroys_item(grd(you.pos()), item))
+    if (feat_virtually_destroys_item(grd(you.pos()), item)
+        && !yesno("Really apport while over this terrain?",
+                  false, 'n'))
     {
-        mpr("That would be silly while over this terrain!");
-        return (false);
+        canned_msg(MSG_OK);
+        return SPRET_ABORT;
     }
 
+    fail_check();
     // Mass of one unit.
     const int unit_mass = item_mass(item);
     const int max_mass = pow * 30 + random2(pow * 20);
@@ -768,21 +809,17 @@ bool cast_apportation(int pow, bolt& beam)
         if (item_is_orb(item))
         {
             orb_pickup_noise(where, 30);
-            return (true);
+            mpr("The mass is resisting your pull.");
         }
         else
-        {
             mpr("The mass is resisting your pull.");
-            return (true);
-        }
+
+            return SPRET_SUCCESS;
     }
 
     // We need to modify the item *before* we move it, because
     // move_top_item() might change the location, or merge
     // with something at our position.
-    mprf("Yoink! You pull the item%s towards yourself.",
-         (item.quantity > 1) ? "s" : "");
-
     if (item_is_orb(item))
     {
         fake_noisy(30, where);
@@ -792,7 +829,7 @@ bool cast_apportation(int pow, bolt& beam)
         {
             orb_pickup_noise(where, 30, "The orb shrieks and becomes a dead weight against your magic!",
                              "The orb lets out a furious burst of light and becomes a dead weight against your magic!");
-            return (true);
+            return SPRET_SUCCESS;
         }
         else // Otherwise it's just a noisy little shiny thing
         {
@@ -811,63 +848,67 @@ bool cast_apportation(int pow, bolt& beam)
             mons->del_ench(ENCH_HELD, true);
     }
 
-    if (item_is_orb(item))
+    // Heavy items require more power to apport directly to your feet.
+    // They might end up just moving a few squares, depending on spell
+    // power and item mass.
+    beam.is_tracer = true;
+    beam.aimed_at_spot = true;
+    beam.affects_nothing = true;
+    beam.fire();
+
+    // Pop the item's location off the end
+    beam.path_taken.pop_back();
+
+    // The actual number of squares it needs to traverse to get to you.
+    int dist = beam.path_taken.size();
+
+    // The maximum number of squares the item will actually move, always
+    // at least one square.
+    int quantity = item.quantity;
+    int apported_mass = unit_mass * std::min(quantity, max_units);
+
+    int max_dist = std::max(60 * pow / (apported_mass + 150), 1);
+
+    dprf("Apport dist=%d, max_dist=%d", dist, max_dist);
+
+    coord_def new_spot = beam.path_taken[beam.path_taken.size() - max_dist];
+
+    if (max_dist <= dist)
     {
-        // The orb drags its heels.
-        beam.is_tracer = true;
-        beam.aimed_at_spot = true;
-        beam.fire();
+        dprf("Apport: new spot is %d/%d", new_spot.x, new_spot.y);
 
-        // Pop the orb's location off the end
-        beam.path_taken.pop_back();
-
-        // The actual number of squares it needs to traverse to get to you.
-        unsigned int dist = beam.path_taken.size();
-
-        // The maximum number of squares the orb will actually move, always
-        // at least one square.
-        unsigned int max_dist = std::max((pow / 10) - 1, 1);
-
-        dprf("Orb apport dist=%d, max_dist=%d", dist, max_dist);
-
-        if (max_dist <= dist)
+        if (feat_virtually_destroys_item(grd(new_spot), item))
         {
-            coord_def new_spot = beam.path_taken[beam.path_taken.size()-max_dist];
-
-            dprf("Orb apport: new spot is %d/%d", new_spot.x, new_spot.y);
-
-            if (feat_virtually_destroys_item(grd(new_spot), item))
-                return (true);
-
-            else
-            {
-                move_top_item(where, new_spot);
-                origin_set(new_spot);
-                return (true);
-            }
+            mpr("Not with that terrain in the way!");
+            return SPRET_SUCCESS;
         }
-        // if power is high enough it'll just come straight to you
     }
+    // If power is high enough it'll just come straight to you.
+    else
+        new_spot = you.pos();
 
     // Actually move the item.
+    mprf("Yoink! You pull the item%s towards yourself.",
+         (item.quantity > 1) ? "s" : "");
+
     if (max_units < item.quantity)
     {
-        if (!copy_item_to_grid(item, you.pos(), max_units))
+        if (!copy_item_to_grid(item, new_spot, max_units))
         {
-            // always >1 item
+            // Always >1 item.
             mpr("They abruptly stop in place!");
             // Too late to abort.
-            return (true);
+            return SPRET_SUCCESS;
         }
         item.quantity -= max_units;
     }
     else
-        move_top_item(where, you.pos());
+        move_top_item(where, new_spot);
 
     // Mark the item as found now.
-    origin_set(you.pos());
+    origin_set(new_spot);
 
-    return (true);
+    return SPRET_SUCCESS;
 }
 
 static int _quadrant_blink(coord_def where, int pow, int, actor *)
@@ -875,14 +916,6 @@ static int _quadrant_blink(coord_def where, int pow, int, actor *)
     if (where == you.pos())
         return (1);
 
-    if (you.level_type == LEVEL_ABYSS)
-    {
-        abyss_teleport(false);
-        if (you.pet_target != MHITYOU)
-            you.pet_target = MHITNOT;
-        return (1);
-    }
-
     if (pow > 100)
         pow = 100;
 
@@ -919,7 +952,8 @@ static int _quadrant_blink(coord_def where, int pow, int, actor *)
 
     if (!found)
     {
-        random_blink(false);
+        // We've already succeeded at blinking, so the Abyss shouldn't block it.
+        random_blink(false, true);
         return (1);
     }
 
@@ -948,7 +982,7 @@ bool can_cast_golubrias_passage()
     return find_golubria_on_level().size() < 2;
 }
 
-bool cast_golubrias_passage(const coord_def& where)
+spret_type cast_golubrias_passage(const coord_def& where, bool fail)
 {
     // randomize position a bit to make it not as useful to use on monsters
     // chasing you, as well as to not give away hidden trap positions
@@ -975,28 +1009,30 @@ bool cast_golubrias_passage(const coord_def& where)
         else
             // XXX: bleh, dumb message
             mpr("Creating a passage of Golubria requires sufficient empty space.");
-        return false;
+        return SPRET_ABORT;
     }
 
     if (!allow_control_teleport(true) ||
         testbits(env.pgrid(randomized_where), FPROP_NO_CTELE_INTO))
     {
+        fail_check();
         // lose a turn
         mpr("A powerful magic interferes with the creation of the passage.");
         place_cloud(CLOUD_TLOC_ENERGY, randomized_where, 3 + random2(3), &you);
-        return true;
+        return SPRET_SUCCESS;
     }
 
+    fail_check();
     place_specific_trap(randomized_where, TRAP_GOLUBRIA);
 
     trap_def *trap = find_trap(randomized_where);
     if (!trap)
     {
         mpr("Something buggy happened.");
-        return false;
+        return SPRET_ABORT;
     }
 
     trap->reveal();
 
-    return true;
+    return SPRET_SUCCESS;
 }
