@@ -29,6 +29,7 @@
 #include "mon-behv.h"
 #include "mon-util.h"
 #include "notes.h"
+#include "options.h"
 #include "player.h"
 #include "religion.h"
 #include "spl-cast.h"
@@ -79,10 +80,6 @@ static int spell_list[NUM_SPELLS];
 #define SPELLDATASIZE (sizeof(spelldata)/sizeof(struct spell_desc))
 
 static struct spell_desc *_seekspell(spell_type spellid);
-static bool _cloud_helper(cloud_func func, const coord_def& where,
-                          int pow, int spread_rate,
-                          cloud_type ctype, const actor *agent, int colour,
-                          std::string name, std::string tile);
 
 //
 //             BEGIN PUBLIC FUNCTIONS
@@ -167,7 +164,7 @@ spell_type spell_by_name(std::string name, bool partial_match)
         return (SPELL_NO_SPELL);
     }
 
-    int spellmatch = -1;
+    spell_type spellmatch = SPELL_NO_SPELL;
     for (int i = 0; i < NUM_SPELLS; i++)
     {
         spell_type type = static_cast<spell_type>(i);
@@ -180,14 +177,13 @@ spell_type spell_by_name(std::string name, bool partial_match)
         if (spell_name.find(name) != std::string::npos)
         {
             if (spell_name == name)
-                return static_cast<spell_type>(i);
+                return type;
 
-            spellmatch = i;
+            spellmatch = type;
         }
     }
 
-    return (spellmatch != -1 ? static_cast<spell_type>(spellmatch)
-                             : SPELL_NO_SPELL);
+    return spellmatch;
 }
 
 spschool_flag_type school_by_name(std::string name)
@@ -278,8 +274,10 @@ spell_type get_spell_by_letter(char letter)
 
 bool add_spell_to_memory(spell_type spell)
 {
-    int i, j;
-
+    int i;
+    int j = -1;
+    std::string sname = spell_title(spell);
+    lowercase(sname);
     // first we find a slot in our head:
     for (i = 0; i < MAX_KNOWN_SPELLS; i++)
     {
@@ -290,11 +288,30 @@ bool add_spell_to_memory(spell_type spell)
     you.spells[i] = spell;
 
     // now we find an available label:
-    for (j = 0; j < 52; j++)
+    // first check to see whether we've chosen an automatic label:
+    for (unsigned k = 0; k < Options.auto_spell_letters.size(); ++k)
     {
-        if (you.spell_letter_table[j] == -1)
+        if (!Options.auto_spell_letters[k].first.matches(sname))
+            continue;
+        for (unsigned l = 0; l < Options.auto_spell_letters[k].second.length(); ++l)
+            if (isaalpha(Options.auto_spell_letters[k].second[l]) &&
+                you.spell_letter_table[letter_to_index(Options.auto_spell_letters[k].second[l])] == -1)
+            {
+                j = letter_to_index(Options.auto_spell_letters[k].second[l]);
+                mprf("Spell assigned to '%c'.",
+                     Options.auto_spell_letters[k].second[l]);
+                break;
+            }
+        if (j != -1)
             break;
     }
+    // If we didn't find a label above, choose the first available one.
+    if (j == -1)
+        for (j = 0; j < 52; j++)
+        {
+            if (you.spell_letter_table[j] == -1)
+                break;
+        }
 
     you.spell_letter_table[j] = i;
 
@@ -302,7 +319,7 @@ bool add_spell_to_memory(spell_type spell)
 
     take_note(Note(NOTE_LEARN_SPELL, spell));
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     tiles.layout_statcol();
     redraw_screen();
 #endif
@@ -330,7 +347,7 @@ bool del_spell_from_memory_by_slot(int slot)
 
     you.spell_no--;
 
-#ifdef USE_TILE
+#ifdef USE_TILE_LOCAL
     tiles.layout_statcol();
     redraw_screen();
 #endif
@@ -746,7 +763,6 @@ int apply_area_within_radius(cell_func cf, const coord_def& where,
                              int pow, int radius, int ctype,
                              actor *agent)
 {
-
     int rv = 0;
 
     for (radius_iterator ri(where, radius, false, false); ri; ++ri)
@@ -755,73 +771,34 @@ int apply_area_within_radius(cell_func cf, const coord_def& where,
     return (rv);
 }
 
-// apply_area_cloud:
-// Try to make a realistic cloud by expanding from a point, filling empty
-// floor tiles until we run out of material (passed in as number).
-// We really need some sort of a queue structure, since ideally I'd like
-// to do a (shallow) breadth-first-search of the dungeon floor.
-// This ought to work okay for small clouds.
 void apply_area_cloud(cloud_func func, const coord_def& where,
                        int pow, int number, cloud_type ctype,
                        const actor *agent,
                        int spread_rate, int colour, std::string name,
                        std::string tile)
 {
-    if (!in_bounds(where))
+    if (number <= 0)
         return;
 
-    int good_squares = 0;
-    int neighbours[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
-
-    if (number && _cloud_helper(func, where, pow, spread_rate, ctype, agent,
-                                colour, name, tile))
-        number--;
-
-    if (number == 0)
+    targetter_cloud place(0, 0, number, number);
+    if (!place.set_aim(where))
         return;
-
-    // These indices depend on the order in Compass (see main.cc)
-    int compass_order_orth[4] = { 2, 6, 4, 0 };
-    int compass_order_diag[4] = { 1, 3, 5, 7 };
-
-    int* const arrs[2] = { compass_order_orth, compass_order_diag };
-
-    for (int m = 0; m < 2; ++m)
+    unsigned int dist = 0;
+    while (number > 0)
     {
-        // Randomise, but do orthogonals first and diagonals later.
-        std::random_shuffle(arrs[m], arrs[m] + 4);
-        for (int i = 0; i < 4 && number; ++i)
-        {
-            const int aux = arrs[m][i];
-            if (_cloud_helper(func, where + Compass[aux],
-                               pow, spread_rate, ctype, agent, colour,
-                               name, tile))
-            {
-                number--;
-                good_squares++;
-                neighbours[aux]++;
-            }
-        }
-    }
+        while (place.queue[dist].empty())
+            if (++dist >= place.queue.size())
+                return;
+        std::vector<coord_def> &q = place.queue[dist];
+        int el = random2(q.size());
+        coord_def c = q[el];
+        q[el] = q[q.size() - 1];
+        q.pop_back();
 
-    // Get a random permutation.
-    int perm[8];
-    for (int i = 0; i < 8; ++i)
-        perm[i] = i;
-    std::random_shuffle(perm, perm+8);
-    for (int i = 0; i < 8 && number; i++)
-    {
-        // Spread (in random order.)
-        const int j = perm[i];
-
-        if (neighbours[j] == 0)
+        if (place.seen[c] <= 0)
             continue;
-
-        int spread = number / good_squares;
-        number -= spread;
-        good_squares--;
-        apply_area_cloud(func, where + Compass[j], pow, spread, ctype, agent,
-                         spread_rate, colour, name, tile);
+        func(c, pow, spread_rate, ctype, agent, colour, name, tile);
+        number--;
     }
 }
 
@@ -835,7 +812,7 @@ bool spell_direction(dist &spelld, bolt &pbolt,
                       bool needs_path, bool may_target_monster,
                       bool may_target_self, const char *target_prefix,
                       const char* top_prompt, bool cancel_at_self,
-                      targetter *hitfunc)
+                      targetter *hitfunc, desc_filter get_desc_func)
 {
     if (range < 1)
         range = (pbolt.range < 1) ? LOS_RADIUS : pbolt.range;
@@ -854,6 +831,7 @@ bool spell_direction(dist &spelld, bolt &pbolt,
     args.behaviour = NULL;
     args.cancel_at_self = cancel_at_self;
     args.hitfunc = hitfunc;
+    args.get_desc_func = get_desc_func;
 
     direction(spelld, args);
 
@@ -968,10 +946,7 @@ skill_type spell_type2skill(unsigned int spelltype)
     default:
     case SPTYP_HOLY:
     case SPTYP_DIVINATION:
-#ifdef DEBUG_DIAGNOSTICS
-        mprf(MSGCH_DIAGNOSTICS, "spell_type2skill: called with spelltype %u",
-             spelltype);
-#endif
+        dprf("spell_type2skill: called with spelltype %u", spelltype);
         return (SK_NONE);
     }
 }                               // end spell_type2skill()
@@ -1000,22 +975,6 @@ bool is_valid_spell(spell_type spell)
             && spell_list[spell] != -1);
 }
 
-static bool _cloud_helper(cloud_func func, const coord_def& where,
-                          int pow, int spread_rate,
-                          cloud_type ctype, const actor* agent, int colour,
-                          std::string name, std::string tile)
-{
-    if (in_bounds(where)
-        && !feat_is_solid(grd(where))
-        && env.cgrid(where) == EMPTY_CLOUD)
-    {
-        func(where, pow, spread_rate, ctype, agent, colour, name, tile);
-        return (true);
-    }
-
-    return (false);
-}
-
 static bool _spell_range_varies(spell_type spell)
 {
     int minrange = _seekspell(spell)->min_range;
@@ -1082,10 +1041,11 @@ int spell_range(spell_type spell, int pow, bool real_cast, bool player_spell)
     const int powercap = spell_power_cap(spell);
 
     if (powercap <= pow)
-        return maxrange;
+        return std::min(maxrange, LOS_RADIUS);
 
     // Round appropriately.
-    return ((pow * (maxrange - minrange) + powercap / 2) / powercap + minrange);
+    return std::min(LOS_RADIUS,
+           (pow * (maxrange - minrange) + powercap / 2) / powercap + minrange);
 }
 
 /**
@@ -1264,10 +1224,6 @@ bool spell_is_useless(spell_type spell, bool transient)
         if (transient && you.is_levitating())
             return (true);
         break;
-    case SPELL_REGENERATION:
-        if (you.species == SP_DEEP_DWARF)
-            return (true);
-        break;
     case SPELL_INVISIBILITY:
         if (transient && (you.duration[DUR_INVIS] > 0 || you.backlit()))
             return (true);
@@ -1280,23 +1236,11 @@ bool spell_is_useless(spell_type spell, bool transient)
         if (you.can_see_invisible(false, false))
             return (true);
         break;
-    // weapon branding is useless
-    case SPELL_FIRE_BRAND:
-    case SPELL_FREEZING_AURA:
-    case SPELL_LETHAL_INFUSION:
-    case SPELL_WARP_BRAND:
-    case SPELL_EXCRUCIATING_WOUNDS:
-    case SPELL_POISON_WEAPON:
-    // could be useful if it didn't require wielding
-    case SPELL_TUKIMAS_DANCE:
-        if (you.species == SP_CAT)
-            return (true);
-        break;
     case SPELL_DARKNESS:
         // mere corona is not enough, but divine light blocks it completely
         if (transient && you.haloed())
             return true;
-        if (you.religion == GOD_SHINING_ONE && player_under_penance())
+        if (you.religion == GOD_SHINING_ONE && !player_under_penance())
             return true;
         break;
     default:
