@@ -322,8 +322,15 @@ static void _clear_golubria_traps()
     }
 }
 
-static void _leaving_level_now()
+static void _leaving_level_now(dungeon_feature_type stair_used)
 {
+    if (you.level_type == LEVEL_PORTAL_VAULT
+        && stair_used == DNGN_EXIT_PORTAL_VAULT
+        && you.level_type_name_abbrev == "Zig:27") // yay no depth
+    {
+        you.zigs_completed++;
+    }
+
     // Note the name ahead of time because the events may cause markers
     // to be discarded.
     const std::string newtype =
@@ -358,7 +365,7 @@ static void _leaving_level_now()
     if (strwidth(newname_abbrev) > MAX_NOTE_PLACE_LEN)
     {
         mprf(MSGCH_ERROR, "'%s' is too long for a portal vault name "
-                          "abbreviation, truncating");
+                          "abbreviation, truncating", newname_abbrev.c_str());
         newname_abbrev = chop_string(newname_abbrev, MAX_NOTE_PLACE_LEN, false);
     }
 
@@ -620,7 +627,7 @@ void up_stairs(dungeon_feature_type force_stair,
     clear_trapping_net();
 
     // Checks are done, the character is committed to moving between levels.
-    _leaving_level_now();
+    _leaving_level_now(stair_find);
 
     // Interlevel travel data.
     const bool collect_travel_data = can_travel_interlevel();
@@ -706,26 +713,8 @@ void up_stairs(dungeon_feature_type force_stair,
 
     viewwindow();
 
-    // Checking new squares for interesting features.
-    if (!you.running)
-        check_for_interesting_features();
-
     seen_monsters_react();
 
-    // Left Zot without enough runes to get back in (because they were
-    // destroyed), but need to get back in Zot to get the Orb?
-    // Xom finds that funny.
-    if (stair_find == DNGN_RETURN_FROM_ZOT
-        && branches[BRANCH_HALL_OF_ZOT].branch_flags & BFLAG_HAS_ORB)
-    {
-        int runes_avail = you.attribute[ATTR_UNIQUE_RUNES]
-                          + you.attribute[ATTR_DEMONIC_RUNES]
-                          + you.attribute[ATTR_ABYSSAL_RUNES];
-
-        if (runes_avail < NUMBER_OF_RUNES_NEEDED)
-            xom_is_stimulated(255, "Xom snickers loudly.", true);
-    }
-
     if (!allow_control_teleport(true))
         mpr("You sense a powerful magical force warping space.", MSGCH_WARN);
 
@@ -799,29 +788,11 @@ static void _maybe_destroy_trap(const coord_def &p)
 {
     trap_def* trap = find_trap(p);
     if (trap)
-        trap->destroy();
-}
-
-int runes_in_pack(std::vector<int> &runes)
-{
-    int num_runes = 0;
-
-    for (int i = 0; i < ENDOFPACK; i++)
     {
-        if (you.inv[i].defined()
-            && you.inv[i].base_type == OBJ_MISCELLANY
-            && you.inv[i].sub_type == MISC_RUNE_OF_ZOT)
-        {
-            num_runes += you.inv[i].quantity;
-            for (int q = 1;
-                 runes.size() < 3 && q <= you.inv[i].quantity; ++q)
-            {
-                runes.push_back(i);
-            }
-        }
+        trap->destroy();
+        env.map_knowledge(p).set_feature(DNGN_FLOOR);
+        maybe_update_stashes();
     }
-
-    return num_runes;
 }
 
 static bool _is_portal_exit(dungeon_feature_type stair)
@@ -855,7 +826,8 @@ void down_stairs(dungeon_feature_type force_stair,
     // Up and down both work for portals.
     if (feat_is_bidirectional_portal(stair_find))
     {
-        if (stair_find == DNGN_ENTER_HELL && player_in_hell()) {
+        if (stair_find == DNGN_ENTER_HELL && player_in_hell())
+        {
             up_stairs(force_stair, entry_cause);
             return;
         }
@@ -950,9 +922,11 @@ void down_stairs(dungeon_feature_type force_stair,
     if (stair_find == DNGN_ENTER_ZOT && !you.opened_zot)
     {
         std::vector<int> runes;
-        const int num_runes = runes_in_pack(runes);
+        for (int i = 0; i < NUM_RUNE_TYPES; i++)
+            if (you.runes[i])
+                runes.push_back(i);
 
-        if (num_runes < NUMBER_OF_RUNES_NEEDED)
+        if (runes.size() < NUMBER_OF_RUNES_NEEDED)
         {
             switch (NUMBER_OF_RUNES_NEEDED)
             {
@@ -969,8 +943,8 @@ void down_stairs(dungeon_feature_type force_stair,
 
         ASSERT(runes.size() >= 3);
 
-        mprf("You insert %s into the lock.",
-             you.inv[runes[0]].name(DESC_NOCAP_THE).c_str());
+        std::random_shuffle(runes.begin(), runes.end());
+        mprf("You insert the %s rune into the lock.", rune_type_name(runes[0]));
 #ifdef USE_TILE
         tiles.add_overlay(you.pos(), tileidx_zap(GREEN));
         update_screen();
@@ -980,15 +954,13 @@ void down_stairs(dungeon_feature_type force_stair,
         mpr("The lock glows an eerie green colour!");
         more();
 
-        mprf("You insert %s into the lock.",
-             you.inv[runes[1]].name(DESC_NOCAP_THE).c_str());
+        mprf("You insert the %s rune into the lock.", rune_type_name(runes[1]));
         big_cloud(CLOUD_BLUE_SMOKE, &you, you.pos(), 20, 7 + random2(7));
         viewwindow();
         mpr("Heavy smoke blows from the lock!");
         more();
 
-        mprf("You insert %s into the lock.",
-             you.inv[runes[2]].name(DESC_NOCAP_THE).c_str());
+        mprf("You insert the %s rune into the lock.", rune_type_name(runes[2]));
 
         if (silenced(you.pos()))
             mpr("The gate opens wide!");
@@ -1013,7 +985,7 @@ void down_stairs(dungeon_feature_type force_stair,
     clear_trapping_net();
 
     // Fire level-leaving trigger.
-    _leaving_level_now();
+    _leaving_level_now(stair_find);
 
     if (!force_stair && !crawl_state.game_is_arena())
     {
@@ -1193,7 +1165,7 @@ void down_stairs(dungeon_feature_type force_stair,
             if (shaft || feat_is_escape_hatch(stair_find))
                 xom_is_stimulated(shaft_depth * 50);
             else
-                xom_is_stimulated(14);
+                xom_is_stimulated(10);
             break;
 
         case LEVEL_PORTAL_VAULT:
@@ -1205,7 +1177,7 @@ void down_stairs(dungeon_feature_type force_stair,
             // Finding the way out of a labyrinth interests Xom,
             // but less so for Minotaurs. (though not now, as they cannot
             // map the labyrinth any more {due})
-            xom_is_stimulated(98);
+            xom_is_stimulated(75);
             break;
 
         case LEVEL_ABYSS:
@@ -1224,18 +1196,18 @@ void down_stairs(dungeon_feature_type force_stair,
                 || entry_cause != EC_SELF_EXPLICIT)
             {
                 if (crawl_state.is_god_acting())
-                    xom_is_stimulated(255);
+                    xom_is_stimulated(200);
                 else if (entry_cause == EC_SELF_EXPLICIT)
                 {
                     // Entering Pandemonium or the Abyss for the first
                     // time *voluntarily* stimulates Xom much more than
                     // entering a normal dungeon level for the first time.
-                    xom_is_stimulated(128, XM_INTRIGUED);
+                    xom_is_stimulated(100, XM_INTRIGUED);
                 }
                 else if (entry_cause == EC_SELF_RISKY)
-                    xom_is_stimulated(128);
+                    xom_is_stimulated(100);
                 else
-                    xom_is_stimulated(255);
+                    xom_is_stimulated(200);
             }
 
             break;
@@ -1294,10 +1266,6 @@ void down_stairs(dungeon_feature_type force_stair,
 
     viewwindow();
 
-    // Checking new squares for interesting features.
-    if (!you.running)
-        check_for_interesting_features();
-
     maybe_update_stashes();
 
     request_autopickup();
@@ -1329,6 +1297,14 @@ void new_level(bool restore)
         std::string desc = "Entered " + place_name(get_packed_place(), true, true);
         take_note(Note(NOTE_DUNGEON_LEVEL_CHANGE, 0, 0, NULL,
                       desc.c_str()));
+
+        // Ziggurat code is a big steaming pile of duplicating in an
+        // incompatible and buggy way things which are already done
+        // elsewhere.  So, instead of having a branch enum and proper
+        // depth like everything else, all you can do is parse strings.
+        int zig_depth;
+        if (sscanf(you.level_type_name_abbrev.c_str(), "Zig:%d", &zig_depth) == 1)
+            you.zig_max = zig_depth;
     }
     else
         take_note(Note(NOTE_DUNGEON_LEVEL_CHANGE));
