@@ -8,6 +8,7 @@
 
 #include <cstdio>
 
+#include "bitary.h"
 #include "tag-version.h"
 #include "package.h"
 
@@ -233,6 +234,7 @@ static inline void unmarshallSigned(reader& th, T& v)
 
 void tag_read(reader &inf, tag_type tag_id);
 void tag_write(tag_type tagID, writer &outf);
+void tag_read_char(reader &th, uint8_t format, uint8_t major, uint8_t minor);
 
 /* ***********************************************************************
  * misc
