@@ -11,6 +11,7 @@
 #include "fprop.h"
 #include "items.h"
 #include "kills.h"
+#include "libutil.h"
 #include "mon-stuff.h"
 #include "mon-util.h"
 #include "options.h"
@@ -27,12 +28,6 @@
 
 void tile_new_level(bool first_time, bool init_unseen)
 {
-    tiles.clear_minimap();
-
-    for (unsigned int x = 0; x < GXM; x++)
-        for (unsigned int y = 0; y < GYM; y++)
-            tiles.update_minimap(coord_def(x, y));
-
     if (first_time)
         tile_init_flavour();
 
@@ -58,6 +53,12 @@ void tile_new_level(bool first_time, bool init_unseen)
             if (!is_unknown_stair(coord_def(x,y)))
                 env.tile_bk_bg[x][y] &= ~TILE_FLAG_NEW_STAIR;
         }
+
+    tiles.clear_minimap();
+
+    for (unsigned int x = 0; x < GXM; x++)
+        for (unsigned int y = 0; y < GYM; y++)
+            tiles.update_minimap(coord_def(x, y));
 }
 
 void tile_init_default_flavour()
@@ -153,7 +154,6 @@ void tile_default_flv(level_area_type lev, branch_type br, tile_flavour &flv)
 
     case BRANCH_TARTARUS:
     case BRANCH_CRYPT:
-    case BRANCH_VESTIBULE_OF_HELL:
         flv.wall  = TILE_WALL_UNDEAD;
         flv.floor = TILE_FLOOR_TOMB;
         return;
@@ -163,6 +163,11 @@ void tile_default_flv(level_area_type lev, branch_type br, tile_flavour &flv)
         flv.floor = TILE_FLOOR_TOMB;
         return;
 
+    case BRANCH_VESTIBULE_OF_HELL:
+        flv.wall  = TILE_WALL_HELL;
+        flv.floor = TILE_FLOOR_INFERNAL;
+        return;
+
     case BRANCH_DIS:
         flv.wall  = TILE_WALL_ZOT_CYAN;
         flv.floor = TILE_FLOOR_TOMB;
@@ -734,7 +739,7 @@ void tile_place_monster(const coord_def &gc, const monster* mon)
         return;
 
     // HACK.  Large-tile monsters don't interact well with name tags.
-    if (mon->type == MONS_PANDEMONIUM_DEMON
+    if (mon->type == MONS_PANDEMONIUM_LORD
         || mon->type == MONS_LERNAEAN_HYDRA)
     {
         return;
@@ -745,6 +750,7 @@ void tile_place_monster(const coord_def &gc, const monster* mon)
 void tile_clear_monster(const coord_def &gc)
 {
     env.tile_bk_fg(gc) = get_clean_map_idx(env.tile_bk_fg(gc), true);
+    tile_clear_map(gc);
 }
 
 void tile_place_cloud(const coord_def &gc, const cloud_struct &cl)
@@ -801,8 +807,8 @@ void tile_draw_rays(bool reset_count)
 {
     for (unsigned int i = 0; i < num_tile_rays; i++)
     {
-        tileidx_t flag = tile_ray_vec[i].in_range > 0 ? TILE_FLAG_RAY
-                                                      : TILE_FLAG_RAY_OOR;
+        tileidx_t flag = tile_ray_vec[i].in_range > AFF_MAYBE ? TILE_FLAG_RAY
+                                                           : TILE_FLAG_RAY_OOR;
         env.tile_bg(tile_ray_vec[i].ep) |= flag;
     }
 
@@ -1024,19 +1030,23 @@ void tile_apply_properties(const coord_def &gc, packed_cell &cell)
     if (haloed(gc))
     {
         monster* mon = monster_at(gc);
-        if (you.see_cell(gc) && mon)
+        if (you.see_cell(gc))
         {
-            if (!mons_class_flag(mon->type, M_NO_EXP_GAIN)
+            if (mon && !mons_class_flag(mon->type, M_NO_EXP_GAIN)
                  && (!mons_is_mimic(mon->type)
                      || testbits(mon->flags, MF_KNOWN_MIMIC)))
             {
-                cell.is_haloed = true;
+                cell.halo = HALO_MONSTER;
                 print_blood = false;
             }
+            else
+            {
+                cell.halo = HALO_RANGE;
+            }
         }
     }
     else
-        cell.is_haloed = false;
+        cell.halo = HALO_NONE;
 
     if (liquefied(gc, true))
         cell.is_liquefied = true;
@@ -1061,7 +1071,7 @@ void tile_apply_properties(const coord_def &gc, packed_cell &cell)
         }
     }
 
-    const dungeon_feature_type feat = grd(gc);
+    const dungeon_feature_type feat = env.map_knowledge(gc).feat();
     if (feat_is_water(feat) || feat == DNGN_LAVA)
         cell.bg |= TILE_FLAG_WATER;
 
@@ -1071,7 +1081,7 @@ void tile_apply_properties(const coord_def &gc, packed_cell &cell)
     if (silenced(gc))
         cell.is_silenced = true;
 
-    if (grd(gc) == DNGN_SWAMP_TREE)
+    if (feat == DNGN_SWAMP_TREE)
         cell.swamp_tree_water = true;
 }
 
