@@ -471,7 +471,8 @@ force_overlay:%u,show_diameter:%u,msg_min_height:%u,stat_width:%u,   \
 min_stat_height:%u,gxm:%u,gym:%u},%u);",
                        Options.view_max_width, Options.view_max_height,
                        Options.tile_force_overlay, ENV_SHOW_DIAMETER,
-                       Options.msg_min_height, stat_width, min_stat_height,
+                       Options.msg_min_height, stat_width,
+                       min_stat_height + (Options.show_gold_turns ? 1 : 0),
                        GXM, GYM,
                        need_response);
 }
@@ -752,6 +753,12 @@ void TilesFramework::update_minimap(const coord_def& gc)
         gc.y < 0 || gc.y >= m_next_view.size().y)
         return;
 
+    if (you.see_cell(gc))
+        return; // This will get updated by load_dungeon.
+                // Also, it's possible that tile_bg is not yet
+                // initialized, which could lead to problems
+                // if we try to draw in-los cells.
+
     screen_cell_t *cell = &m_next_view[gc.x + gc.y * GXM];
 
     draw_cell(cell, gc, false, m_next_flash_colour);
