@@ -51,12 +51,12 @@
 
 bool trap_def::active() const
 {
-    return (this->type != TRAP_UNASSIGNED);
+    return (type != TRAP_UNASSIGNED);
 }
 
 bool trap_def::type_has_ammo() const
 {
-    switch (this->type)
+    switch (type)
     {
     case TRAP_DART:   case TRAP_ARROW:  case TRAP_BOLT:
     case TRAP_NEEDLE: case TRAP_SPEAR:  case TRAP_AXE:
@@ -69,81 +69,87 @@ bool trap_def::type_has_ammo() const
 
 void trap_def::message_trap_entry()
 {
-    if (this->type == TRAP_TELEPORT)
+    if (type == TRAP_TELEPORT)
         mpr("You enter a teleport trap!");
 }
 
 void trap_def::disarm()
 {
-    if (this->type_has_ammo() && this->ammo_qty > 0)
+    if (type_has_ammo() && ammo_qty > 0)
     {
-        item_def trap_item = this->generate_trap_item();
-        trap_item.quantity = this->ammo_qty;
-        copy_item_to_grid(trap_item, this->pos);
+        item_def trap_item = generate_trap_item();
+        trap_item.quantity = ammo_qty;
+        copy_item_to_grid(trap_item, pos);
     }
-    this->destroy();
+    destroy();
 }
 
 void trap_def::destroy()
 {
-    if (!in_bounds(this->pos))
+    if (!in_bounds(pos))
         die("Trap position out of bounds!");
 
-    grd(this->pos) = DNGN_FLOOR;
-    this->ammo_qty = 0;
-    this->pos      = coord_def(-1,-1);
-    this->type     = TRAP_UNASSIGNED;
+    grd(pos) = DNGN_FLOOR;
+    ammo_qty = 0;
+    pos      = coord_def(-1,-1);
+    type     = TRAP_UNASSIGNED;
 }
 
 void trap_def::hide()
 {
-    grd(this->pos) = DNGN_UNDISCOVERED_TRAP;
+    grd(pos) = DNGN_UNDISCOVERED_TRAP;
 }
 
 void trap_def::prepare_ammo()
 {
-    switch (this->type)
+    switch (type)
     {
     case TRAP_DART:
     case TRAP_ARROW:
     case TRAP_BOLT:
     case TRAP_NEEDLE:
-        this->ammo_qty = 3 + random2avg(9, 3);
+        ammo_qty = 3 + random2avg(9, 3);
         break;
     case TRAP_SPEAR:
     case TRAP_AXE:
-        this->ammo_qty = 2 + random2avg(6, 3);
+        ammo_qty = 2 + random2avg(6, 3);
         break;
     case TRAP_ALARM:
-        this->ammo_qty = 1 + random2(3);
+        ammo_qty = 1 + random2(3);
         // Zotdef: alarm traps have practically unlimited ammo
         if (crawl_state.game_is_zotdef())
-            this->ammo_qty = 100000;
+            ammo_qty = 3276; // *10, stored as short
         break;
     case TRAP_GOLUBRIA:
         // really, turns until it vanishes
-        this->ammo_qty = 30 + random2(20);
+        ammo_qty = 30 + random2(20);
+        break;
+    case TRAP_TELEPORT:
+        if (crawl_state.game_is_zotdef())
+            this->ammo_qty = 2 + random2(2);
+        else
+            this->ammo_qty = 0;
         break;
     default:
-        this->ammo_qty = 0;
+        ammo_qty = 0;
         break;
     }
     // Zot def: traps have 10x as much ammo
-    if (crawl_state.game_is_zotdef())
-        this->ammo_qty *= 10;
+    if (crawl_state.game_is_zotdef() && type != TRAP_GOLUBRIA)
+        ammo_qty *= 10;
 }
 
 void trap_def::reveal()
 {
-    grd(this->pos) = this->category();
+    grd(pos) = category();
 }
 
 std::string trap_def::name(description_level_type desc) const
 {
-    if (this->type >= NUM_TRAPS)
+    if (type >= NUM_TRAPS)
         return ("buggy");
 
-    const char* basename = trap_name(this->type);
+    const char* basename = trap_name(type);
     if (desc == DESC_CAP_A || desc == DESC_NOCAP_A)
     {
         std::string prefix = (desc == DESC_CAP_A ? "A" : "a");
@@ -179,7 +185,7 @@ bool trap_def::is_known(const actor* act) const
         // * very intelligent monsters can be assumed to have a high T&D
         //   skill (or have memorised part of the dungeon layout ;))
 
-        if (this->category() == DNGN_TRAP_NATURAL)
+        if (category() == DNGN_TRAP_NATURAL)
         {
             // Slightly different rules for shafts:
             // * Lower intelligence requirement for native monsters.
@@ -191,15 +197,68 @@ bool trap_def::is_known(const actor* act) const
         }
         else
         {
-            return (intel >= I_NORMAL
-                    && (mons_is_native_in_branch(mons)
-                        || player_knows && mons->wont_attack()
-                        || intel >= I_HIGH && one_chance_in(3)));
+            if (intel < I_NORMAL)
+                return false;
+            if (player_knows && mons->wont_attack())
+                return true;
+
+            // This should ultimately be removed, but only after monsters
+            // learn to make use of the trap being limited in ZotDef if
+            // there is no other way.  Golubria and Malign Gateway are a
+            // problem, too...
+            if (crawl_state.game_is_zotdef())
+                return false;
+
+            return (mons_is_native_in_branch(mons)
+                    || intel >= I_HIGH && one_chance_in(3));
         }
     }
     die("invalid actor type");
 }
 
+bool trap_def::is_safe(actor* act) const
+{
+    if (!act)
+        act = &you;
+
+    // Shaft and mechanical traps are safe when flying or clinging.
+    if ((act->airborne() || act->can_cling_to(pos))
+        && category() != DNGN_TRAP_MAGICAL)
+    {
+        return true;
+    }
+
+    if (act->atype() != ACT_PLAYER)
+        return false;
+
+    // No prompt (teleport traps are ineffective if
+    // wearing an amulet of stasis)
+    if (type == TRAP_TELEPORT
+        && (player_equip(EQ_AMULET, AMU_STASIS, true)
+            || scan_artefacts(ARTP_PREVENT_TELEPORTATION, false)))
+    {
+        return true;
+    }
+
+    if (!is_known(act))
+        return false;
+
+    if (type == TRAP_GOLUBRIA || type == TRAP_SHAFT
+        || crawl_state.game_is_zotdef())
+    {
+        return true;
+    }
+
+    #ifdef CLUA_BINDINGS
+     // Prompt for any trap where you might not have enough hp
+     // as defined in init.txt (see trapwalk.lua)
+     if (clua.callbooleanfn(false, "ch_cross_trap", "s", name().c_str()))
+         return true;
+
+#endif
+
+     return false;
+}
 
 // Returns the number of a net on a given square.
 // If trapped, only stationary ones are counted
@@ -430,11 +489,11 @@ std::string direction_string(coord_def pos, bool fuzz)
 
 void trap_def::trigger(actor& triggerer, bool flat_footed)
 {
-    const bool you_know = this->is_known();
-    const bool trig_knows = !flat_footed && this->is_known(&triggerer);
+    const bool you_know = is_known();
+    const bool trig_knows = !flat_footed && is_known(&triggerer);
 
     const bool you_trigger = (triggerer.atype() == ACT_PLAYER);
-    const bool in_sight = you.see_cell(this->pos);
+    const bool in_sight = you.see_cell(pos);
 
     // Zot def - player never sets off known traps
     if (crawl_state.game_is_zotdef() && you_trigger && you_know)
@@ -452,7 +511,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
     // Smarter monsters and those native to the level will simply
     // side-step known shafts. Unless they are already looking for
     // an exit, of course.
-    if (this->type == TRAP_SHAFT && m)
+    if (type == TRAP_SHAFT && m)
     {
         if (!m->will_trigger_shaft()
             || trig_knows && !mons_is_fleeing(m) && !m->pacified())
@@ -471,7 +530,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
         return;
     }
     // Only magical traps affect flying critters.
-    if (!triggerer.ground_level() && this->category() != DNGN_TRAP_MAGICAL)
+    if (!triggerer.ground_level() && category() != DNGN_TRAP_MAGICAL)
     {
         if (you_know && m && triggerer.airborne())
             simple_monster_message(m, " flies safely over a trap.");
@@ -481,20 +540,21 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
     // Anything stepping onto a trap almost always reveals it.
     // (We can rehide it later for the exceptions.)
     if (in_sight)
-        this->reveal();
+        reveal();
 
     // OK, something is going to happen.
     if (you_trigger)
-        this->message_trap_entry();
+        message_trap_entry();
 
     // Store the position now in case it gets cleared inbetween.
-    const coord_def p(this->pos);
+    const coord_def p(pos);
 
-    if (this->type_has_ammo())
-        this->shoot_ammo(triggerer, trig_knows);
-    else switch (this->type)
+    if (type_has_ammo())
+        shoot_ammo(triggerer, trig_knows);
+    else switch (type)
+    {
+    case TRAP_GOLUBRIA:
     {
-    case TRAP_GOLUBRIA: {
         coord_def to = p;
         if (_find_other_passage_side(to))
         {
@@ -523,7 +583,15 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
         // Never revealed by monsters.
         // except when it's in sight, it's pretty obvious what happened. -doy
         if (!you_trigger && !you_know && !in_sight)
-            this->hide();
+            hide();
+        if (ammo_qty > 0 && !--ammo_qty)
+        {
+            // can't use trap_destroyed, as we might recurse into a shaft
+            // or be banished by a Zot trap
+            if (in_sight)
+                env.map_knowledge(pos).set_feature(DNGN_FLOOR);
+            disarm();
+        }
         triggerer.teleport(true);
         break;
 
@@ -536,14 +604,14 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
                 mpr("The alarm trap gives no sound.");
             trap_destroyed = true;
         }
-        else if (silenced(this->pos))
+        else if (silenced(pos))
         {
             if (you_know && in_sight)
                 mpr("The alarm trap is silent.");
 
             // If it's silent, you don't know about it.
             if (!you_know)
-                this->hide();
+                hide();
         }
         else if (!(m && m->friendly()))
         {
@@ -554,7 +622,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
                 msg = "An alarm trap emits a blaring wail!";
             else
             {
-                std::string dir=direction_string(this->pos, !in_sight);
+                std::string dir=direction_string(pos, !in_sight);
                 msg = std::string("You hear a ") +
                     ((in_sight) ? "" : "distant ")
                     + "blaring wail "
@@ -567,7 +635,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
 
             // Zotdef - Made alarm traps noisier and more noticeable
             int noiselevel = crawl_state.game_is_zotdef() ? 30 : 12;
-            noisy(noiselevel, this->pos, msg.c_str(), source, false);
+            noisy(noiselevel, pos, msg.c_str(), source, false);
             if (crawl_state.game_is_zotdef())
                 more();
         }
@@ -604,7 +672,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
                                            " fails to trigger a blade trap.");
                 }
                 else
-                    this->hide();
+                    hide();
             }
             else if (random2(m->ev) > 8 || (trig_knows && random2(m->ev) > 8))
             {
@@ -669,10 +737,10 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
                 {
                     mpr("A large net falls onto you!");
                     if (player_caught_in_net() && player_in_a_dangerous_place())
-                        xom_is_stimulated(64);
+                        xom_is_stimulated(50);
                 }
 
-                item_def item = this->generate_trap_item();
+                item_def item = generate_trap_item();
                 copy_item_to_grid(item, triggerer.pos());
 
                 if (you.attribute[ATTR_HELD])
@@ -691,7 +759,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
                 if (you_know)
                     simple_monster_message(m, " fails to trigger a net trap.");
                 else
-                    this->hide();
+                    hide();
             }
             else if (random2(m->ev) > 8 || (trig_knows && random2(m->ev) > 8))
             {
@@ -730,7 +798,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
 
             if (triggered)
             {
-                item_def item = this->generate_trap_item();
+                item_def item = generate_trap_item();
                 copy_item_to_grid(item, triggerer.pos());
 
                 if (m->caught())
@@ -747,7 +815,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
             mpr((trig_knows) ? "You enter the Zot trap."
                              : "Oh no! You have blundered into a Zot trap!");
             if (!trig_knows)
-                xom_is_stimulated(32);
+                xom_is_stimulated(25);
 
             MiscastEffect(&you, ZOT_TRAP_MISCAST, SPTYP_RANDOM,
                            3, "a Zot trap");
@@ -769,7 +837,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
 
             // Give the player a chance to figure out what happened
             // to their friend.
-            if (player_can_hear(this->pos) && (!targ || !in_sight))
+            if (player_can_hear(pos) && (!targ || !in_sight))
             {
                 mprf(MSGCH_SOUND, "You hear a %s \"Zot\"!",
                      in_sight ? "loud" : "distant");
@@ -806,7 +874,7 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
         // The shafting code in downstairs() needs to know
         // whether it's undiscovered.
         if (!you_know)
-            this->hide();
+            hide();
 
         // Known shafts don't trigger as traps.
         if (trig_knows)
@@ -825,7 +893,10 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
         if (!you_trigger)
         {
             if (in_sight)
+            {
                 mpr("The shaft crumbles and collapses.");
+                know_trap_destroyed = true;
+            }
             trap_destroyed = true;
         }
         break;
@@ -844,17 +915,15 @@ void trap_def::trigger(actor& triggerer, bool flat_footed)
 
         // Exercise T&D if the trap revealed itself, but not if it ran
         // out of ammo.
-        if (!you_know && this->type != TRAP_UNASSIGNED && this->is_known())
+        if (!you_know && type != TRAP_UNASSIGNED && is_known())
             practise(EX_TRAP_TRIGGER);
     }
 
     if (trap_destroyed)
     {
         if (know_trap_destroyed)
-        {
-            env.map_knowledge(this->pos).set_feature(DNGN_FLOOR);
-        }
-        this->destroy();
+            env.map_knowledge(pos).set_feature(DNGN_FLOOR);
+        destroy();
     }
 }
 
@@ -869,7 +938,7 @@ int trap_def::max_damage(const actor& act)
     if (act.atype() == ACT_MONSTER)
         level = 0;
 
-    switch (this->type)
+    switch (type)
     {
         case TRAP_NEEDLE: return  0;
         case TRAP_DART:   return  4 + level/2;
@@ -908,7 +977,7 @@ int reveal_traps(const int range)
         {
             traps_found++;
             trap.reveal();
-            env.map_knowledge(trap.pos).set_feature(grd(trap.pos));
+            env.map_knowledge(trap.pos).set_feature(grd(trap.pos), 0, trap.type);
             set_terrain_mapped(trap.pos);
         }
     }
@@ -1333,7 +1402,7 @@ item_def trap_def::generate_trap_item()
     object_class_type base;
     int sub;
 
-    switch (this->type)
+    switch (type)
     {
     case TRAP_DART:   base = OBJ_MISSILES; sub = MI_DART;         break;
     case TRAP_ARROW:  base = OBJ_MISSILES; sub = MI_ARROW;        break;
@@ -1366,14 +1435,14 @@ item_def trap_def::generate_trap_item()
 // Shoot a single piece of ammo at the relevant actor.
 void trap_def::shoot_ammo(actor& act, bool was_known)
 {
-    if (this->ammo_qty <= 0)
+    if (ammo_qty <= 0)
     {
         if (was_known && act.atype() == ACT_PLAYER)
             mpr("The trap is out of ammunition!");
-        else if (player_can_hear(this->pos) && you.see_cell(this->pos))
+        else if (player_can_hear(pos) && you.see_cell(pos))
             mpr("You hear a soft click.");
 
-        this->disarm();
+        disarm();
     }
     else
     {
@@ -1381,7 +1450,7 @@ void trap_def::shoot_ammo(actor& act, bool was_known)
         // resetting its position) before the ammo can be dropped.
         const coord_def apos = act.pos();
 
-        item_def shot = this->generate_trap_item();
+        item_def shot = generate_trap_item();
 
         bool force_poison = (env.markers.property_at(pos, MAT_ANY,
                                 "poisoned_needle_trap") == "true");
@@ -1389,13 +1458,13 @@ void trap_def::shoot_ammo(actor& act, bool was_known)
         bool force_hit = (env.markers.property_at(pos, MAT_ANY,
                                 "force_hit") == "true");
 
-        bool poison = (this->type == TRAP_NEEDLE
+        bool poison = (type == TRAP_NEEDLE
                        && !act.res_poison()
                        && (x_chance_in_y(50 - (3*act.armour_class()) / 2, 100)
                             || force_poison));
 
         int damage_taken =
-            std::max(this->shot_damage(act) - random2(act.armour_class()+1),0);
+            std::max(shot_damage(act) - random2(act.armour_class()+1),0);
 
         int trap_hit = (20 + (you.absdepth0*2)) * random2(200) / 100;
 
@@ -1404,7 +1473,7 @@ void trap_def::shoot_ammo(actor& act, bool was_known)
             if (!force_hit && (one_chance_in(5) || was_known && !one_chance_in(4)))
             {
                 mprf("You avoid triggering %s trap.",
-                      this->name(DESC_NOCAP_A).c_str());
+                      name(DESC_NOCAP_A).c_str());
 
                 return;         // no ammo generated either
             }
@@ -1494,7 +1563,7 @@ void trap_def::shoot_ammo(actor& act, bool was_known)
         if (coinflip())
             copy_item_to_grid(shot, apos);
 
-        this->ammo_qty--;
+        ammo_qty--;
     }
 }
 
