@@ -611,13 +611,13 @@ static void _draw_title(const coord_def& cpos, const feature_list& feats)
     const int columns = get_number_of_cols();
     const formatted_string help =
         formatted_string::parse_string("(Press <w>?</w> for help)");
-    const int helplen = std::string(help).length();
+    const int helplen = help.width();
 
     if (columns < helplen)
         return;
 
     const formatted_string title = feats.format();
-    const int titlelen = title.length();
+    const int titlelen = title.width();
     if (columns < titlelen)
         return;
 
@@ -850,7 +850,6 @@ bool show_map(level_pos &lpos,
                 new_level = false;
             }
 
-#if defined(USE_UNIX_SIGNALS) && defined(SIGHUP_SAVE) && defined(USE_CURSES)
             // If we've received a HUP signal then the user can't choose a
             // location, so indicate this by returning an invalid position.
             if (crawl_state.seen_hups)
@@ -858,7 +857,6 @@ bool show_map(level_pos &lpos,
                 lpos = level_pos();
                 chose = false;
             }
-#endif
 
             start_y = screen_y - half_screen;
 
@@ -1241,22 +1239,14 @@ bool show_map(level_pos &lpos,
             if (!map_alive)
                 break;
 
-#ifdef USE_TILE
-            {
-                const coord_def oldp = lpos.pos;
-                lpos.pos.x += move_x;
-                lpos.pos.y += move_y;
-                lpos.pos.x = std::min(std::max(lpos.pos.x, 1), GXM);
-                lpos.pos.y = std::min(std::max(lpos.pos.y, 1), GYM);
-                curs_x += lpos.pos.x - oldp.x;
-                curs_y += lpos.pos.y - oldp.y;
-            }
-#else
-            if (curs_x + move_x < 1 || curs_x + move_x > crawl_view.termsz.x)
-                move_x = 0;
-
-            curs_x += move_x;
-
+            const coord_def oldp = lpos.pos;
+            lpos.pos.x += move_x;
+            lpos.pos.y += move_y;
+            lpos.pos.x = std::min(std::max(lpos.pos.x, min_x), max_x);
+            lpos.pos.y = std::min(std::max(lpos.pos.y, min_y), max_y);
+            move_x = lpos.pos.x - oldp.x;
+            move_y = lpos.pos.y - oldp.y;
+#ifndef USE_TILE
             if (num_lines < map_lines)
             {
                 // Scrolling only happens when we don't have a large enough
@@ -1272,48 +1262,21 @@ bool show_map(level_pos &lpos,
                     curs_y -= (screen_y - old_screen_y);
                     scroll_y = 0;
                 }
-
-                if (curs_y + move_y < 1)
+                if (curs_y + move_y < 1 || curs_y + move_y > num_lines)
                 {
                     screen_y += move_y;
-
-                    if (screen_y < min_y + half_screen)
-                    {
-                        move_y   = screen_y - (min_y + half_screen);
-                        screen_y = min_y + half_screen;
-                    }
-                    else
-                        move_y = 0;
-                }
-
-                if (curs_y + move_y > num_lines)
-                {
-                    screen_y += move_y;
-
-                    if (screen_y > max_y - half_screen)
-                    {
-                        move_y   = screen_y - (max_y - half_screen);
-                        screen_y = max_y - half_screen;
-                    }
-                    else
-                        move_y = 0;
+                    curs_y -= move_y;
                 }
             }
             start_y = screen_y - half_screen;
-
-            if (curs_y + move_y < 1 || curs_y + move_y > num_lines)
-                move_y = 0;
-
-            curs_y += move_y;
-
-            lpos.pos.x = start_x + curs_x - 1;
-            lpos.pos.y = start_y + curs_y - 1;
 #endif
+            curs_x += move_x;
+            curs_y += move_y;
         }
     }
 
 #ifdef USE_TILE
-    tiles.place_cursor(CURSOR_MAP, Region::NO_CURSOR);
+    tiles.place_cursor(CURSOR_MAP, NO_CURSOR);
 #endif
 
     redraw_screen();
