@@ -1017,7 +1017,9 @@ static void _debug_acquirement_stats(FILE *ostat)
     const int e_order[] =
     {
         EQ_WEAPON, EQ_BODY_ARMOUR, EQ_SHIELD, EQ_HELMET, EQ_CLOAK,
-        EQ_GLOVES, EQ_BOOTS, EQ_AMULET, EQ_RIGHT_RING, EQ_LEFT_RING
+        EQ_GLOVES, EQ_BOOTS, EQ_AMULET, EQ_RIGHT_RING, EQ_LEFT_RING,
+        EQ_RING_ONE, EQ_RING_TWO, EQ_RING_THREE, EQ_RING_FOUR,
+        EQ_RING_FIVE, EQ_RING_SIX, EQ_RING_SEVEN, EQ_RING_EIGHT
     };
 
     bool naked = true;
@@ -1294,6 +1296,7 @@ static void _debug_acquirement_stats(FILE *ostat)
     mpr("Results written into 'items.stat'.");
 }
 
+#define MAX_TRIES 16777216 /* not special anymore */
 static void _debug_rap_stats(FILE *ostat)
 {
     int i = prompt_invent_item("Generate randart stats on which item?",
@@ -1376,7 +1379,7 @@ static void _debug_rap_stats(FILE *ostat)
 
     artefact_properties_t proprt;
 
-    for (i = 0; i < RANDART_SEED_MASK; ++i)
+    for (i = 0; i < MAX_TRIES; ++i)
     {
         if (kbhit())
         {
@@ -1385,8 +1388,6 @@ static void _debug_rap_stats(FILE *ostat)
             break;
         }
 
-        item.special = i;
-
         // Generate proprt once and hand it off to randart_is_bad(),
         // so that randart_is_bad() doesn't generate it a second time.
         artefact_wpn_properties(item, proprt);
@@ -1442,11 +1443,11 @@ static void _debug_rap_stats(FILE *ostat)
         total_bad_props     += num_bad_props;
         total_balance_props += balance;
 
-        if (i % 16777 == 0)
+        if (i % 16767 == 0)
         {
             mesclr();
             float curr_percent = (float) i * 1000.0
-                / (float) RANDART_SEED_MASK;
+                / (float) MAX_TRIES;
             mprf("%4.1f%% done.", curr_percent / 10.0);
         }
 
